@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qapplication.h>
@@ -27,10 +27,10 @@
 
 #include <kdebug.h>
 #include <kgenericfactory.h>
-#include <koDocumentInfo.h>
-#include <koFilter.h>
-#include <koFilterChain.h>
-#include <koStore.h>
+#include <KoDocumentInfo.h>
+#include <KoFilter.h>
+#include <KoFilterChain.h>
+#include <KoStore.h>
 
 #include "epsexport.h"
 #include "epsexportdlg.h"
@@ -366,7 +366,7 @@ EpsExport::getFill( const VFill& fill )
 			if( ramp.size() > 2 || ramp.size() == 2 && ramp[0]->midPoint != 0.5 )
 			{
 				// Gradient with more than two colors or asymmetrical midpoint.
-				for( int i = 1;i < ramp.size();i++ )
+				for( uint i = 1;i < ramp.size();i++ )
 				{
 					char name[15];
 					sprintf( name, "Function%d", 2 * i - 1 );
@@ -409,10 +409,10 @@ EpsExport::getFill( const VFill& fill )
 			{
 				// Gradient with more than two colors or asymmetrical midpoint.
 				*m_stream << "\t\t/FunctionType 3\n" << "\t\t/Functions [ ";
-				for( int i = 1; i < ( 2 * ramp.size() - 1 );i++ )
+				for( uint i = 1; i < ( 2 * ramp.size() - 1 );i++ )
 					*m_stream << "Function" << i << " ";
 				*m_stream << "]\n" << "\t\t/Bounds [";
-				for( int i = 0;i < ramp.size() - 1;i++ )
+				for( uint i = 0;i < ramp.size() - 1;i++ )
 				{
 					VColorStop stop = *ramp[i];
 					if( i > 0 )
@@ -420,7 +420,7 @@ EpsExport::getFill( const VFill& fill )
 					*m_stream << " " << ( stop.rampPoint + ( ramp[i + 1]->rampPoint - stop.rampPoint ) * stop.midPoint );
 				}
 				*m_stream << " ]\n" << "\t\t/Encode [ ";
-				for( int i = 0;i < 2 * ramp.size() - 2;i++ )
+				for( uint i = 0;i < 2 * ramp.size() - 2;i++ )
 					*m_stream << "0 1 ";
 				*m_stream << "]\n";
 			}
