@@ -13,15 +13,16 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __KONTOURIMPORT_H__
 #define __KONTOURIMPORT_H__
 
-#include <koFilter.h>
+#include <KoFilter.h>
 #include <qdom.h>
+#include <core/vdocument.h>
 
 class KontourImport : public KoFilter
 {
@@ -32,11 +33,16 @@ public:
 	virtual ~KontourImport();
 
 	virtual KoFilter::ConversionStatus convert(const QCString& from, const QCString& to);
+
 protected:
 	QDomDocument inpdoc;
 	QDomDocument outdoc;
 	void convert();
-	void importRectangle( QDomElement base, QDomElement lay );
+
+private:
+	void parseGObject( VObject *, const QDomElement & );
+	void parseGroup( const QDomElement & );
+	VDocument m_document;
 };
 
 #endif // __KONTOURIMPORT_H__
