@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qcstring.h>
@@ -24,9 +24,9 @@
 #include <qvaluelist.h>
 
 #include <kgenericfactory.h>
-#include <koFilter.h>
-#include <koFilterChain.h>
-#include <koStore.h>
+#include <KoFilter.h>
+#include <KoFilterChain.h>
+#include <KoStore.h>
 
 #include "svgexport.h"
 #include "vcolor.h"
@@ -43,17 +43,26 @@
 #include "vsegment.h"
 #include "vselection.h"
 #include "vstroke.h"
-//#include "vtext.h"
+#include "vtext.h"
+#include <commands/vtransformcmd.h>
 
 #include <kdebug.h>
 
+QString INDENT("  ");
+
+void
+printIndentation( QTextStream *stream, unsigned int indent )
+{
+	for( unsigned int i = 0; i < indent;++i)
+		*stream << INDENT;
+}
 
 typedef KGenericFactory<SvgExport, KoFilter> SvgExportFactory;
 K_EXPORT_COMPONENT_FACTORY( libkarbonsvgexport, SvgExportFactory( "kofficefilters" ) )
 
 
 SvgExport::SvgExport( KoFilter*, const char*, const QStringList& )
-	: KoFilter()
+	: KoFilter(), m_indent( 0 ), m_indent2( 0 ), m_trans( 0L )
 {
 	m_gc.setAutoDelete( true );
 }
@@ -87,7 +96,6 @@ SvgExport::convert( const QCString& from, const QCString& to )
 	QString defs;
 	m_defs = new QTextStream( &defs, IO_ReadWrite );
 
-
 	// load the document and export it:
 	VDocument doc;
 	doc.load( docNode );
@@ -126,11 +134,13 @@ SvgExport::visitVDocument( VDocument& document )
 		"<!-- Created using Karbon14, part of koffice: http://www.koffice.org/karbon -->" << endl;
 
 	*m_defs <<
-		"<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"" <<
+		"<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"" <<
 		rect.width() << "px\" height=\"" << rect.height() << "px\">" << endl;
+	printIndentation( m_defs, ++m_indent2 );
 	*m_defs << "<defs>" << endl;
 
-	*m_body << "<g transform=\"scale(1, -1) translate(0, -" << rect.height() << ")\">" << endl;
+	m_indent++;
+	m_indent2++;
 
 	// we dont need the selection anymore:
 	document.selection()->clear();
@@ -139,11 +149,20 @@ SvgExport::visitVDocument( VDocument& document )
 	SvgGraphicsContext *gc = new SvgGraphicsContext;
 	m_gc.push( gc );
 
+	QWMatrix mat;
+	mat.scale( 1, -1 );
+	mat.translate( 0, -document.height() );
+
+	m_trans = new VTransformCmd( 0L, mat, false );
+	
 	// export layers:
 	VVisitor::visitVDocument( document );
 
+	delete m_trans;
+	m_trans = 0L;
+
 	// end tag:
-	*m_body << "</g>" << endl;
+	printIndentation( m_defs, --m_indent2 );
 	*m_defs << "</defs>" << endl;
 	*m_body << "</svg>" << endl;
 }
@@ -159,8 +178,10 @@ SvgExport::getID( VObject *obj )
 void
 SvgExport::visitVGroup( VGroup& group )
 {
+	printIndentation( m_body, m_indent++ );
 	*m_body << "<g" << getID( &group ) << ">" << endl;
 	VVisitor::visitVGroup( group );
+	printIndentation( m_body, --m_indent );
 	*m_body << "</g>" << endl;
 }
 
@@ -169,6 +190,7 @@ SvgExport::visitVGroup( VGroup& group )
 void
 SvgExport::visitVImage( VImage& image )
 {
+	printIndentation( m_body, m_indent );
 	*m_body << "<image ";
 	VVisitor::visitVImage( image );
 	*m_body << "x=\"" << "\" ";
@@ -182,34 +204,49 @@ SvgExport::visitVImage( VImage& image )
 void
 SvgExport::visitVLayer( VLayer& layer )
 {
+	printIndentation( m_body, m_indent++ );
 	*m_body << "<g" << getID( &layer ) << ">" << endl;
+	//*m_body << " transform=\"scale(1, -1) translate(0, -" << layer.document()->height() << ")\">" << endl;
 	VVisitor::visitVLayer( layer );
+	printIndentation( m_body, --m_indent );
 	*m_body << "</g>" << endl;
 }
 
+void
+SvgExport::writePathToStream( VPath &composite, const QString &id, QTextStream *stream, unsigned int indent )
+{
+	if( ! stream )
+		return;
+
+	printIndentation( stream, indent );
+	*stream << "<path" << id;
+
+	VVisitor::visitVPath( composite );
+
+	getFill( *( composite.fill() ), stream );
+	getStroke( *( composite.stroke() ), stream );
+
+	QString d;
+	composite.saveSvgPath( d );
+	*stream << " d=\"" << d << "\" ";
+
+	if( composite.fillRule() != m_gc.current()->fillRule )
+	{
+		if( composite.fillRule() == evenOdd )
+			*stream << " fill-rule=\"evenodd\"";
+		else
+			*stream << " fill-rule=\"nonzero\"";
+	}
+
+	*stream << " />" << endl;
+}
+
 void
 SvgExport::visitVPath( VPath& composite )
 {
-	*m_body << "<path" << getID( &composite );
-
-	VVisitor::visitVPath( composite );
-
-	getFill( *( composite.fill() ) );
-	getStroke( *( composite.stroke() ) );
-
-	QString d;
-	composite.saveSvgPath( d );
-	*m_body << " d=\"" << d << "\" ";
-
-	if( composite.fillRule() != m_gc.current()->fillRule )
-	{
-		if( composite.fillRule() == evenOdd )
-			*m_body << " fill-rule=\"evenodd\"";
-		else
-			*m_body << " fill-rule=\"nonzero\"";
-	}
-
-	*m_body << " />" << endl;
+	m_trans->visitVPath( composite );
+	writePathToStream( composite, getID( &composite ), m_body, m_indent );
+	m_trans->visitVPath( composite );
 }
 
 void
@@ -227,13 +264,16 @@ QString createUID()
 void
 SvgExport::getColorStops( const QPtrVector<VColorStop> &colorStops )
 {
+	m_indent2++;
 	for( unsigned int i = 0; i < colorStops.count() ; i++ )
 	{
+		printIndentation( m_defs, m_indent2 );
 		*m_defs << "<stop stop-color=\"";
 		getHexColor( m_defs, colorStops.at( i )->color );
 		*m_defs << "\" offset=\"" << QString().setNum( colorStops.at( i )->rampPoint );
 		*m_defs << "\" stop-opacity=\"" << colorStops.at( i )->color.opacity() << "\"" << " />" << endl;
 	}
+	m_indent2--;
 }
 
 void
@@ -242,6 +282,7 @@ SvgExport::getGradient( const VGradient& grad )
 	QString uid = createUID();
 	if( grad.type() == VGradient::linear )
 	{
+		printIndentation( m_defs, m_indent2 );
 		// do linear grad
 		*m_defs << "<linearGradient id=\"" << uid << "\" ";
 		*m_defs << "gradientUnits=\"userSpaceOnUse\" ";
@@ -258,12 +299,14 @@ SvgExport::getGradient( const VGradient& grad )
 		// color stops
 		getColorStops( grad.colorStops() );
 
+		printIndentation( m_defs, m_indent2 );
 		*m_defs << "</linearGradient>" << endl;
 		*m_body << "url(#" << uid << ")";
 	}
 	else if( grad.type() == VGradient::radial )
 	{
 		// do radial grad
+		printIndentation( m_defs, m_indent2 );
 		*m_defs << "<radialGradient id=\"" << uid << "\" ";
 		*m_defs << "gradientUnits=\"userSpaceOnUse\" ";
 		*m_defs << "cx=\"" << grad.origin().x() << "\" ";
@@ -281,6 +324,7 @@ SvgExport::getGradient( const VGradient& grad )
 		// color stops
 		getColorStops( grad.colorStops() );
 
+		printIndentation( m_defs, m_indent2 );
 		*m_defs << "</radialGradient>" << endl;
 		*m_body << "url(#" << uid << ")";
 	}
@@ -289,6 +333,7 @@ SvgExport::getGradient( const VGradient& grad )
 	{
 		// fake conical grad as radial.  
 		// fugly but better than data loss.  
+		printIndentation( m_defs, m_indent2 );
 		*m_defs << "<radialGradient id=\"" << uid << "\" ";
 		*m_defs << "gradientUnits=\"userSpaceOnUse\" ";
 		*m_defs << "cx=\"" << grad.origin().x() << "\" ";
@@ -306,6 +351,7 @@ SvgExport::getGradient( const VGradient& grad )
 		// color stops
 		getColorStops( grad.colorStops() );
 
+		printIndentation( m_defs, m_indent2 );
 		*m_defs << "</radialGradient>" << endl;
 		*m_body << "url(#" << uid << ")";
 	}
@@ -313,9 +359,10 @@ SvgExport::getGradient( const VGradient& grad )
 
 // better than nothing
 void
-SvgExport::getPattern( const VPattern & patt )
+SvgExport::getPattern( const VPattern & )
 {
 	QString uid = createUID();
+	printIndentation( m_defs, m_indent2 );
 	*m_defs << "<pattern id=\"" << uid << "\" ";
 	*m_defs << "width=\"" << "\" ";
 	*m_defs << "height=\"" << "\" ";
@@ -323,84 +370,85 @@ SvgExport::getPattern( const VPattern & patt )
 	*m_defs << "patternContentUnits=\"userSpaceOnUse\" "; 
 	*m_defs << " />" << endl;
 	// TODO: insert hard work here ;)
+	printIndentation( m_defs, m_indent2 );
 	*m_defs << "</pattern>" << endl;
 	*m_body << "url(#" << uid << ")";
 }
 
 void
-SvgExport::getFill( const VFill& fill )
+SvgExport::getFill( const VFill& fill, QTextStream *stream )
 {
-	*m_body << " fill=\"";
+	*stream << " fill=\"";
 	if( fill.type() == VFill::none )
-		*m_body << "none";
+		*stream << "none";
 	else if( fill.type() == VFill::grad )
 		getGradient( fill.gradient() );
 	else if( fill.type() == VFill::patt )
 		getPattern( fill.pattern() );
 	else
-		getHexColor( m_body, fill.color() );
-	*m_body << "\"";
+		getHexColor( stream, fill.color() );
+	*stream << "\"";
 
 	if( fill.color().opacity() != m_gc.current()->fill.color().opacity() )
-		*m_body << " fill-opacity=\"" << fill.color().opacity() << "\"";
+		*stream << " fill-opacity=\"" << fill.color().opacity() << "\"";
 }
 
 void
-SvgExport::getStroke( const VStroke& stroke )
+SvgExport::getStroke( const VStroke& stroke, QTextStream *stream )
 {
 	if( stroke.type() != m_gc.current()->stroke.type() )
 	{
-		*m_body << " stroke=\"";
+		*stream << " stroke=\"";
 		if( stroke.type() == VStroke::none )
-			*m_body << "none";
+			*stream << "none";
 		else if( stroke.type() == VStroke::grad )
 			getGradient( stroke.gradient() );
 		else
-			getHexColor( m_body, stroke.color() );
-		*m_body << "\"";
+			getHexColor( stream, stroke.color() );
+		*stream << "\"";
 	}
 
 	if( stroke.color().opacity() != m_gc.current()->stroke.color().opacity() )
-		*m_body << " stroke-opacity=\"" << stroke.color().opacity() << "\"";
+		*stream << " stroke-opacity=\"" << stroke.color().opacity() << "\"";
 
 	if( stroke.lineWidth() != m_gc.current()->stroke.lineWidth() )
-		*m_body << " stroke-width=\"" << stroke.lineWidth() << "\"";
+		*stream << " stroke-width=\"" << stroke.lineWidth() << "\"";
 
 	if( stroke.lineCap() != m_gc.current()->stroke.lineCap() )
 	{
 		if( stroke.lineCap() == VStroke::capButt )
-			*m_body << " stroke-linecap=\"butt\"";
+			*stream << " stroke-linecap=\"butt\"";
 		else if( stroke.lineCap() == VStroke::capRound )
-			*m_body << " stroke-linecap=\"round\"";
+			*stream << " stroke-linecap=\"round\"";
 		else if( stroke.lineCap() == VStroke::capSquare )
-			*m_body << " stroke-linecap=\"square\"";
+			*stream << " stroke-linecap=\"square\"";
 	}
 
 	if( stroke.lineJoin() != m_gc.current()->stroke.lineJoin() )
 	{
 		if( stroke.lineJoin() == VStroke::joinMiter )
 		{
-			*m_body << " stroke-linejoin=\"miter\"";
-			*m_body << " stroke-miterlimit=\"" << stroke.miterLimit() << "\"";
+			*stream << " stroke-linejoin=\"miter\"";
+			*stream << " stroke-miterlimit=\"" << stroke.miterLimit() << "\"";
 		}
 		else if( stroke.lineJoin() == VStroke::joinRound )
-			*m_body << " stroke-linejoin=\"round\"";
+			*stream << " stroke-linejoin=\"round\"";
 		else if( stroke.lineJoin() == VStroke::joinBevel )
-				*m_body << " stroke-linejoin=\"bevel\"";
+				*stream << " stroke-linejoin=\"bevel\"";
 	}
 
 	// dash
 	if( stroke.dashPattern().array().count() > 0 )
 	{
-		*m_body << " stroke-dashoffset=\"" << stroke.dashPattern().offset() << "\"";
-		*m_body << " stroke-dasharray=\" ";
+		*stream << " stroke-dashoffset=\"" << stroke.dashPattern().offset() << "\"";
+		*stream << " stroke-dasharray=\" ";
 
 		QValueListConstIterator<float> itr;
 		for(itr = stroke.dashPattern().array().begin(); itr != stroke.dashPattern().array().end(); ++itr )
 		{
-			*m_body << *itr << " ";
+			*stream << *itr << " ";
 		}
-		*m_body << "\"";
+		*stream << "\"";
 	}
 }
 
@@ -420,57 +468,44 @@ SvgExport::getHexColor( QTextStream *stream, const VColor& color )
 }
 
 void
-SvgExport::visitVText( VText& /*text*/ )
+SvgExport::visitVText( VText& text )
 {
-/*
-	// TODO: set placement once karbon supports it
+	VPath path( 0L );
+	path.combinePath( text.basePath() );
 
-	*m_body << "<text";
+	m_trans->visitVPath( path );
 
-	if( !node.attribute( "size" ).isNull() )
-	{
-		*m_body << " font-size=\"" << node.attribute( "size" ) << "\"";
-	}
+	QString id = createUID();
+	writePathToStream( path, " id=\""+ id + "\"", m_defs, m_indent2 );
 
-	if( !node.attribute( "family" ).isNull() )
-	{
-		*m_body << " font-family=\"" << node.attribute( "family" ) << "\"";
-	}
+	printIndentation( m_body, m_indent++ );
+	*m_body << "<text" << getID( &text );
+	//*m_body << " transform=\"scale(1, -1) translate(0, -" << text.document()->height() << ")\"";
+	getFill( *( text.fill() ), m_body );
+	getStroke( *( text.stroke() ), m_body );
 
-	if( !node.attribute( "bold" ).isNull() )
-	{
+	*m_body << " font-family=\"" << text.font().family() << "\"";
+	*m_body << " font-size=\"" << text.font().pointSize() << "\"";
+	if( text.font().bold() )
 		*m_body << " font-weight=\"bold\"";
-	}
-
-	if( !node.attribute( "italic" ).isNull() )
-	{
+	if( text.font().italic() )
 		*m_body << " font-style=\"italic\"";
-	}
-
-	QDomNodeList list = node.childNodes();
-	for( uint i = 0; i < list.count(); ++i )
-	{
-		if( list.item( i ).isElement() )
-		{
-			QDomElement e = list.item( i ).toElement();
-
-			if( e.tagName() == "FILL" )
-				exportFill( s, e );
-			if( e.tagName() == "STROKE" )
-				exportStroke( s, e );
-		}
-	}
+	if( text.alignment() == VText::Center )
+		*m_body << " text-anchor=\"middle\"";
+	else if( text.alignment() == VText::Right )
+		*m_body << " text-anchor=\"end\"";
 
+	*m_body << ">" << endl;
+	
+	printIndentation( m_body, m_indent );
+	*m_body << "<textPath xlink:href=\"#" << id << "\"";
+	if( text.offset() > 0.0 )
+		*m_body << " startOffset=\"" << text.offset() * 100.0 << "%\"";	
 	*m_body << ">";
-
-
-	if( !node.attribute( "text" ).isNull() )
-	{
-		*m_body << node.attribute( "text" );
-	}
-
+	*m_body << text.text();
+	*m_body << "</textPath>" << endl;
+	printIndentation( m_body, --m_indent );
 	*m_body << "</text>" << endl;
-*/
 }
 
 #include "svgexport.moc"
