@@ -13,14 +13,14 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __SVGEXPORT_H__
 #define __SVGEXPORT_H__
 
-#include <koFilter.h>
+#include <KoFilter.h>
 
 #include "vvisitor.h"
 #include "vgradient.h"
@@ -40,6 +40,7 @@ class VLayer;
 class VSubpath;
 class VStroke;
 class VText;
+class VTransformCmd;
 
 
 class SvgExport : public KoFilter, private VVisitor
@@ -61,19 +62,26 @@ private:
 	virtual void visitVSubpath( VSubpath& path );
 	virtual void visitVText( VText& text );
 
-	void getStroke( const VStroke& stroke );
+	void getStroke( const VStroke& stroke, QTextStream *stream );
 	void getColorStops( const QPtrVector<VColorStop> &colorStops );
-	void getFill( const VFill& fill  );
+	void getFill( const VFill& fill, QTextStream *stream );
 	void getGradient( const VGradient& grad );
 	void getPattern( const VPattern& patt );
 	void getHexColor( QTextStream *, const VColor& color  );
 	QString getID( VObject *obj );
 
+	void writePathToStream( VPath &composite, const QString &id, QTextStream *stream, unsigned int indent );
+
 	QTextStream* m_stream;
 	QTextStream* m_defs;
 	QTextStream* m_body;
 
 	QPtrStack<SvgGraphicsContext>	m_gc;
+
+	unsigned int m_indent;
+	unsigned int m_indent2;
+
+	VTransformCmd *m_trans;
 };
 
 #endif
