@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "ooimpressimport.h"
@@ -31,16 +31,16 @@
 #include <kzip.h>
 #include <karchive.h>
 #include <kdebug.h>
-#include <koUnit.h>
-#include <koDocumentInfo.h>
-#include <koDocument.h>
+#include <KoUnit.h>
+#include <KoDocumentInfo.h>
+#include <KoDocument.h>
 
 #include <kgenericfactory.h>
-#include <koFilterChain.h>
-#include <koGlobal.h>
+#include <KoFilterChain.h>
+#include <KoGlobal.h>
 #include <ooutils.h>
-#include <kodom.h>
-#include <koOasisSettings.h>
+#include <KoDom.h>
+#include <KoOasisSettings.h>
 
 typedef KGenericFactory<OoImpressImport, KoFilter> OoImpressImportFactory;
 K_EXPORT_COMPONENT_FACTORY( libooimpressimport, OoImpressImportFactory( "kofficefilters" ) )
@@ -1550,10 +1550,10 @@ void OoImpressImport::applyListStyle( QDomElement& paragraph )
     // Spec: see 3.3.5 p137
     if ( m_listStyleStack.hasListStyle() && m_nextItemIsListItem ) {
         //const QDomElement listStyle = m_listStyleStack.currentListStyle();
-        bool heading = paragraph.localName() == "h";
+        //bool heading = paragraph.localName() == "h";
         m_nextItemIsListItem = false;
-        int level = heading ? paragraph.attributeNS( ooNS::text, "level", QString::null ).toInt()
-                    : m_listStyleStack.level();
+        /*int level = heading ? paragraph.attributeNS( ooNS::text, "level", QString::null ).toInt()
+                    : m_listStyleStack.level();*/
 
         QDomElement counter = paragraph.ownerDocument().createElement( "COUNTER" );
         counter.setAttribute( "numberingtype", 0 );
@@ -1648,7 +1648,7 @@ QDomElement OoImpressImport::parseParagraph( QDomDocument& doc, const QDomElemen
     fillStyleStack( paragraph );
 
     // Style name
-    QString styleName = m_styleStack.userStyleName();
+    QString styleName = m_styleStack.userStyleName("paragraph");
     if ( !styleName.isEmpty() )
     {
         QDomElement nameElem = doc.createElement("NAME");
@@ -2323,7 +2323,7 @@ void OoImpressImport::createPresentationAnimation(const QDomElement& element)
 
 QDomElement OoImpressImport::findAnimationByObjectID(const QString & id,  int & order)
 {
-    //kdDebug(30518)<<"QDomElement OoImpressImport::findAnimationByObjectID(const QString & id) :"<<id<<endl;
+    kdDebug(30518)<<"QDomElement OoImpressImport::findAnimationByObjectID(const QString & id) :"<<id<<endl;
     if (m_animations.isEmpty() )
         return QDomElement();
 
@@ -2335,7 +2335,7 @@ QDomElement OoImpressImport::findAnimationByObjectID(const QString & id,  int &
     {
         QDomElement e = node.toElement();
         order = animation->order;
-        //kdDebug(30518)<<"e.tagName() :"<<e.tagName()<<" e.attribute(draw:shape-id) :"<<e.attributeNS( ooNS::draw, "shape-id", QString::null)<<endl;
+        kdDebug(30518)<<"e.tagName() :"<<e.tagName()<<" e.attribute(draw:shape-id) :"<<e.attributeNS( ooNS::draw, "shape-id", QString::null)<<endl;
         if (e.tagName()=="presentation:show-shape" && e.attributeNS( ooNS::draw, "shape-id", QString::null)==id)
                 return e;
     }
