@@ -25,6 +25,9 @@
 #include <qfile.h>
 
 #include <kapplication.h>
+#include <kmessagebox.h>
+#include <klocale.h>
+
 #include <KoDocumentInfo.h>
 
 #include <kio/netaccess.h>
@@ -59,7 +62,7 @@ namespace {
             return alpha ? PNG_COLOR_TYPE_RGB_ALPHA : PNG_COLOR_TYPE_RGB;
         }
 
-        kdDebug(41008) << "Cannot export images in " + cs->id().name() + " yet.\n";
+        KMessageBox::error(0, i18n("The selected image format does not support the colorspace of the image (%1)\nPlease choose another format or convert to a different colorspace").arg(cs->id().name()) ) ;
         return -1;
 
     }
