@@ -1,6 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 1999 David Faure <faure@kde.org>
-
+   Copyright (C) 2004 Nicolas GOUTTE <goutte@kde.org>
+   
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
@@ -13,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <dialogui.h>
@@ -30,11 +31,14 @@
 #include <qbuttongroup.h>
 #include <qpushbutton.h>
 #include <qradiobutton.h>
+#include <qtextcodec.h>
 
 #include <kapplication.h>
 #include <kdebug.h>
 #include <klocale.h>
+#include <kcombobox.h>
 #include <kmessagebox.h>
+#include <kcharsets.h>
 
 CSVDialog::CSVDialog(QWidget* parent, QByteArray& fileArray, const QString /*seperator*/)
     : KDialogBase(parent, 0, true, QString::null, Ok|Cancel, No, true),
@@ -48,34 +52,59 @@ CSVDialog::CSVDialog(QWidget* parent, QByteArray& fileArray, const QString /*sep
       m_delimiter(","),
       m_ignoreDups(false),
       m_fileArray(fileArray),
-      m_dialog(new DialogUI(this))
+      m_dialog(new DialogUI(this)),
+      m_codec( QTextCodec::codecForName( "UTF-8" ) )
 {
     setCaption( i18n( "Import" ) );
     kapp->restoreOverrideCursor();
 
+    QStringList encodings;
+    encodings << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).arg( "UTF-8" );
+    encodings << i18n( "Descriptive encoding name", "Locale ( %1 )" ).arg( QTextCodec::codecForLocale()->name() );
+    encodings += KGlobal::charsets()->descriptiveEncodingNames();
+    // Add a few non-standard encodings, which might be useful for text files
+    const QString description(i18n("Descriptive encoding name","Other ( %1 )"));
+    encodings << description.arg("Apple Roman"); // Apple
+    encodings << description.arg("IBM 850") << description.arg("IBM 866"); // MS DOS
+    encodings << description.arg("CP 1258"); // Windows
+    m_dialog->comboBoxEncoding->insertStringList(encodings);
+
+    m_formatList << i18n( "Text" );
+    m_formatList << i18n( "Number" );
+    m_formatList << i18n( "Currency" );
+    m_formatList << i18n( "Date" );
+    m_formatList << i18n( "Decimal Comma Number" );
+    m_formatList << i18n( "Decimal Point Number" );
+    m_dialog->m_formatComboBox->insertStringList( m_formatList );
+
+    m_dialog->m_sheet->setReadOnly( true );
+
     fillTable();
 
-    resize(sizeHint());
+    //resize(sizeHint());
+    resize( 600, 400 ); // Try to show as much as possible of the table view
     setMainWidget(m_dialog);
 
-    m_dialog->m_table->setSelectionMode(QTable::NoSelection);
+    m_dialog->m_sheet->setSelectionMode( QTable::Multi );
 
-    connect(m_dialog->m_formatBox, SIGNAL(clicked(int)),
-            this, SLOT(formatClicked(int)));
+    connect(m_dialog->m_formatComboBox, SIGNAL(activated( const QString& )),
+            this, SLOT(formatChanged( const QString& )));
     connect(m_dialog->m_delimiterBox, SIGNAL(clicked(int)),
             this, SLOT(delimiterClicked(int)));
     connect(m_dialog->m_delimiterEdit, SIGNAL(returnPressed()),
             this, SLOT(returnPressed()));
     connect(m_dialog->m_delimiterEdit, SIGNAL(textChanged ( const QString & )),
-            this, SLOT(textChanged ( const QString & ) ));
+            this, SLOT(formatChanged ( const QString & ) ));
     connect(m_dialog->m_comboQuote, SIGNAL(activated(const QString &)),
             this, SLOT(textquoteSelected(const QString &)));
-    connect(m_dialog->m_table, SIGNAL(currentChanged(int, int)),
+    connect(m_dialog->m_sheet, SIGNAL(currentChanged(int, int)),
             this, SLOT(currentCellChanged(int, int)));
     connect(m_dialog->m_ignoreDuplicates, SIGNAL(stateChanged(int)),
             this, SLOT(ignoreDuplicatesChanged(int)));
     connect(m_dialog->m_updateButton, SIGNAL(clicked()),
             this, SLOT(updateClicked()));
+    connect(m_dialog->comboBoxEncoding, SIGNAL(textChanged ( const QString & )),
+            this, SLOT(encodingChanged ( const QString & ) ));
 }
 
 CSVDialog::~CSVDialog()
@@ -91,25 +120,48 @@ void CSVDialog::fillTable( )
            S_MAYBE_NORMAL_FIELD, S_NORMAL_FIELD } state = S_START;
 
     QChar x;
-    QString field = "";
+    QString field;
 
     kapp->setOverrideCursor(Qt::waitCursor);
 
-    for (row = 0; row < m_dialog->m_table->numRows(); ++row)
-        for (column = 0; column < m_dialog->m_table->numCols(); ++column)
-            m_dialog->m_table->clearCell(row, column);
+    for (row = 0; row < m_dialog->m_sheet->numRows(); ++row)
+        for (column = 0; column < m_dialog->m_sheet->numCols(); ++column)
+            m_dialog->m_sheet->clearCell(row, column);
 
     int maxColumn = 1;
     row = column = 1;
     QTextStream inputStream(m_fileArray, IO_ReadOnly);
-    inputStream.setEncoding(QTextStream::Locale);
+    kdDebug(30501) << "Encoding: " << m_codec->name() << endl;
+    inputStream.setCodec( m_codec );
 
+    bool lastCharWasCr = false; // Last character was a Carriage Return
     while (!inputStream.atEnd()) 
     {
         inputStream >> x; // read one char
 
-        if (x == '\r') 
-            inputStream >> x; // eat '\r', to handle DOS/LOSEDOWS files correctly
+        // ### TODO: we should perhaps skip all other control characters
+        if ( x == '\r' )
+        {
+            // We have a Carriage Return, assume that its role is the one of a LineFeed
+            lastCharWasCr = true;
+            x = '\n'; // Replace by Line Feed
+        }
+        else if ( x == '\n' && lastCharWasCr )
+        {
+            // The end of line was already handled by the Carriage Return, so do nothing for this character
+            lastCharWasCr = false;
+            continue;
+        }
+        else if ( x == QChar( 0xc ) )
+        {
+            // We have a FormFeed, skip it
+            lastCharWasCr = false;
+            continue;
+        }
+        else
+        {
+            lastCharWasCr = false;
+        }
 
         if ( column > maxColumn )
           maxColumn = column;
@@ -145,18 +197,6 @@ void CSVDialog::fillTable( )
             {
                 state = S_MAYBE_END_OF_QUOTED_FIELD;
             }
-            else if (x == '\n')
-            {
-                setText(row - m_startRow, column - m_startCol, field);
-                field = "";
-
-                ++row;
-                column = 1;
-                if ( row > ( m_endRow - m_startRow ) && m_endRow >= 0 )
-                  break;
-
-                state = S_START;
-            }
             else
             {
                 field += x;
@@ -171,7 +211,7 @@ void CSVDialog::fillTable( )
             else if (x == m_delimiter || x == '\n')
             {
                 setText(row - m_startRow, column - m_startCol, field);
-                field = "";
+                field = QString::null;
                 if (x == '\n')
                 {
                     ++row;
@@ -196,7 +236,7 @@ void CSVDialog::fillTable( )
             if (x == m_delimiter || x == '\n')
             {
                 setText(row - m_startRow, column - m_startCol, field);
-                field = "";
+                field = QString::null;
                 if (x == '\n')
                 {
                     ++row;
@@ -212,15 +252,11 @@ void CSVDialog::fillTable( )
                 }
                 state = S_START;
             }
-            else
-            {
-                state = S_END_OF_QUOTED_FIELD;
-            }
             break;
          case S_MAYBE_NORMAL_FIELD :
             if (x == m_textquote)
             {
-                field = "";
+                field = QString::null;
                 state = S_QUOTED_FIELD;
                 break;
             }
@@ -228,7 +264,7 @@ void CSVDialog::fillTable( )
             if (x == m_delimiter || x == '\n')
             {
                 setText(row - m_startRow, column - m_startCol, field);
-                field = "";
+                field = QString::null;
                 if (x == '\n')
                 {
                     ++row;
@@ -253,12 +289,12 @@ void CSVDialog::fillTable( )
           lastCharDelimiter = false;
     }
 
-    // file with only one line without '\n'
-    if (field.length() > 0)
+    if ( !field.isEmpty() )
     {
+      // the last line of the file had not any line end
       setText(row - m_startRow, column - m_startCol, field);
       ++row;
-      field = "";
+      field = QString::null;
     }
     
     m_adjustCols = true;
@@ -269,14 +305,13 @@ void CSVDialog::fillTable( )
       m_dialog->m_colEnd->setValue( maxColumn );
     
 
-    for (column = 0; column < m_dialog->m_table->numCols(); ++column)
+    for (column = 0; column < m_dialog->m_sheet->numCols(); ++column)
     {
-        QString header = m_dialog->m_table->horizontalHeader()->label(column);
-        if (header != i18n("Text") && header != i18n("Number") &&
-            header != i18n("Date") && header != i18n("Currency"))
-            m_dialog->m_table->horizontalHeader()->setLabel(column, i18n("Text"));
+        const QString header = m_dialog->m_sheet->horizontalHeader()->label(column);
+        if ( m_formatList.find( header ) == m_formatList.end() )
+            m_dialog->m_sheet->horizontalHeader()->setLabel(column, i18n("Text"));
 
-        m_dialog->m_table->adjustColumn(column);
+        m_dialog->m_sheet->adjustColumn(column);
     }
     fillComboBox();
 
@@ -286,29 +321,29 @@ void CSVDialog::fillTable( )
 void CSVDialog::fillComboBox()
 {
   if ( m_endRow == -1 )
-    m_dialog->m_rowEnd->setValue( m_dialog->m_table->numRows() );  
+    m_dialog->m_rowEnd->setValue( m_dialog->m_sheet->numRows() );  
   else
     m_dialog->m_rowEnd->setValue( m_endRow );
 
   if ( m_endCol == -1 )
-    m_dialog->m_colEnd->setValue( m_dialog->m_table->numCols() );
+    m_dialog->m_colEnd->setValue( m_dialog->m_sheet->numCols() );
   else
     m_dialog->m_colEnd->setValue( m_endCol );  
 
   m_dialog->m_rowEnd->setMinValue( 1 );
   m_dialog->m_colEnd->setMinValue( 1 );
-  m_dialog->m_rowEnd->setMaxValue( m_dialog->m_table->numRows() );
-  m_dialog->m_colEnd->setMaxValue( m_dialog->m_table->numCols() );
+  m_dialog->m_rowEnd->setMaxValue( m_dialog->m_sheet->numRows() );
+  m_dialog->m_colEnd->setMaxValue( m_dialog->m_sheet->numCols() );
 
   m_dialog->m_rowStart->setMinValue( 1 );
   m_dialog->m_colStart->setMinValue( 1 );
-  m_dialog->m_rowStart->setMaxValue( m_dialog->m_table->numRows() );
-  m_dialog->m_colStart->setMaxValue( m_dialog->m_table->numCols() );
+  m_dialog->m_rowStart->setMaxValue( m_dialog->m_sheet->numRows() );
+  m_dialog->m_colStart->setMaxValue( m_dialog->m_sheet->numCols() );
 }
 
 int CSVDialog::getRows()
 {
-  int rows = m_dialog->m_table->numRows();
+  int rows = m_dialog->m_sheet->numRows();
   if ( m_endRow >= 0 )
   {
     if ( rows > ( m_startRow + m_endRow ) )
@@ -320,7 +355,7 @@ int CSVDialog::getRows()
 
 int CSVDialog::getCols()
 {
-  int cols = m_dialog->m_table->numCols();
+  int cols = m_dialog->m_sheet->numCols();
   if ( m_endCol >= 0 )
   {
     if ( cols > ( m_startCol + m_endCol ) )
@@ -332,21 +367,27 @@ int CSVDialog::getCols()
 
 int CSVDialog::getHeader(int col)
 {
-    QString header = m_dialog->m_table->horizontalHeader()->label(col);
-
+    QString header = m_dialog->m_sheet->horizontalHeader()->label(col);
+    
     if (header == i18n("Text"))
         return TEXT;
     else if (header == i18n("Number"))
         return NUMBER;
     else if (header == i18n("Currency"))
         return CURRENCY;
-    else
+    else if ( header == i18n( "Date" ) )
         return DATE;
+    else if ( header == i18n( "Decimal Comma Number" ) )
+        return COMMANUMBER;
+    else if ( header == i18n( "Decimal Point Number" ) )
+        return POINTNUMBER;
+    else
+        return TEXT; // Should not happen
 }
 
 QString CSVDialog::getText(int row, int col)
 {
-    return m_dialog->m_table->text( row, col );
+    return m_dialog->m_sheet->text( row, col );
 }
 
 void CSVDialog::setText(int row, int col, const QString& text)
@@ -357,19 +398,19 @@ void CSVDialog::setText(int row, int col, const QString& text)
     if ( ( row > ( m_endRow - m_startRow ) && m_endRow > 0 ) || ( col > ( m_endCol - m_startCol ) && m_endCol > 0 ) )
       return;
 
-    if ( m_dialog->m_table->numRows() < row ) 
+    if ( m_dialog->m_sheet->numRows() < row ) 
     {
-        m_dialog->m_table->setNumRows( row + 5000 ); /* We add 5000 at a time to limit recalculations */
+        m_dialog->m_sheet->setNumRows( row + 5000 ); /* We add 5000 at a time to limit recalculations */
         m_adjustRows = true;
     }
 
-    if ( m_dialog->m_table->numCols() < col )
+    if ( m_dialog->m_sheet->numCols() < col )
     {
-        m_dialog->m_table->setNumCols( col );
+        m_dialog->m_sheet->setNumCols( col );
         m_adjustCols = true;
     }
 
-    m_dialog->m_table->setText( row - 1, col - 1, text );
+    m_dialog->m_sheet->setText( row - 1, col - 1, text );
 }
 
 /*
@@ -379,7 +420,7 @@ void CSVDialog::adjustRows(int iRows)
 {
     if (m_adjustRows) 
     {
-        m_dialog->m_table->setNumRows( iRows );
+        m_dialog->m_sheet->setNumRows( iRows );
         m_adjustRows = false;
     }
 }
@@ -388,7 +429,7 @@ void CSVDialog::adjustCols(int iCols)
 {
     if (m_adjustCols) 
     {  
-        m_dialog->m_table->setNumCols( iCols );
+        m_dialog->m_sheet->setNumCols( iCols );
         m_adjustCols = false;
 
         if ( m_endCol == -1 )
@@ -396,7 +437,7 @@ void CSVDialog::adjustCols(int iCols)
           if ( iCols > ( m_endCol - m_startCol ) )
             iCols = m_endCol - m_startCol;
 
-          m_dialog->m_table->setNumCols( iCols );
+          m_dialog->m_sheet->setNumCols( iCols );
         }
     }
 }
@@ -416,27 +457,18 @@ void CSVDialog::textChanged ( const QString & )
     delimiterClicked(4); // other
 }
 
-void CSVDialog::formatClicked(int id)
+void CSVDialog::formatChanged( const QString& newValue )
 {
-    QString header;
-
-    switch (id)
+    //kdDebug(30501) << "CSVDialog::formatChanged:" << newValue << endl;
+    for ( int i = 0; i < m_dialog->m_sheet->numSelections(); ++i )
     {
-    case 1: // text
-        header = i18n("Text");
-        break;
-    case 0: // number
-        header = i18n("Number");
-        break;
-    case 2: // date
-        header = i18n("Date");
-        break;
-    case 3: // currency
-        header = i18n("Currency");
-        break;
+        QTableSelection select ( m_dialog->m_sheet->selection( i ) );
+        for ( int j = select.leftCol(); j <= select.rightCol() ; ++j )
+        {
+            m_dialog->m_sheet->horizontalHeader()->setLabel( j, newValue );
+            
+        }
     }
-
-    m_dialog->m_table->horizontalHeader()->setLabel(m_dialog->m_table->currentColumn(), header);
 }
 
 void CSVDialog::delimiterClicked(int id)
@@ -501,19 +533,8 @@ bool CSVDialog::checkUpdateRange()
 
 void CSVDialog::currentCellChanged(int, int col)
 {
-    int id;
-    QString header = m_dialog->m_table->horizontalHeader()->label(col);
-
-    if (header == i18n("Text"))
-        id = 1;
-    else if (header == i18n("Number"))
-        id = 0;
-    else if (header == i18n("Date"))
-        id = 3;
-    else
-        id = 2;
-
-    m_dialog->m_formatBox->setButton(id);
+    const QString header = m_dialog->m_sheet->horizontalHeader()->label(col);
+    m_dialog->m_formatComboBox->setCurrentText( header );
 }
 
 void CSVDialog::ignoreDuplicatesChanged(int)
@@ -525,4 +546,47 @@ void CSVDialog::ignoreDuplicatesChanged(int)
   fillTable();
 }
 
+QTextCodec* CSVDialog::getCodec(void) const
+{
+    const QString strCodec( KGlobal::charsets()->encodingForName( m_dialog->comboBoxEncoding->currentText() ) );
+    kdDebug(30502) << "Encoding: " << strCodec << endl;
+
+    bool ok = false;
+    QTextCodec* codec = QTextCodec::codecForName( strCodec.utf8() );
+
+    // If QTextCodec has not found a valid encoding, so try with KCharsets.
+    if ( codec )
+    {
+        ok = true;
+    }
+    else
+    {
+        codec = KGlobal::charsets()->codecForName( strCodec, ok );
+    }
+
+    // Still nothing?
+    if ( !codec || !ok )
+    {
+        // Default: UTF-8
+        kdWarning(30502) << "Cannot find encoding:" << strCodec << endl;
+        // ### TODO: what parent to use?
+        KMessageBox::error( 0, i18n("Cannot find encoding: %1").arg( strCodec ) );
+        return 0;
+    }
+
+    return codec;
+}
+
+void CSVDialog::encodingChanged ( const QString & )
+{
+    QTextCodec* codec = getCodec();
+
+    if ( codec )
+    {
+        m_codec = codec;
+        fillTable();
+    }
+}
+
+
 #include <csvdialog.moc>
