@@ -1,7 +1,7 @@
-// -*- c-basic-offset: 2 -*-
 /*
  *  This file is part of the KDE libraries
  *  Copyright (C) 1999-2000 Harri Porten (porten@kde.org)
+ *  Copyright (C) 2006 Ariya Hidayat (ariya@kde.org)
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -16,202 +16,25 @@
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
  *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ *  Boston, MA 02110-1301, USA.
  */
 
 #include "ustring.h"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-
-#define USTRING_SIMPLIFIED
-
-#ifdef USTRING_SIMPLIFIED
 #include <string.h>
 #include <ctype.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
-#endif
 
-
-#ifndef USTRING_SIMPLIFIED
-
-#include <stdlib.h>
-#include <stdio.h>
-#include <ctype.h>
-#ifdef HAVE_STRING_H
-#include <string.h>
+#ifdef _MSC_VER
+#define snprintf _snprintf
 #endif
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-
-#ifdef HAVE_MATH_H
-#include <math.h>
-#endif
-#ifdef HAVE_FLOAT_H
-#include <float.h>
-#endif
-#ifdef HAVE_IEEEFP_H
-#include <ieeefp.h>
-#endif
-
-#endif
-
-namespace Swinder {
-#ifdef WORDS_BIGENDIAN
-  unsigned char NaN_Bytes[] = { 0x7f, 0xf8, 0, 0, 0, 0, 0, 0 };
-  unsigned char Inf_Bytes[] = { 0x7f, 0xf0, 0, 0, 0, 0, 0, 0 };
-#elif defined(arm)
-  unsigned char NaN_Bytes[] = { 0, 0, 0xf8, 0x7f, 0, 0, 0, 0 };
-  unsigned char Inf_Bytes[] = { 0, 0, 0xf0, 0x7f, 0, 0, 0, 0 };
-#else
-  unsigned char NaN_Bytes[] = { 0, 0, 0, 0, 0, 0, 0xf8, 0x7f };
-  unsigned char Inf_Bytes[] = { 0, 0, 0, 0, 0, 0, 0xf0, 0x7f };
-#endif
-
-  const double NaN = *( reinterpret_cast<const double*>( NaN_Bytes ) );
-  const double Inf = *( reinterpret_cast<const double*>( Inf_Bytes ) );
-}
 
 using namespace Swinder;
 
-#ifdef USTRING_SIMPLIFIED
-bool Swinder::isNaN(double)
-{
-  return false;
-}
-#else
-bool Swinder::isNaN(double d)
-{
-#ifdef HAVE_FUNC_ISNAN
-  return isnan(d);
-#elif defined HAVE_FLOAT_H
-  return _isnan(d) != 0;
-#else
-  return !(d == d);
-#endif
-}
-#endif
-
-#ifdef USTRING_SIMPLIFIED
-bool Swinder::isPosInf(double)
-{
-  return false;
-}
-#else
-bool Swinder::isPosInf(double d)
-{
-#if defined(HAVE_FUNC_ISINF)
-  return (isinf(d) == 1);
-#elif HAVE_FUNC_FINITE
-  return finite(d) == 0 && d == d; // ### can we distinguish between + and - ?
-#elif HAVE_FUNC__FINITE
-  return _finite(d) == 0 && d == d; // ###
-#else
-  return false;
-#endif
-}
-#endif
-
-#ifdef USTRING_SIMPLIFIED
-bool Swinder::isNegInf(double)
-{
-  return false;
-}
-#else
-bool Swinder::isNegInf(double d)
-{
-#if defined(HAVE_FUNC_ISINF)
-  return (isinf(d) == -1);
-#elif HAVE_FUNC_FINITE
-  return finite(d) == 0 && d == d; // ###
-#elif HAVE_FUNC__FINITE
-  return _finite(d) == 0 && d == d; // ###
-#else
-  return false;
-#endif
-}
-#endif
-
-CString::CString(const char *c)
-{
-  data = new char[strlen(c)+1];
-  strcpy(data, c);
-}
-
-CString::CString(const CString &b)
-{
-  data = new char[b.length()+1];
-  strcpy(data, b.c_str());
-}
-
-CString::~CString()
-{
-  delete [] data;
-}
-
-CString &CString::append(const CString &t)
-{
-  char *n;
-  if (data) {
-    n = new char[strlen(data)+t.length()+1];
-    strcpy(n, data);
-  } else {
-    n = new char[t.length()+1];
-    n[0] = '\0';
-  }
-  strcat(n, t.c_str());
-
-  delete [] data;
-  data = n;
-
-  return *this;
-}
-
-CString &CString::operator=(const char *c)
-{
-  if (data)
-    delete [] data;
-  data = new char[strlen(c)+1];
-  strcpy(data, c);
-
-  return *this;
-}
-
-CString &CString::operator=(const CString &str)
-{
-  if (this == &str)
-    return *this;
-
-  if (data)
-    delete [] data;
-  data = new char[str.length()+1];
-  strcpy(data, str.c_str());
-
-  return *this;
-}
-
-CString &CString::operator+=(const CString &str)
-{
-  return append(CString(str.c_str()));
-}
-
-int CString::length() const
-{
-  return strlen(data);
-}
-
-bool Swinder::operator==(const Swinder::CString& c1, const Swinder::CString& c2)
-{
-  return (strcmp(c1.c_str(), c2.c_str()) == 0);
-}
-
 UChar UChar::null;
-UString::Rep UString::Rep::null = { 0, 0, 1 };
+UString::Rep UString::Rep::null = { 0, 0, 1, 0 };
 UString UString::null;
 static char *statBuffer = 0L;
 
@@ -220,23 +43,6 @@ UChar::UChar(const UCharReference &c)
 {
 }
 
-UChar UChar::toLower() const
-{
-  // ### properly support unicode tolower
-  if (uc >= 256 || islower(uc))
-    return *this;
-
-  return UChar(tolower(uc));
-}
-
-UChar UChar::toUpper() const
-{
-  if (uc >= 256 || isupper(uc))
-    return *this;
-
-  return UChar(toupper(uc));
-}
-
 UCharReference& UCharReference::operator=(UChar c)
 {
   str->detach();
@@ -251,7 +57,10 @@ UChar& UCharReference::ref() const
   if (offset < str->rep->len)
     return *(str->rep->dat + offset);
   else
-    return UChar::null;
+  {
+    static UChar nullRef('\0');
+    return nullRef;
+  }
 }
 
 namespace {
@@ -263,11 +72,24 @@ namespace {
   }
 }
 
+
 UString::Rep *UString::Rep::create(UChar *d, int l)
 {
   Rep *r = new Rep;
   r->dat = d;
   r->len = l;
+  r->cap = l;
+  r->rc = 1;
+
+  return r;
+}
+
+UString::Rep *UString::Rep::create(UChar *d, int l, int c)
+{
+  Rep *r = new Rep;
+  r->dat = d;
+  r->len = l;
+  r->cap = c;
   r->rc = 1;
 
   return r;
@@ -322,67 +144,268 @@ UString::UString(const UString &b)
   attach(b.rep);
 }
 
+// NOTE: this is private, be careful when using it !
+UString::UString(Rep *r): rep(r)
+{
+}
+
+
 UString::~UString()
 {
   release();
 }
 
-UString UString::from(int i)
+UString UString::number(int i)
 {
-  char buf[40];
-  sprintf(buf, "%d", i);
-
+#if 0
+  // standard and safe way
+  char buf[1+sizeof(int)*3];
+  snprintf(buf, sizeof(int)*3, "%d", i);
+  buf[sizeof(int)*3] = '\0';
   return UString(buf);
-}
-
-UString UString::from(unsigned int u)
-{
-  char buf[40];
-  sprintf(buf, "%u", u);
-
-  return UString(buf);
-}
-
-UString UString::from(double d)
-{
-  char buf[40];
-
-  if (d == -0)
-    strcpy(buf,"0");
-  else if (isNaN(d))
-    strcpy(buf,"NaN");
-  else if (isPosInf(d))
-    strcpy(buf,"Infinity");
-  else if (isNegInf(d))
-    strcpy(buf,"-Infinity");
-  else
-    sprintf(buf, "%.16g", d);	// does the right thing
-
-  // ECMA 3rd ed. 9.8.1 9 e: "with no leading zeros"
-  int buflen = strlen(buf);
-  if (buflen >= 4 && buf[buflen-4] == 'e' && buf[buflen-2] == '0') {
-    buf[buflen-2] = buf[buflen-1];
-    buf[buflen-1] = 0;
+#else
+  // micro-optimized version
+  static unsigned short digits[] = 
+    { '9', '8', '7', '6', '5', '4', '3', '2', '1', 
+      '0', '1', '2', '3', '4', '5', '6', '7', '8', '9' };
+      
+  UString::Rep* rep = 0;
+      
+  if(i == 0)
+  {
+    UChar* buf = allocateChars(1);
+    buf[0] = '0';
+    rep = Rep::create(buf, 1);
   }
+  else
+  {
+    bool neg = (i < 0);
+    int ndig = 1 + sizeof(int)*3;
 
+    UChar* buf = allocateChars(ndig);
+    UChar* ptr = buf + ndig - 1;
+    int len = (neg) ? 1 : 0;
+
+    // construct all the digits
+    for(; i != 0; i/=10, len++) 
+      *ptr-- = digits[9+i%10];
+
+    if(neg) 
+      *ptr-- = '-';  
+  
+    // shift, don't use memcpy because overlapping area
+    memmove(buf, ptr+1, len*sizeof(unsigned short));
+    
+    rep = Rep::create(buf, len, ndig);
+  }
+  
+  return UString(rep);
+#endif
+}
+
+UString UString::number(unsigned int u)
+{
+#if 0
+  // standard and safe way
+  char buf[1+sizeof(unsigned int)*3];
+  snprintf(buf, sizeof(unsigned int)*3, "%d", u);
+  buf[sizeof(int)*3] = '\0';
   return UString(buf);
+#else
+  // micro-optimized version
+  static unsigned short digits[] = 
+    { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9' };
+
+  UString::Rep* rep = 0;
+      
+  if(u < 10)
+  {
+    UChar* buf = allocateChars(1);
+    buf[0] = digits[u];
+    rep = Rep::create(buf, 1);
+  }
+  else
+  {
+    int ndig = 1 + sizeof(int)*3;
+    UChar* buf = allocateChars(ndig);
+    UChar* ptr = buf + ndig - 1;
+    int len = 0;
+
+    // construct all the digits
+    for(; u != 0; u/=10, len++) 
+      *ptr-- = digits[u%10];
+  
+    // shift, don't use memcpy because overlapping area
+    memmove(buf, ptr+1, len*sizeof(unsigned short));
+    
+    rep = Rep::create(buf, len, ndig);
+  }
+  
+  return UString(rep);
+#endif
+}
+
+UString UString::number(double d)
+{
+  char buf[40];
+  snprintf(buf, 39, "%.16g", d);
+  buf[sizeof(int)*3] = '\0';
+  return UString(buf);
+}
+
+void UString::truncate(int n)
+{
+  if((n >= 0) && (n < length()))
+  {
+    detach();
+    rep->len = n;
+  }
+}
+
+void UString::reserve(int r)
+{
+  if(r > length())
+  {
+    int l = length();
+    UChar* n = allocateChars( r );
+    memcpy(n, data(), l * sizeof(UChar));
+    release();
+    rep = Rep::create(n, l, r); 
+  }
 }
 
 UString &UString::append(const UString &t)
 {
-  int l = length();
-  UChar *n = allocateChars( l+t.length() );
-  memcpy(n, data(), l * sizeof(UChar));
-  memcpy(n+l, t.data(), t.length() * sizeof(UChar));
-  release();
-  rep = Rep::create(n, l + t.length());
+  int tl = t.length();
+  if(tl > 0)
+  {
+    detach();
+    int l = length();
+    
+    // no space, we have to reallocate first
+    if(capacity() < tl + l)
+      reserve(tl +l);
+      
+    UChar *dd = rep->data();
+    memcpy(dd+l, t.data(), tl * sizeof(UChar));
+    rep->len += tl;
+  }
 
   return *this;
 }
 
-CString UString::cstring() const
+UString &UString::append(const char* s)
 {
-  return CString(ascii());
+  int tl = strlen(s);
+  if(tl > 0)
+  {
+    detach();
+    int l = length();
+    
+    // no space, we have to reallocate first
+    if(capacity() < tl + l)
+      reserve(tl +l);
+
+    // copy each character        
+    UChar *dd = rep->data();
+    for (int i = 0; i < tl; i++)
+      dd[l+i].uc = static_cast<unsigned char>( s[i] );
+    rep->len += tl;
+  }
+
+  return *this;
+}
+
+UString &UString::append(UChar c)
+{
+  detach();
+  int l = length();
+  
+  // we need to reallocate
+  // in case another append follows, so let's reserve()
+  // this avoids subsequent expensive reallocation
+  if(capacity() < l + 1)
+    reserve(l + 8);
+  
+  UChar *dd = rep->data();
+  dd[l] = c;
+  rep->len++;
+
+  return *this;
+}
+
+UString &UString::append(char c)
+{
+  return append( UChar((unsigned short)c) );
+}
+
+
+UString &UString::prepend(const UString &t)
+{
+  int tl = t.length();
+  if(tl > 0)
+  {
+    int l = length();
+    
+    // no space, we have to reallocate first
+    if(capacity() < tl + l)
+      reserve(tl +l);
+
+    // shift the string, then place the new string      
+    UChar *dd = rep->data();
+    for(int i = l-1; i >= 0; i--)
+      dd[i+tl] = dd[i];
+    memcpy(dd, t.data(), tl * sizeof(UChar));
+    rep->len += tl;
+  }
+
+  return *this;
+}
+
+UString &UString::prepend(const char* s)
+{
+  int tl = strlen(s);
+  if(tl > 0)
+  {
+    int l = length();
+    
+    // no space, we have to reallocate first
+    if(capacity() < tl + l)
+      reserve(tl +l);
+
+    // shift the string, then copy each new character        
+    UChar *dd = rep->data();
+    for(int i = l-1; i >= 0; i--)
+      dd[i+tl] = dd[i];
+    for(int j = 0; j < tl; j++)
+      dd[j].uc = static_cast<unsigned char>( s[j] );
+    rep->len += tl;
+  }
+
+  return *this;
+}
+
+UString &UString::prepend(UChar c)
+{
+  int l = length();
+  
+  // we need to reallocate and reserve
+  // see also append(UChar c) function
+  if(capacity() < l + 1)
+    reserve(l + 8);
+  
+  UChar *dd = rep->data();
+  for(int i = l-1; i >= 0; i--)
+    dd[i+1] = dd[i];
+  dd[0] = c;
+  rep->len++;
+
+  return *this;
+}
+
+UString &UString::prepend(char c)
+{
+  return prepend( UChar((unsigned short)c) );
 }
 
 char *UString::ascii() const
@@ -448,114 +471,6 @@ UCharReference UString::operator[](int pos)
   return UCharReference(this, pos);
 }
 
-double UString::toDouble( bool tolerant ) const
-{
-  double d;
-
-  if (!is8Bit())
-    return NaN;
-
-  CString str = cstring();
-  const char *c = str.c_str();
-
-  // skip leading white space
-  while (isspace(*c))
-    c++;
-
-  // empty string ?
-  if (*c == '\0')
-    return tolerant ? NaN : 0.0;
-
-  // hex number ?
-  if (*c == '0' && (*(c+1) == 'x' || *(c+1) == 'X')) {
-    c++;
-    d = 0.0;
-    while (*(++c)) {
-      if (*c >= '0' && *c <= '9')
-	d = d * 16.0 + *c - '0';
-      else if ((*c >= 'A' && *c <= 'F') || (*c >= 'a' && *c <= 'f'))
-	d = d * 16.0 + (*c & 0xdf) - 'A' + 10.0;
-      else
-	break;
-    }
-  } else {
-    // regular number ?
-    char *end;
-    d = strtod(c, &end);
-    if ((d != 0.0 || end != c) && d != HUGE_VAL && d != -HUGE_VAL) {
-      c = end;
-    } else {
-      // infinity ?
-      d = 1.0;
-      if (*c == '+')
-	c++;
-      else if (*c == '-') {
-	d = -1.0;
-	c++;
-      }
-      if (strncmp(c, "Infinity", 8) != 0)
-	return NaN;
-      d = d * Inf;
-      c += 8;
-    }
-  }
-
-  // allow trailing white space
-  while (isspace(*c))
-    c++;
-  // don't allow anything after - unless tolerant=true
-  if ( !tolerant && *c != '\0')
-    d = NaN;
-
-  return d;
-}
-
-unsigned long UString::toULong(bool *ok) const
-{
-  double d = toDouble();
-  bool b = true;
-
-  if (isNaN(d) || d != static_cast<unsigned long>(d)) {
-    b = false;
-    d = 0;
-  }
-
-  if (ok)
-    *ok = b;
-
-  return static_cast<unsigned long>(d);
-}
-
-int UString::find(const UString &f, int pos) const
-{
-  if (isNull())
-    return -1;
-  long fsize = f.length() * sizeof(UChar);
-  if (pos < 0)
-    pos = 0;
-  const UChar *end = data() + length() - f.length();
-  for (const UChar *c = data() + pos; c <= end; c++)
-    if (!memcmp(c, f.data(), fsize))
-      return (c-data());
-
-  return -1;
-}
-
-int UString::rfind(const UString &f, int pos) const
-{
-  if (isNull())
-    return -1;
-  if (pos + f.length() >= length())
-    pos = length() - f.length();
-  long fsize = f.length() * sizeof(UChar);
-  for (const UChar *c = data() + pos; c >= data(); c--) {
-    if (!memcmp(c, f.data(), fsize))
-      return (c-data());
-  }
-
-  return -1;
-}
-
 UString UString::substr(int pos, int len) const
 {
   if (isNull())
@@ -577,6 +492,21 @@ UString UString::substr(int pos, int len) const
   return result;
 }
 
+int UString::find(const UString &f, int pos) const
+{
+  if (isNull())
+    return -1;
+  long fsize = f.length() * sizeof(UChar);
+  if (pos < 0)
+    pos = 0;
+  const UChar *end = data() + length() - f.length();
+  for (const UChar *c = data() + pos; c <= end; c++)
+    if (!memcmp(c, f.data(), fsize))
+      return (c-data());
+
+  return -1;
+}
+
 void UString::attach(Rep *r)
 {
   rep = r;
@@ -585,18 +515,21 @@ void UString::attach(Rep *r)
 
 void UString::detach()
 {
-  if (rep->rc > 1) {
+  if (rep->rc > 1) 
+  {
+    int c = capacity();
     int l = length();
-    UChar *n = allocateChars( l );
+    UChar *n = allocateChars( c );
     memcpy(n, data(), l * sizeof(UChar));
     release();
-    rep = Rep::create(n, l);
+    rep = Rep::create(n, l, c);
   }
 }
 
 void UString::release()
 {
-  if (!rep->deref()) {
+  if (!rep->deref()) 
+  {
     delete [] rep->dat;
     delete rep;
   }
@@ -613,14 +546,15 @@ bool Swinder::operator==(const UString& s1, const UString& s2)
 
 bool Swinder::operator==(const UString& s1, const char *s2)
 {
-  if (s2 == 0L && s1.isNull())
-    return true;
+  if (s2 == 0L)
+    return s1.isEmpty();
 
   if (s1.length() != static_cast<int>( strlen(s2) ))
     return false;
 
   const UChar *u = s1.data();
-  while (*s2) {
+  while (*s2) 
+  {
     if (u->uc != *s2 )
       return false;
     s2++;
@@ -638,7 +572,8 @@ bool Swinder::operator<(const UString& s1, const UString& s2)
   const UChar *c1 = s1.data();
   const UChar *c2 = s2.data();
   int l = 0;
-  while (l < lmin && *c1 == *c2) {
+  while (l < lmin && *c1 == *c2) 
+  {
     c1++;
     c2++;
     l++;
@@ -658,7 +593,8 @@ UString Swinder::operator+(const UString& s1, const UString& s2)
 }
 
 
-UConstString::UConstString( UChar* data, unsigned int length ) : UString( data, length, false )
+UConstString::UConstString( UChar* data, unsigned int length ) : 
+UString( data, length, false )
 {
 }
 
