@@ -1,7 +1,5 @@
-// $Header: /home/kde/koffice/filters/kword/abiword/abiwordimport.cc,v 1.76 2002/07/24 20:36:57 goutte Exp $
-
 /* This file is part of the KDE project
-   Copyright (C) 2001, 2002 Nicolas GOUTTE <nicog@snafu.de>
+   Copyright 2001, 2002, 2003, 2004 Nicolas GOUTTE <goutte@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -15,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -30,15 +28,17 @@
 #include <qpicture.h>
 #include <qxml.h>
 #include <qdom.h>
+#include <qdatetime.h>
 
 #include <kdebug.h>
 #include <kmdcodec.h>
 #include <kfilterdev.h>
 #include <kgenericfactory.h>
+#include <kmessagebox.h>
 
-#include <koGlobal.h>
-#include <koStore.h>
-#include <koFilterChain.h>
+#include <KoPageLayout.h>
+#include <KoStore.h>
+#include <KoFilterChain.h>
 
 #include "ImportHelpers.h"
 #include "ImportFormatting.h"
@@ -47,8 +47,19 @@
 
 #include "abiwordimport.h"
 
-typedef KGenericFactory<ABIWORDImport, KoFilter> ABIWORDImportFactory;
-K_EXPORT_COMPONENT_FACTORY( libabiwordimport, ABIWORDImportFactory( "kwordabiwordimport" ) );
+class ABIWORDImportFactory : KGenericFactory<ABIWORDImport, KoFilter>
+{
+public:
+    ABIWORDImportFactory(void) : KGenericFactory<ABIWORDImport, KoFilter> ("kwordabiwordimport")
+    {}
+protected:
+    virtual void setupTranslations( void )
+    {
+        KGlobal::locale()->insertCatalogue( "kofficefilters" );
+    }
+};
+
+K_EXPORT_COMPONENT_FACTORY( libabiwordimport, ABIWORDImportFactory() )
 
 // *Note for the reader of this code*
 // Tags in lower case (e.g. <c>) are AbiWord's ones.
@@ -59,15 +70,16 @@ K_EXPORT_COMPONENT_FACTORY( libabiwordimport, ABIWORDImportFactory( "kwordabiwor
 class StructureParser : public QXmlDefaultHandler
 {
 public:
-    StructureParser(QDomDocument& doc, KoFilterChain* chain)
-        : mainDocument("DOC"), m_chain(chain), m_pictureNumber(0), m_pictureFrameNumber(0)
+    StructureParser(KoFilterChain* chain)
+        :  m_chain(chain), m_pictureNumber(0), m_pictureFrameNumber(0), m_tableGroupNumber(0),
+        m_timepoint(QDateTime::currentDateTime(Qt::UTC)), m_fatalerror(false)
     {
         createDocument();
-        doc=mainDocument;
         structureStack.setAutoDelete(true);
         StackItem *stackItem=new(StackItem);
         stackItem->elementType=ElementTypeBottom;
-        stackItem->stackElementText=mainFramesetElement;
+        stackItem->m_frameset=mainFramesetElement; // The default frame set.
+        stackItem->stackElementText=mainFramesetElement; // This is more for DEBUG
         structureStack.push(stackItem); //Security item (not to empty the stack)
     }
     virtual ~StructureParser()
@@ -80,6 +92,13 @@ public:
     virtual bool startElement( const QString&, const QString&, const QString& name, const QXmlAttributes& attributes);
     virtual bool endElement( const QString&, const QString& , const QString& qName);
     virtual bool characters ( const QString & ch );
+    virtual bool warning(const QXmlParseException& exception);
+    virtual bool error(const QXmlParseException& exception);
+    virtual bool fatalError(const QXmlParseException& exception);
+public:
+    inline QDomDocument getDocInfo(void) const { return m_info; }
+    inline QDomDocument getDocument(void) const { return mainDocument; }
+    inline bool wasFatalError(void) const { return m_fatalerror; }
 protected:
     bool clearStackUntilParagraph(StackItemStack& auxilaryStack);
     bool complexForcedPageBreak(StackItem* stackItem);
@@ -92,13 +111,20 @@ private:
     bool StartElementImage(StackItem* stackItem, StackItem* stackCurrent,
         const QXmlAttributes& attributes);
     bool EndElementD (StackItem* stackItem);
+    bool EndElementM (StackItem* stackItem);
     bool StartElementSection(StackItem* stackItem, StackItem* stackCurrent,
         const QXmlAttributes& attributes);
+    bool StartElementFoot(StackItem* stackItem, StackItem* stackCurrent,
+        const QXmlAttributes& attributes);
+    bool StartElementTable(StackItem* stackItem, StackItem* stackCurrent, const QXmlAttributes& attributes);
+    bool StartElementCell(StackItem* stackItem, StackItem* stackCurrent,const QXmlAttributes& attributes);
 private:
     void createDocument(void);
+    void createDocInfo(void);
     QString indent; //DEBUG
     StackItemStack structureStack;
     QDomDocument mainDocument;
+    QDomDocument m_info;
     QDomElement framesetsPluralElement; // <FRAMESETS>
     QDomElement mainFramesetElement;    // The main <FRAMESET> where the body text will be under.
     QDomElement m_picturesElement;      // <PICTURES>
@@ -109,6 +135,10 @@ private:
     KoFilterChain* m_chain;
     uint m_pictureNumber;                   // unique: increment *before* use
     uint m_pictureFrameNumber;              // unique: increment *before* use
+    uint m_tableGroupNumber;                // unique: increment *before* use
+    QMap<QString,QString> m_metadataMap;    // Map for <m> elements
+    QDateTime m_timepoint;              // Date/time (for pictures)
+    bool m_fatalerror;                  // Did a XML parsing fatal error happened?
 };
 
 // Element <c>
@@ -116,7 +146,7 @@ private:
 bool StructureParser::StartElementC(StackItem* stackItem, StackItem* stackCurrent, const QXmlAttributes& attributes)
 {
     // <c> elements can be nested in <p> elements, in <a> elements or in other <c> elements
-    // AbiWord does not nest <c> elements in other <c> elements, but explicitely allows external programs to do it!
+    // AbiWord does not nest <c> elements in other <c> elements, but explicitly allows external programs to do it!
 
     // <p> or <c> (not child of <a>)
     if ((stackCurrent->elementType==ElementTypeParagraph)||(stackCurrent->elementType==ElementTypeContent))
@@ -291,7 +321,7 @@ static bool EndElementA (StackItem* stackItem, StackItem* stackCurrent, QDomDocu
 // Element <p>
 
 bool StartElementP(StackItem* stackItem, StackItem* stackCurrent,
-    QDomDocument& mainDocument, QDomElement& mainFramesetElement,
+    QDomDocument& mainDocument,
     StyleDataMap& styleDataMap, const QXmlAttributes& attributes)
 {
     // We must prepare the style
@@ -316,9 +346,9 @@ bool StartElementP(StackItem* stackItem, StackItem* stackCurrent,
     }
 
     QDomElement elementText=stackCurrent->stackElementText;
-    //We use mainFramesetElement here not to be dependant that <section> has happened before
     QDomElement paragraphElementOut=mainDocument.createElement("PARAGRAPH");
-    mainFramesetElement.appendChild(paragraphElementOut);
+    stackCurrent->m_frameset.appendChild(paragraphElementOut);
+
     QDomElement textElementOut=mainDocument.createElement("TEXT");
     paragraphElementOut.appendChild(textElementOut);
     QDomElement formatsPluralElementOut=mainDocument.createElement("FORMATS");
@@ -381,7 +411,7 @@ static bool StartElementField(StackItem* stackItem, StackItem* stackCurrent,
         // We create a format element
         QDomElement variableElement=mainDocument.createElement("VARIABLE");
 
-        if (!ProcessField(mainDocument, variableElement, strType))
+        if (!ProcessField(mainDocument, variableElement, strType, attributes))
         {
             // The field type was not recognised,
             //   therefore write the field type in red as normal text
@@ -497,13 +527,12 @@ bool StructureParser::StartElementImage(StackItem* stackItem, StackItem* stackCu
         kdDebug(30506) << "Image: " << strDataId << endl;
     }
 
-    QString strPictureFrameName("Picture ");
-    strPictureFrameName+=QString::number(++m_pictureFrameNumber);
+    QString strPictureFrameName(i18n("Frameset name","Picture %1").arg(++m_pictureFrameNumber));
 
     // Create the frame set of the image
 
     QDomElement framesetElement=mainDocument.createElement("FRAMESET");
-    framesetElement.setAttribute("frameType",-1); // -1 will be replaced when processing <d>
+    framesetElement.setAttribute("frameType",2);
     framesetElement.setAttribute("frameInfo",0);
     framesetElement.setAttribute("visible",1);
     framesetElement.setAttribute("name",strPictureFrameName);
@@ -519,20 +548,19 @@ bool StructureParser::StartElementImage(StackItem* stackItem, StackItem* stackCu
     framesetElement.appendChild(frameElementOut);
 
     QDomElement element=mainDocument.createElement("PICTURE");
-    element.setAttribute("keepAspectRatio","true"); // Cliparts will be always false in KWord 1.2
+    element.setAttribute("keepAspectRatio","true");
     framesetElement.setAttribute("frameType",2); // Picture
     framesetElement.appendChild(element);
 
     QDomElement key=mainDocument.createElement("KEY");
     key.setAttribute("filename",strDataId);
-    //As we have no date to set, set to the *nix epoch
-    key.setAttribute("year",1970);
-    key.setAttribute("month",1);
-    key.setAttribute("day",1);
-    key.setAttribute("hour",0);
-    key.setAttribute("minute",0);
-    key.setAttribute("second",0);
-    key.setAttribute("msec",0);
+    key.setAttribute("year",m_timepoint.date().year());
+    key.setAttribute("month",m_timepoint.date().month());
+    key.setAttribute("day",m_timepoint.date().day());
+    key.setAttribute("hour",m_timepoint.time().hour());
+    key.setAttribute("minute",m_timepoint.time().minute());
+    key.setAttribute("second",m_timepoint.time().second());
+    key.setAttribute("msec",m_timepoint.time().msec());
     element.appendChild(key);
 
     // Now use the image's frame set
@@ -623,7 +651,7 @@ bool StructureParser::EndElementD (StackItem* stackItem)
     {
         extension=".png";
     }
-    else if (stackItem->strTemp1=="image/jpeg")
+    else if (stackItem->strTemp1=="image/jpeg") // ### FIXME: in fact it does not exist in AbiWord
     {
         extension=".jpeg";
     }
@@ -647,21 +675,20 @@ bool StructureParser::EndElementD (StackItem* stackItem)
     QString strDataId=stackItem->fontName;  // AbiWord's data id
     QDomElement key=mainDocument.createElement("KEY");
     key.setAttribute("filename",strDataId);
-    //As we have no date to set, set to the *nix epoch
-    key.setAttribute("year",1970);
-    key.setAttribute("month",1);
-    key.setAttribute("day",1);
-    key.setAttribute("hour",0);
-    key.setAttribute("minute",0);
-    key.setAttribute("second",0);
-    key.setAttribute("msec",0);
+    key.setAttribute("year",m_timepoint.date().year());
+    key.setAttribute("month",m_timepoint.date().month());
+    key.setAttribute("day",m_timepoint.date().day());
+    key.setAttribute("hour",m_timepoint.time().hour());
+    key.setAttribute("minute",m_timepoint.time().minute());
+    key.setAttribute("second",m_timepoint.time().second());
+    key.setAttribute("msec",m_timepoint.time().msec());
     key.setAttribute("name",strStoreName);
     m_picturesElement.appendChild(key);
 
     KoStoreDevice* out=m_chain->storageFile(strStoreName, KoStore::Write);
     if(!out)
     {
-        kdError(30506) << "Unable to open output file for: " << stackItem->fontName << endl;
+        kdError(30506) << "Unable to open output file for: " << stackItem->fontName << " Storage: " << strStoreName << endl;
         return false;
     }
 
@@ -687,6 +714,56 @@ bool StructureParser::EndElementD (StackItem* stackItem)
     return true;
 }
 
+// <m>
+static bool StartElementM(StackItem* stackItem, StackItem* /*stackCurrent*/,
+    const QXmlAttributes& attributes)
+{
+    // We do not assume when we are called or if we are or not a child of <metadata>
+    stackItem->elementType=ElementTypeRealMetaData;
+
+    QString strKey=attributes.value("key").stripWhiteSpace();
+    kdDebug(30506) << "Metadata key: " << strKey << endl;
+
+    if (strKey.isEmpty())
+    {
+        kdWarning(30506) << "Metadata has no key!" << endl;
+        stackItem->elementType=ElementTypeIgnore;
+        return true;
+    }
+
+    stackItem->strTemp1=strKey;        // Key
+    stackItem->strTemp2=QString::null;  // Meta data
+
+    return true;
+}
+
+static bool CharactersElementM (StackItem* stackItem, const QString & ch)
+{
+    // As we have no guarantee to have the whole data in one call, we must store the data.
+    stackItem->strTemp2+=ch;
+    return true;
+}
+
+bool StructureParser::EndElementM (StackItem* stackItem)
+{
+    if (!stackItem->elementType==ElementTypeRealData)
+    {
+        kdError(30506) << "Wrong element type!! Aborting! (in endElementM)" << endl;
+        return false;
+    }
+
+    if (stackItem->strTemp1.isEmpty())
+    {
+        // Probably an internal error!
+        kdError(30506) << "Key name was erased! Aborting! (in endElementM)" << endl;
+        return false;
+    }
+
+    // Just add it to the metadata map, we do not do something special with the values.
+    m_metadataMap[stackItem->strTemp1]=stackItem->strTemp2;
+
+    return true;
+}
 
 // <br> (forced line break)
 static bool StartElementBR(StackItem* stackItem, StackItem* stackCurrent,
@@ -727,14 +804,14 @@ static bool StartElementBR(StackItem* stackItem, StackItem* stackCurrent,
 // <cbr> (forced column break, not supported)
 // <pbr> (forced page break)
 static bool StartElementPBR(StackItem* /*stackItem*/, StackItem* stackCurrent,
-    QDomDocument& mainDocument, QDomElement& mainFramesetElement)
+    QDomDocument& mainDocument)
 {
     // We are sure to be the child of a <p> element
 
     // The following code is similar to the one in StartElementP
     // We use mainFramesetElement here not to be dependant that <section> has happened before
     QDomElement paragraphElementOut=mainDocument.createElement("PARAGRAPH");
-    mainFramesetElement.appendChild(paragraphElementOut);
+    stackCurrent->m_frameset.appendChild(paragraphElementOut);
     QDomElement textElementOut=mainDocument.createElement("TEXT");
     paragraphElementOut.appendChild(textElementOut);
     QDomElement formatsPluralElementOut=mainDocument.createElement("FORMATS");
@@ -863,7 +940,7 @@ static bool StartElementPageSize(QDomElement& paperElement, const QXmlAttributes
         kwordWidth  = MillimetresToPoints(KoPageFormat::width (kwordFormat,PG_PORTRAIT));
     }
 
-    if ((kwordHeight <= 1.0) || (kwordWidth <=1.0))
+    if ((kwordHeight <= 1.0) || (kwordWidth <= 1.0))
         // At least one of the two values is ridiculous
     {
         kdWarning(30506) << "Page width or height is too small: "
@@ -898,11 +975,14 @@ bool StructureParser::complexForcedPageBreak(StackItem* stackItem)
     StackItemStack auxilaryStack;
 
     if (!clearStackUntilParagraph(auxilaryStack))
+    {
+        kdError(30506) << "Could not clear stack until a paragraph!" << endl;
         return false;
+    }
 
     // Now we are a child of a <p> element!
 
-    bool success=StartElementPBR(stackItem,structureStack.current(),mainDocument,mainFramesetElement);
+    bool success=StartElementPBR(stackItem,structureStack.current(),mainDocument);
 
     // Now restore the stack
 
@@ -982,6 +1062,191 @@ static bool EndElementIW(StackItem* stackItem, StackItem* /*stackCurrent*/,
     return true;
 }
 
+// <foot>
+bool StructureParser::StartElementFoot(StackItem* stackItem, StackItem* /*stackCurrent*/,
+    const QXmlAttributes& /*attributes*/)
+{
+#if 0
+    stackItem->elementType=ElementTypeFoot;
+
+    const QString id(attributes.value("endnote-id").stripWhiteSpace());
+    kdDebug(30506) << "Foot note id: " << id << endl;
+
+    if (id.isEmpty())
+    {
+        kdWarning(30506) << "Footnote has no id!" << endl;
+        stackItem->elementType=ElementTypeIgnore;
+        return true;
+    }
+
+    // We need to create a frameset for the foot note.
+    QDomElement framesetElement(mainDocument.createElement("FRAMESET"));
+    framesetElement.setAttribute("frameType",1);
+    framesetElement.setAttribute("frameInfo",7);
+    framesetElement.setAttribute("visible",1);
+    framesetElement.setAttribute("name",getFootnoteFramesetName(id));
+    framesetsPluralElement.appendChild(framesetElement);
+
+    QDomElement frameElementOut(mainDocument.createElement("FRAME"));
+    //frameElementOut.setAttribute("left",28);
+    //frameElementOut.setAttribute("top",42);
+    //frameElementOut.setAttribute("bottom",566);
+    //frameElementOut.setAttribute("right",798);
+    frameElementOut.setAttribute("runaround",1);
+    // ### TODO: a few attributes are missing
+    framesetElement.appendChild(frameElementOut);
+
+    stackItem->m_frameset=framesetElement;
+#else
+    stackItem->elementType=ElementTypeIgnore;
+#endif
+    return true;
+}
+
+// Element <table>
+bool StructureParser::StartElementTable(StackItem* stackItem, StackItem* stackCurrent,
+    const QXmlAttributes& attributes)
+{
+#if 1
+    // In KWord, inline tables are inside a paragraph.
+    // In AbiWord, tables are outside any paragraph.
+
+    QStringList widthList;
+    widthList.split('/', attributes.value("table-column-props"), false);
+    const uint columns = widthList.size();
+    stackItem->m_doubleArray.detach(); // Be sure not to modify parents
+    stackItem->m_doubleArray.resize(columns+1); // All left positions but the last right one
+    stackItem->m_doubleArray[0] = 0.0;
+    QStringList::ConstIterator it;
+    uint i;
+    for ( i=0, it=widthList.begin(); i<columns; ++i, ++it )
+    {
+        kdDebug(30506) << "Column width: " << (*it) << " cooked " << ValueWithLengthUnit(*it) << endl;
+        stackItem->m_doubleArray[i+1] = ValueWithLengthUnit(*it) + stackItem->m_doubleArray[i];
+    }
+    // ### TODO: in case of automatic column widths, we have not any width given by AbiWord
+
+    const uint tableNumber(++m_tableGroupNumber);
+    const QString tableName(i18n("Table %1").arg(tableNumber));
+
+    QDomElement elementText=stackCurrent->stackElementText;
+    QDomElement paragraphElementOut=mainDocument.createElement("PARAGRAPH");
+    stackCurrent->m_frameset.appendChild(paragraphElementOut);
+
+    QDomElement textElementOut(mainDocument.createElement("TEXT"));
+    textElementOut.appendChild(mainDocument.createTextNode("#"));
+    paragraphElementOut.appendChild(textElementOut);
+
+    QDomElement formatsPluralElementOut=mainDocument.createElement("FORMATS");
+    paragraphElementOut.appendChild(formatsPluralElementOut);
+
+    QDomElement elementFormat(mainDocument.createElement("FORMAT"));
+    elementFormat.setAttribute("id",6);
+    elementFormat.setAttribute("pos",0);
+    elementFormat.setAttribute("len",1);
+    formatsPluralElementOut.appendChild(elementFormat);
+
+    QDomElement elementAnchor(mainDocument.createElement("ANCHOR"));
+    elementAnchor.setAttribute("type","frameset");
+    elementAnchor.setAttribute("instance",tableName);
+    elementFormat.appendChild(elementAnchor);
+
+    stackItem->elementType=ElementTypeTable;
+    stackItem->stackElementParagraph=paragraphElementOut; // <PARAGRAPH>
+    stackItem->stackElementText=textElementOut; // <TEXT>
+    stackItem->stackElementFormatsPlural=formatsPluralElementOut; // <FORMATS>
+    stackItem->strTemp1=tableName;
+    stackItem->strTemp2=QString::number(tableNumber); // needed as I18N does not allow adding phrases
+    stackItem->pos=1; // Just #
+
+    // Now we populate the layout
+    QDomElement layoutElement=mainDocument.createElement("LAYOUT");
+    paragraphElementOut.appendChild(layoutElement);
+
+    AbiPropsMap abiPropsMap;
+    styleDataMap.useOrCreateStyle("Normal"); // We might have to create the "Normal" style.
+    AddLayout("Normal", layoutElement, stackItem, mainDocument, abiPropsMap, 0, false);
+#else
+    stackItem->elementType=ElementTypeIgnore;
+#endif
+    return true;
+}
+
+// <cell>
+bool StructureParser::StartElementCell(StackItem* stackItem, StackItem* stackCurrent,
+    const QXmlAttributes& attributes)
+{
+#if 1
+    if (stackCurrent->elementType!=ElementTypeTable)
+    {
+        kdError(30506) << "Wrong element type!! Aborting! (in StructureParser::endElementCell)" << endl;
+        return false;
+    }
+
+    stackItem->elementType=ElementTypeCell;
+
+    const QString tableName(stackCurrent->strTemp1);
+    kdDebug(30506) << "Table name: " << tableName << endl;
+
+    if (tableName.isEmpty())
+    {
+        kdError(30506) << "Table name is empty! Aborting!" << endl;
+        return false;
+    }
+
+    AbiPropsMap abiPropsMap;
+    abiPropsMap.splitAndAddAbiProps(attributes.value("props")); // Do not check PROPS
+
+    // We abuse the attach number to know the row and col numbers.
+    const uint row=abiPropsMap["top-attach"].getValue().toUInt();
+    const uint col=abiPropsMap["left-attach"].getValue().toUInt();
+
+    if ( col >= stackItem->m_doubleArray.size() )
+    {
+        // We do not know the right position of this column, so improvise. (### TODO)
+        // We play on the fact that QByteArray uses shallow copies by default.
+        //  (We do want that the change is known at <table> level)
+        stackItem->m_doubleArray.resize( stackItem->m_doubleArray.size() + 1, QGArray::SpeedOptim );
+        stackItem->m_doubleArray[col+1] = stackItem->m_doubleArray[col] + 72; // Try 1 inch
+    }
+
+    const QString frameName(i18n("Frameset name","Table %3, row %1, column %2")
+        .arg(row).arg(col).arg(stackCurrent->strTemp2)); // As the stack could be wrong, be careful and use the string as last!
+
+    // We need to create a frameset for the cell
+    QDomElement framesetElement(mainDocument.createElement("FRAMESET"));
+    framesetElement.setAttribute("frameType",1);
+    framesetElement.setAttribute("frameInfo",0);
+    framesetElement.setAttribute("visible",1);
+    framesetElement.setAttribute("name",frameName);
+    framesetElement.setAttribute("row",row);
+    framesetElement.setAttribute("col",col);
+    framesetElement.setAttribute("rows",1); // ### TODO: rowspan
+    framesetElement.setAttribute("cols",1); // ### TODO: colspan
+    framesetElement.setAttribute("grpMgr",tableName);
+    framesetsPluralElement.appendChild(framesetElement);
+
+    QDomElement frameElementOut(mainDocument.createElement("FRAME"));
+    frameElementOut.setAttribute( "left", stackItem->m_doubleArray[col] );
+    frameElementOut.setAttribute( "right", stackItem->m_doubleArray[col+1] );
+    frameElementOut.setAttribute("top",0);
+    frameElementOut.setAttribute("bottom",0);
+    frameElementOut.setAttribute("runaround",1);
+    frameElementOut.setAttribute("autoCreateNewFrame",0); // Very important for cell growing!
+    // ### TODO: a few attributes are missing
+    framesetElement.appendChild(frameElementOut);
+
+    stackItem->m_frameset=framesetElement;
+    QDomElement nullDummy;
+    stackItem->stackElementParagraph=nullDummy; // <PARAGRAPH>
+    stackItem->stackElementText=nullDummy; // <TEXT>
+    stackItem->stackElementFormatsPlural=nullDummy; // <FORMATS>
+
+#else
+    stackItem->elementType=ElementTypeIgnore;
+#endif
+    return true;
+}
 
 // Parser for SAX2
 
@@ -1017,7 +1282,7 @@ bool StructureParser :: startElement( const QString&, const QString&, const QStr
     else if ((name=="p")||(name=="P"))
     {
         success=StartElementP(stackItem,structureStack.current(),mainDocument,
-            mainFramesetElement,styleDataMap,attributes);
+            styleDataMap,attributes);
     }
     else if ((name=="section")||(name=="SECTION"))
     {
@@ -1046,7 +1311,7 @@ bool StructureParser :: startElement( const QString&, const QString&, const QStr
         else if (stackCurrent->elementType==ElementTypeParagraph)
         {
             kdWarning(30506) << "Forced column break found! Transforming to forced page break" << endl;
-            success=StartElementPBR(stackItem,stackCurrent,mainDocument,mainFramesetElement);
+            success=StartElementPBR(stackItem,stackCurrent,mainDocument);
         }
         else
         {
@@ -1066,7 +1331,7 @@ bool StructureParser :: startElement( const QString&, const QString&, const QStr
         }
         else if (stackCurrent->elementType==ElementTypeParagraph)
         {
-            success=StartElementPBR(stackItem,stackCurrent,mainDocument,mainFramesetElement);
+            success=StartElementPBR(stackItem,stackCurrent,mainDocument);
         }
         else
         {
@@ -1105,6 +1370,22 @@ bool StructureParser :: startElement( const QString&, const QString&, const QStr
         stackItem->elementType=ElementTypeIgnoreWord;
         success=true;
     }
+    else if (name=="m") // No upper-case
+    {
+        success=StartElementM(stackItem,structureStack.current(),attributes);
+    }
+    else if (name=="foot") // No upper-case
+    {
+        success=StartElementFoot(stackItem,structureStack.current(),attributes);
+    }
+    else if (name=="table") // No upper-case
+    {
+        success=StartElementTable(stackItem,structureStack.current(), attributes);
+    }
+    else if (name=="cell") // No upper-case
+    {
+        success=StartElementCell(stackItem,structureStack.current(),attributes);
+    }
     else
     {
         stackItem->elementType=ElementTypeUnknown;
@@ -1165,6 +1446,10 @@ bool StructureParser :: endElement( const QString&, const QString& , const QStri
     {
         success=EndElementIW(stackItem,structureStack.current(), mainDocument, m_ignoreWordsElement);
     }
+    else if (name=="m") // No upper-case
+    {
+        success=EndElementM(stackItem);
+    }
     else
     {
         success=true; // No problem, so authorisation to continue parsing
@@ -1172,7 +1457,7 @@ bool StructureParser :: endElement( const QString&, const QString& , const QStri
     if (!success)
     {
         // If we have no success, then it was surely a tag mismatch. Help debugging!
-        kdDebug(30506) << "Found tag name: " << name
+        kdError(30506) << "Found tag name: " << name
             << " expected: " << stackItem->itemName << endl;
     }
     delete stackItem;
@@ -1186,6 +1471,10 @@ bool StructureParser :: characters ( const QString & ch )
     {
         kdDebug(30506) << indent << " (LINEFEED)" << endl;
     }
+    else if (ch.length()> 40)
+    {   // 40 characters are enough (especially for image data)
+        kdDebug(30506) << indent << " :" << ch.left(40) << "..." << endl;
+    }
     else
     {
         kdDebug(30506) << indent << " :" << ch << ":" << endl;
@@ -1233,6 +1522,10 @@ bool StructureParser :: characters ( const QString & ch )
         stackItem->strTemp2+=ch; // Just collect the data
         success=true;
     }
+    else if (stackItem->elementType==ElementTypeRealMetaData)
+    {
+        success=CharactersElementM(stackItem,ch);
+    }
     else
     {
         success=true;
@@ -1248,6 +1541,42 @@ bool StructureParser::startDocument(void)
     return true;
 }
 
+void StructureParser::createDocInfo(void)
+{
+    QDomImplementation implementation;
+    QDomDocument doc(implementation.createDocumentType("document-info",
+        "-//KDE//DTD document-info 1.2//EN", "http://www.koffice.org/DTD/document-info-1.2.dtd"));
+
+    m_info=doc;
+
+    m_info.appendChild(
+        mainDocument.createProcessingInstruction(
+        "xml","version=\"1.0\" encoding=\"UTF-8\""));
+
+    QDomElement elementDoc(mainDocument.createElement("document-info"));
+    elementDoc.setAttribute("xmlns","http://www.koffice.org/DTD/document-info");
+    m_info.appendChild(elementDoc);
+
+    QDomElement about(mainDocument.createElement("about"));
+    elementDoc.appendChild(about);
+
+    QDomElement abstract(mainDocument.createElement("abstract"));
+    about.appendChild(abstract);
+    abstract.appendChild(mainDocument.createTextNode(m_metadataMap["dc.description"]));
+
+    QDomElement title(mainDocument.createElement("title"));
+    about.appendChild(title);
+    title.appendChild(mainDocument.createTextNode(m_metadataMap["dc.title"]));
+
+    QDomElement keyword(mainDocument.createElement("keyword"));
+    about.appendChild(keyword);
+    keyword.appendChild(mainDocument.createTextNode(m_metadataMap["abiword.keywords"]));
+
+    QDomElement subject(mainDocument.createElement("subject"));
+    about.appendChild(subject);
+    subject.appendChild(mainDocument.createTextNode(m_metadataMap["dc.subject"]));
+}
+
 bool StructureParser::endDocument(void)
 {
     QDomElement stylesPluralElement=mainDocument.createElement("STYLES");
@@ -1256,7 +1585,7 @@ bool StructureParser::endDocument(void)
 
     kdDebug(30506) << "###### Start Style List ######" << endl;
     StyleDataMap::ConstIterator it;
-    
+
     // At first, we put the Normal style
     it=styleDataMap.find("Normal");
     if (it!=styleDataMap.end())
@@ -1269,7 +1598,7 @@ bool StructureParser::endDocument(void)
     else
         kdWarning(30506) << "No 'Normal' style" << endl;
 
-    for (it=styleDataMap.begin();it!=styleDataMap.end();it++)
+    for (it=styleDataMap.begin();it!=styleDataMap.end();++it)
     {
         if (it.key()=="Normal")
             continue;
@@ -1283,9 +1612,38 @@ bool StructureParser::endDocument(void)
     }
     kdDebug(30506) << "######  End Style List  ######" << endl;
 
+    createDocInfo();
+
     return true;
 }
 
+bool StructureParser::warning(const QXmlParseException& exception)
+{
+    kdWarning(30506) << "XML parsing warning: line " << exception.lineNumber()
+        << " col " << exception.columnNumber() << " message: " << exception.message() << endl;
+    return true;
+}
+
+bool StructureParser::error(const QXmlParseException& exception)
+{
+    // A XML error is recoverable, so it is only a KDE warning
+    kdWarning(30506) << "XML parsing error: line " << exception.lineNumber()
+        << " col " << exception.columnNumber() << " message: " << exception.message() << endl;
+    return true;
+}
+
+bool StructureParser::fatalError (const QXmlParseException& exception)
+{
+    kdError(30506) << "XML parsing fatal error: line " << exception.lineNumber()
+        << " col " << exception.columnNumber() << " message: " << exception.message() << endl;
+    m_fatalerror=true;
+    KMessageBox::error(NULL, i18n("An error has occurred while parsing the AbiWord file.\nAt line: %1, column %2\nError message: %3")
+        .arg(exception.lineNumber()).arg(exception.columnNumber())
+        .arg( i18n( "QXml", exception.message().utf8() ) ),
+        i18n("AbiWord Import Filter"),0);
+    return false; // Stop parsing now, we do not need further errors.
+}
+
 void StructureParser :: createDocument(void)
 {
     QDomImplementation implementation;
@@ -1301,9 +1659,9 @@ void StructureParser :: createDocument(void)
     QDomElement elementDoc;
     elementDoc=mainDocument.createElement("DOC");
     elementDoc.setAttribute("xmlns","http://www.koffice.org/DTD/kword");
-    elementDoc.setAttribute("editor","KWord's AbiWord Import Filter");
+    elementDoc.setAttribute("editor","AbiWord Import Filter");
     elementDoc.setAttribute("mime","application/x-kword");
-    elementDoc.setAttribute("syntaxVersion",2);
+    elementDoc.setAttribute( "syntaxVersion", 3 );
     mainDocument.appendChild(elementDoc);
 
     QDomElement element;
@@ -1312,12 +1670,12 @@ void StructureParser :: createDocument(void)
     element.setAttribute("standardpage",1);
     element.setAttribute("hasHeader",0);
     element.setAttribute("hasFooter",0);
-    element.setAttribute("unit","mm");
+    //element.setAttribute("unit","mm"); // use KWord default instead
     element.setAttribute("tabStopValue",36); // AbiWord has a default of 0.5 inch tab stops
     elementDoc.appendChild(element);
 
     // <PAPER> will be partialy changed by an AbiWord <pagesize> element.
-    // default paper format of AbiWord is "Letter"
+    // Default paper format of AbiWord is "Letter"
     m_paperElement=mainDocument.createElement("PAPER");
     m_paperElement.setAttribute("format",PG_US_LETTER);
     m_paperElement.setAttribute("width",MillimetresToPoints(KoPageFormat::width (PG_US_LETTER,PG_PORTRAIT)));
@@ -1346,7 +1704,7 @@ void StructureParser :: createDocument(void)
     mainFramesetElement.setAttribute("frameType",1);
     mainFramesetElement.setAttribute("frameInfo",0);
     mainFramesetElement.setAttribute("visible",1);
-    mainFramesetElement.setAttribute("name","Main Frameset");
+    mainFramesetElement.setAttribute("name",i18n("Frameset name","Main Text Frameset"));
     framesetsPluralElement.appendChild(mainFramesetElement);
 
     QDomElement frameElementOut=mainDocument.createElement("FRAME");
@@ -1406,12 +1764,12 @@ KoFilter::ConversionStatus ABIWORDImport::convert( const QCString& from, const Q
 
     kdDebug(30506)<<"AbiWord to KWord Import filter"<<endl;
 
-    QDomDocument documentOut;
-    StructureParser handler(documentOut,m_chain);
+    StructureParser handler(m_chain);
 
     //We arbitrarily decide that Qt can handle the encoding in which the file was written!!
     QXmlSimpleReader reader;
     reader.setContentHandler( &handler );
+    reader.setErrorHandler( &handler );
 
     //Find the last extension
     QString strExt;
@@ -1437,19 +1795,21 @@ KoFilter::ConversionStatus ABIWORDImport::convert( const QCString& from, const Q
         ||(strExt==".bzabw")||(strExt==".BZABW")) //in case of .bzabw (extension used prioritary with AbiWord)
     {
         // Compressed with bzip2
-
-        // It seems that bzip2-compressed AbiWord files were planned
-        //   but AbiWord CVS 2001-12-15 does not have export and import filters for them anymore.
-        //   We leave this code but leave the .desktop file without bzip2 files
         strMime="application/x-bzip2";
         kdDebug(30506) << "Compression: bzip2" << endl;
     }
 
     QIODevice* in = KFilterDev::deviceForFile(fileIn,strMime);
 
+    if ( !in )
+    {
+        kdError(30506) << "Cannot create device for uncompressing! Aborting!" << endl;
+        return KoFilter::FileNotFound; // ### TODO: better error?
+    }
+
     if (!in->open(IO_ReadOnly))
     {
-        kdError(30506) << "Cannot open file! Aborting!" << endl;
+        kdError(30506) << "Cannot open file for uncompressing! Aborting!" << endl;
         delete in;
         return KoFilter::FileNotFound;
     }
@@ -1461,21 +1821,45 @@ KoFilter::ConversionStatus ABIWORDImport::convert( const QCString& from, const Q
     if (!reader.parse( source ))
     {
         kdError(30506) << "Import: Parsing unsuccessful. Aborting!" << endl;
-        // TODO: try to give line and column number like the QDom parser does.
         delete in;
-        return KoFilter::StupidError;
+        if (!handler.wasFatalError())
+        {
+            // As the parsing was stopped for something else than a fatal error, we have not yet get an error message. (Can it really happen?)
+            KMessageBox::error(NULL, i18n("An error occurred during the load of the AbiWord file: %1").arg(from),
+                i18n("AbiWord Import Filter"),0);
+        }
+        return KoFilter::ParsingError;
     }
     delete in;
 
-    KoStoreDevice* out=m_chain->storageFile( "root", KoStore::Write );
+    QCString strOut;
+    KoStoreDevice* out;
+
+    kdDebug(30506) << "Creating documentinfo.xml" << endl;
+    out=m_chain->storageFile( "documentinfo.xml", KoStore::Write );
     if(!out)
     {
-        kdError(30506) << "AbiWord Import unable to open output file!" << endl;
+        kdError(30506) << "AbiWord Import unable to open output file! (Documentinfo)" << endl;
+        KMessageBox::error(NULL, i18n("Unable to save document information."),i18n("AbiWord Import Filter"),0);
+        return KoFilter::StorageCreationError;
+    }
+
+    //Write the document information!
+    strOut=handler.getDocInfo().toCString(); // UTF-8
+    // WARNING: we cannot use KoStore::write(const QByteArray&) because it writes an extra NULL character at the end.
+    out->writeBlock(strOut,strOut.length());
+
+    kdDebug(30506) << "Creating maindoc.xml" << endl;
+    out=m_chain->storageFile( "root", KoStore::Write );
+    if(!out)
+    {
+        kdError(30506) << "AbiWord Import unable to open output file! (Root)" << endl;
+        KMessageBox::error(NULL, i18n("Unable to save main document."),i18n("AbiWord Import Filter"),0);
         return KoFilter::StorageCreationError;
     }
 
     //Write the document!
-    QCString strOut=documentOut.toCString(); // UTF-8
+    strOut=handler.getDocument().toCString(); // UTF-8
     // WARNING: we cannot use KoStore::write(const QByteArray&) because it writes an extra NULL character at the end.
     out->writeBlock(strOut,strOut.length());
 
