@@ -1,5 +1,3 @@
-// $Header$
-
 /*
    This file is part of the KDE project
    Copyright (C) 2001, 2002, 2004 Nicolas GOUTTE <goutte@kde.org>
@@ -16,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef _IMPORT_DIALOG_H
