@@ -1,5 +1,3 @@
-//
-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
    Copyright (C) 2000 Michael Johnson <mikej@xnet.com>
@@ -17,8 +15,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -40,11 +38,11 @@
 #include <kglobal.h>
 #include <kgenericfactory.h>
 
-#include <koGlobal.h>
-#include <koPageLayout.h>
-#include <koStore.h>
-#include <koFilterChain.h>
-#include <koFilterManager.h>
+#include <KoGlobal.h>
+#include <KoPageLayout.h>
+#include <KoStore.h>
+#include <KoFilterChain.h>
+#include <KoFilterManager.h>
 
 #include <asciiimport.h>
 #include <asciiimport.moc>
