@@ -1,5 +1,3 @@
-// $Header: /home/kde/koffice/filters/kword/html/export/ExportCss.h,v 1.6 2003/06/19 19:43:33 zrusin Exp $
-
 /*
    This file is part of the KDE project
    Copyright (C) 2001, 2002 Nicolas GOUTTE <goutte@kde.org>
@@ -16,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef EXPORTCSS_H
@@ -41,13 +39,13 @@ public:
     HtmlCssWorker(void) { }
     virtual ~HtmlCssWorker(void) { }
 public:
-    virtual bool doOpenStyles(void); // HTML's <style>
-    virtual bool doCloseStyles(void); // HTML's </style>
+    virtual bool doOpenStyles(void); ///< HTML's \<style\>
+    virtual bool doCloseStyles(void); ///< HTML's \</style\>
     virtual bool doFullDefineStyle(LayoutData& layout);
     virtual bool doFullPaperFormat(const int format,
         const double width, const double height, const int orientation);
     virtual bool doFullPaperBorders (const double top, const double left,
-        const double bottom, const double right); // Like KWord's <PAPERBORDERS>
+        const double bottom, const double right); ///< Like KWord's \<PAPERBORDERS\>
 protected:
     virtual QString getStartOfListOpeningTag(const CounterData::Style typeList, bool& ordered);
     virtual void openParagraph(const QString& strTag, const LayoutData& layout,
