@@ -30,7 +30,7 @@
 #include <qwidget.h>
 #include <kapplication.h>
 #include <dom/html_misc.h>
-
+#include <qregexp.h>
 
 KHTMLReader::KHTMLReader(KWDWriter *w){
 	_html=new KHTMLPart();
@@ -55,6 +55,7 @@ bool KHTMLReader::filter(KURL url) {
 	_html->setJScriptEnabled(false);
 	_html->setPluginsEnabled(false);
 	_html->setJavaEnabled(false);
+	_html->setMetaRefreshEnabled(false);
 	if (_html->openURL(url) == false) {
 		kdWarning(30503) << "openURL returned false" << endl;
 		return false;
@@ -75,6 +76,7 @@ HTMLReader_state *KHTMLReader::state() {
 		s->paragraph = _writer->addParagraph(s->frameset);
 		s->format=_writer->currentFormat(s->paragraph,true);
 		s->layout=_writer->currentLayout(s->paragraph);
+		s->in_pre_mode = false;
 		_state.push(s);
 	}
 	return _state.top();
@@ -86,6 +88,7 @@ HTMLReader_state *KHTMLReader::pushNewState() {
         s->paragraph=state()->paragraph;
         s->format=state()->format;
         s->layout=state()->layout;
+	s->in_pre_mode=state()->in_pre_mode;
         _writer->cleanUpParagraph(s->paragraph);
         _state.push(s);
         return s;
@@ -161,7 +164,7 @@ void KHTMLReader::parseNode(DOM::Node node) {
         // check if this is a text node.
 	DOM::Text t=node;
 	if (!t.isNull()) {
-	   _writer->addText(state()->paragraph,t.data().string());
+	   _writer->addText(state()->paragraph,t.data().string(),1,state()->in_pre_mode);
 	   return; // no children anymore...
 	}
 
@@ -230,9 +233,10 @@ void KHTMLReader::parse_head(DOM::Element e) {
 
 
 bool KHTMLReader::parseTag(DOM::Element e) {
+	_PP(a);
 	_PP(p);
 	_PP(br);
-	// _PP(table); <- disabled for beta.
+	_PP(table);
 	_PP(pre);
 	_PP(ul);
 	_PP(ol);
@@ -256,22 +260,41 @@ bool KHTMLReader::parseTag(DOM::Element e) {
 	_PL(h4,NAME,value,h4);
 	_PL(h5,NAME,value,h5);
 	_PL(h6,NAME,value,h6);
+
+	// Don't handle the content of comment- or script-nodes.
+	if(e.nodeType() == DOM::Node::COMMENT_NODE || e.tagName().lower() == "script") {
+		return false;
+	}
+
 	return true;
 }
 
 
 
 void KHTMLReader::parseStyle(DOM::Element e) {
-#if 0  // styles are broken broken broken broken broken broken.
+  // styles are broken broken broken broken broken broken.
+  //FIXME: wait until getComputedStyle is more than
+  // 'return 0' in khtml
+  kdDebug(30503) << "entering parseStyle" << endl;
      DOM::CSSStyleDeclaration s1=e.style();
      DOM::Document doc=_html->document();
      DOM::CSSStyleDeclaration s2=doc.defaultView().getComputedStyle(e,"");
-     				//FIXME: wait until getComputedStyle is more than
-     				// 'return 0' in khtml
 
-     if (PROPV("font-weight") == "bolder")
+     kdDebug(30503) << "font-weight=" << s1.getPropertyValue("font-weight").string() << endl;
+     if ( s1.getPropertyValue("font-weight").string() == "bolder" )
+     {
 	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
-
+     }
+     if ( s1.getPropertyValue("font-weight").string() == "bold" )
+     {
+	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
+     }
+     /*if (DOM::PROPV("font-weight") == "bolder")
+	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
+     if (PROPV("font-weight") == "bold")
+	_writer->formatAttribute(state()->paragraph,"WEIGHT","value","75");
+     */
+/*
      // debugging code.
      kdDebug(30503) << "e.style()" << endl;
      for (unsigned int i=0;i<s1.length();i++) {
@@ -281,7 +304,7 @@ void KHTMLReader::parseStyle(DOM::Element e) {
      for (unsigned int i=0;i<s2.length();i++) {
         kdDebug(30503) << QString("%1: %2").arg(s2.item(i).string()).arg(s2.getPropertyValue(s2.item(i)).string()) << endl;
      }
-#endif
+*/
 }
 
 void KHTMLReader::startNewParagraph(bool startnewformat, bool startnewlayout) {
@@ -321,6 +344,7 @@ void KHTMLReader::startNewParagraph(bool startnewformat, bool startnewlayout) {
 }
 
 KHTMLReader::~KHTMLReader(){
+	delete _html;
 }
 
 
@@ -334,35 +358,67 @@ KHTMLReader::~KHTMLReader(){
 
 
 bool KHTMLReader::parse_CommonAttributes(DOM::Element e) {
+        kdDebug(30503) << "entering KHTMLReader::parse_CommonAttributes" << endl;
+        kdDebug(30503) << "tagName is " << e.tagName().string() << endl;
         QString s=e.getAttribute("align").string();
-        if (!s.isEmpty()) {
+        if (!s.isEmpty()) 
+        {
               _writer->formatAttribute(state()->paragraph,"FLOW","align",s);
         }
+        QRegExp rx( "h[0-9]+" );
+        if ( 0 == rx.search( e.getAttribute("class").string() ) )
+        // example: <p class="h1" style="text-align:left; ">
+        {
+              _writer->layoutAttribute(state()->paragraph,"NAME","value",e.getAttribute("class").string());
+        }
         return true;
 }
 
-
+bool KHTMLReader::parse_a(DOM::Element e) {
+        QString url = e.getAttribute("href").string();
+        if (!url.isEmpty()) 
+        {
+		QString linkName;
+		DOM::Text t = e.firstChild();
+		if (t.isNull()) {
+			/* Link without text -> just drop it*/
+			return false; /* stop parsing recursively */
+		}
+		linkName = t.data().string().simplifyWhiteSpace();
+		t.setData(DOM::DOMString("#")); // replace with '#'
+		_writer->createLink(state()->paragraph, linkName, url);
+        }
+	return true; /* stop parsing recursively */
+}
 
 bool KHTMLReader::parse_p(DOM::Element e) {
-	startNewParagraph();
+        // For every starting paragraph, a line break has to be inserted.
+        // exception: the first paragraph, e.g. if the <body> starts with a <p>.
+        static bool firstparagraph=true;
+        if (firstparagraph)
+        {
+          firstparagraph=false;
+        }
+        else {
+	  startNewParagraph();
+	}
 	parse_CommonAttributes(e);
-
 	return true;
 }
 
-bool KHTMLReader::parse_hr(DOM::Element e) {
+bool KHTMLReader::parse_hr(DOM::Element /*e*/) {
 	startNewParagraph();
 	_writer->createHR(state()->paragraph);
 	startNewParagraph();
 	return true;
 }
 
-bool KHTMLReader::parse_br(DOM::Element e) {
+bool KHTMLReader::parse_br(DOM::Element /*e*/) {
 	startNewParagraph(false,false); //keep the current format and layout
 	return false; // a BR tag has no childs.
 }
 
-QColor parsecolor(QString colorstring) {
+static const QColor parsecolor(const QString& colorstring) {
       QColor color;
       if (colorstring[0]=='#') {
             color.setRgb(
@@ -418,12 +474,31 @@ QColor parsecolor(QString colorstring) {
 
 
 bool KHTMLReader::parse_table(DOM::Element e) {
+	if(_writer->isInTable()) {
+		// We are already inside of a table. Tables in tables are not supported
+		// yet. So, just add that table-content as text.
+		for (DOM::Node rows=e.firstChild().firstChild();!rows.isNull();rows=rows.nextSibling())
+			if (!rows.isNull() && rows.nodeName().string().lower() == "tr")
+				for (DOM::Node cols=rows.firstChild();!cols.isNull();cols=cols.nextSibling())
+					if (!cols.isNull())
+						parseNode(cols);
+		return false;
+	}
+
+ 	DOM::Element table_body=e.firstChild();
+	if(table_body.isNull()) {
+ 		// If the table_body is empty, we don't continue cause else
+ 		// KHTML will throw a DOM::DOMException if we try to access
+ 		// the null element.
+ 		return true;
+	}
+
 	int tableno=_writer->createTable();
  	int nrow=0;
  	int ncol=0;
- 	int has_borders=false;
+ 	bool has_borders=false;
 	QColor bgcolor=parsecolor("#FFFFFF");
- 	DOM::Element table_body=e.firstChild();
+
  	if (!table_body.getAttribute("bgcolor").string().isEmpty())
  	       bgcolor=parsecolor(table_body.getAttribute("bgcolor").string());
  	if ((e.getAttribute("border").string().toInt() > 0))
@@ -431,16 +506,18 @@ bool KHTMLReader::parse_table(DOM::Element e) {
 
  	// fixme rewrite this proper
  	//(maybe using computed sizes from khtml if thats once exported)
- 	for (DOM::Element rows=table_body.firstChild();!rows.isNull();rows=rows.nextSibling()) {
- 	if (rows.tagName().string().lower() == "tr") {
-
+ 	for (DOM::Node rowsnode=table_body.firstChild();!rowsnode.isNull();rowsnode=rowsnode.nextSibling()) {
+ 	DOM::Element rows = rowsnode;
+ 	if (!rows.isNull() && rows.tagName().string().lower() == "tr") {
  	    QColor obgcolor=bgcolor;
  	    if (!rows.getAttribute("bgcolor").string().isEmpty())
  	       	bgcolor=parsecolor(rows.getAttribute("bgcolor").string());
 
  		ncol=0;
- 		for (DOM::Element cols=rows.firstChild();!cols.isNull();cols=cols.nextSibling()) {
- 		        if (cols.tagName().string().lower() == "td") {
+ 		for (DOM::Node colsnode=rows.firstChild();!colsnode.isNull();colsnode=colsnode.nextSibling()) {
+ 		        DOM::Element cols = colsnode;
+                        const QString nodename = cols.isNull() ? QString::null : cols.nodeName().string().lower();
+ 		        if (nodename == "td" || nodename == "th") {
  		             QColor bbgcolor=bgcolor;
 		 	    if (!cols.getAttribute("bgcolor").string().isEmpty())
  	       			bgcolor=parsecolor(cols.getAttribute("bgcolor").string());
@@ -478,25 +555,30 @@ bool KHTMLReader::parse_table(DOM::Element e) {
 	return false; // we do our own recursion
 }
 
-bool KHTMLReader::parse_img(DOM::Element e) {
+bool KHTMLReader::parse_img(DOM::Element /*e*/) {
      	//QRect e=e.getRect();
     return true;
 }
 
-
 bool KHTMLReader::parse_pre(DOM::Element e) {
-	DOM::Text prething=e.firstChild();
-	if (prething.isNull()) return false;
-
-	QStringList k=QStringList::split("\n",prething.data().string());
-
+#if 0 // see Bug #74601 (normal): kword doesn't recognize PRE-tags in HTML
+	//pushNewState();
+	/// \todo set fixed width font
+	DOM::HTMLElement htmlelement(e);
+	if(! htmlelement.isNull())
+		_writer->addText(state()->paragraph,htmlelement.innerHTML().string(),1);
 	startNewParagraph();
-
-	for (QStringList::Iterator b=k.begin();b!=k.end();++b) {
-		_writer->addText(state()->paragraph,*b);
-		startNewParagraph();
+	//popState();
+	return false; // children are already handled.
+#else
+	pushNewState();
+	state()->in_pre_mode=true;
+	for (DOM::Node q=e.firstChild(); !q.isNull(); q=q.nextSibling()) {
+		parseNode(q); // parse everything...
 	}
-	return false; // FIXME no support for tags in <PRE> sections ATM.
+	popState();
+	return false; // children are already handled.
+#endif
 }
 
 bool KHTMLReader::parse_ol(DOM::Element e) {
@@ -530,10 +612,16 @@ bool KHTMLReader::parse_font(DOM::Element e) {
 
 bool KHTMLReader::parse_ul(DOM::Element e) {
         _list_depth++;
-        for (DOM::Element items=e.firstChild();!items.isNull();items=items.nextSibling()) {
-                  if (items.tagName().string().lower() == "li") {
-                  	pushNewState();
+        bool popstateneeded = false;
+        for (DOM::Node items=e.firstChild();!items.isNull();items=items.nextSibling()) {
+                  if (items.nodeName().string().lower() == "li") {
+                  		if (popstateneeded) {
+                  			popState();
+                  			//popstateneeded = false;
+                  		}
+                  		pushNewState();
                   		startNewLayout();
+                  		popstateneeded = true;
                   		_writer->layoutAttribute(state()->paragraph,"COUNTER","numberingtype","1");
                   		_writer->layoutAttribute(state()->paragraph,"COUNTER","righttext",".");
                   		if (e.tagName().string().lower() == "ol")
@@ -549,11 +637,11 @@ bool KHTMLReader::parse_ul(DOM::Element e) {
         	          		_writer->layoutAttribute(state()->paragraph,"COUNTER","righttext","");
 	                  		}
                   		_writer->layoutAttribute(state()->paragraph,"COUNTER","depth",QString("%1").arg(_list_depth-1));
-                  		parseNode(items);
-                  	popState();
-
                   }
+                  parseNode(items);
         }
+        if (popstateneeded)
+            popState();
         _list_depth--;
 	return false;
 }
