@@ -19,11 +19,11 @@
 #include "kwdwriter.h"
 #include <stdlib.h>
 #include "qrect.h"
-#include <kozoomhandler.h>
+#include <KoTextZoomHandler.h>
 #include <qpaintdevice.h>
 
 KWDWriter::KWDWriter(KoStore *store){
-	_zoomhandler = new KoZoomHandler();
+	_zoomhandler = new KoTextZoomHandler();
 
 	_store=store;
 	_doc= new QDomDocument("DOC");
@@ -37,6 +37,7 @@ KWDWriter::KWDWriter(KoStore *store){
 	_docinfo->appendChild(infodoc);
 
 	tableNo=1;
+	insidetable = false;
 	QDomElement kwdoc = _doc->createElement( "DOC" );
 	kwdoc.setAttribute( "editor", "HTML Import Filter" );
 	kwdoc.setAttribute( "mime", "application/x-kword" );
@@ -124,8 +125,12 @@ HEADINGSTYLE(h6,8);
 
 }
 
+bool KWDWriter::isInTable() const {
+	return insidetable;
+}
 
 int KWDWriter::createTable() {
+ insidetable = true;
  return tableNo++;
 }
 
@@ -208,6 +213,7 @@ void KWDWriter::createHR(QDomElement paragraph, int width) {
 void KWDWriter::finishTable(int tableno,QRect rect) {
 	int ncols=0;
 	int nrows=0;
+	insidetable = false;
 
 	int x=rect.x();
 	int y=rect.y();
@@ -256,7 +262,7 @@ void KWDWriter::finishTable(int tableno,QRect rect) {
 	      if (must_resize == true) {
 	      QDomElement ee=e.firstChild().toElement(); // the frame in the frameset
 	          int cs=e.attribute("cols").toInt();
-	          int rs=e.attribute("cols").toInt();
+	          int rs=e.attribute("rows").toInt();
 	          kdDebug(30503) << "resizing" << endl;
 	          addRect(ee,QRect(x+step_x*curcol,0,step_x*cs,step_y*rs));
 	      }
@@ -294,6 +300,32 @@ QDomElement KWDWriter::addParagraph(QDomElement parent) {
 	return addParagraph(parent,k);
 }
 
+void KWDWriter::appendKWordVariable(QDomDocument& doc, QDomElement& format, 
+	const QString& text, const QString& key, int type, QDomElement& child) {
+
+	QDomElement variableElement ( doc.createElement("VARIABLE") );
+
+	QDomElement typeElement ( doc.createElement("TYPE") );
+	typeElement.setAttribute("key",key);
+	typeElement.setAttribute("type",type);
+	typeElement.setAttribute("text",text);
+	variableElement.appendChild(typeElement); //Append to <VARIABLE>
+
+	variableElement.appendChild(child); //Append to <VARIABLE>
+
+	format.appendChild(variableElement);
+}
+
+QDomElement KWDWriter::createLink(QDomElement paragraph, QString linkName, QString hrefName) {
+	QDomElement linkElement = _doc->createElement("LINK");
+	linkElement.setAttribute( "linkName", linkName );
+	linkElement.setAttribute( "hrefName", hrefName );
+	QDomElement format = currentFormat(paragraph,true);
+	format.setAttribute("id", 4); // change Variable
+        appendKWordVariable(*_doc, format, linkName, "STRING", 9, linkElement);
+
+	return linkElement;
+}
 
 
 QDomElement KWDWriter::setLayout(QDomElement paragraph, QDomElement layout) {
@@ -387,15 +419,34 @@ QDomElement KWDWriter::layoutAttribute(QDomElement paragraph, QString name, QStr
 	}
 }
 
-void KWDWriter::addText(QDomElement paragraph, QString text, int format_id) {
+void KWDWriter::addText(QDomElement paragraph, QString text, int format_id, bool keep_formatting) {
 	QDomNode temp=paragraph.elementsByTagName("TEXT").item(0).firstChild();
 	QDomText currentText=temp.toText();
 	if (temp.isNull()) { kdDebug(30503) << "no text" << endl; return; }
-	int oldLength=currentText.data().length();
-	currentText.setData(currentText.data()+text);
+	QString oldtext=currentText.data();
+	int oldLength=oldtext.length();
+	if (keep_formatting) {
+		if (oldLength) {
+			++oldLength;
+			oldtext.append('\n');
+		}
+	} else {
+		if (oldLength)
+			++oldLength; // add new trailing space char
+		text=text.simplifyWhiteSpace(); // drop all unprintable chars
+	}
+	QString newtext;
+	if (keep_formatting)
+		newtext=oldtext + text;
+	else {
+		newtext=oldtext + " " + text;
+		newtext=newtext.simplifyWhiteSpace(); // strip possible new space at beginning.
+	}
+	currentText.setData(newtext);
 	int newLength=text.length();
 	QDomElement lastformat=currentFormat(paragraph,true);
-	lastformat.setAttribute("id",format_id);
+	if (lastformat.attribute("id").isEmpty()) // keep old id value, e.g. for LINK URL
+		lastformat.setAttribute("id",format_id);
 	lastformat.setAttribute("pos",QString("%1").arg(oldLength));
 	lastformat.setAttribute("len",QString("%1").arg(newLength));
 }
