@@ -1,5 +1,3 @@
-// $Header: /home/kde/koffice/filters/kword/libexport/KWEFUtil.h,v 1.7 2003/08/16 12:22:48 mueller Exp $
-
 /*
    This file is part of the KDE project
    Copyright (C) 2001 Nicolas GOUTTE <goutte@kde.org>
@@ -16,19 +14,20 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KWEF_UTIL_H
 #define KWEF_UTIL_H
 
+#include <koffice_export.h>
 namespace KWEFUtil
 {
 
-QString EscapeSgmlText(const QTextCodec* codec, const QString& strIn,
+KOFFICEFILTER_EXPORT QString EscapeSgmlText(const QTextCodec* codec, const QString& strIn,
     const bool quot = false, const bool apos = false );
-void GetNativePaperFormat(const int format,
+KOFFICEFILTER_EXPORT void GetNativePaperFormat(const int format,
     QString& width, QString& height, QString& units);
 }
 
