@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU Library General Public License
    Version 2 along with this library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <limits.h>
@@ -33,7 +33,7 @@
 #include <kdebug.h>
 #include <kgenericfactory.h>
 
-#include <koFilterChain.h>
+#include <KoFilterChain.h>
 #include <kowmfpaint.h>
 
 #include <KWEFStructures.h>
@@ -1905,7 +1905,7 @@ MSWriteExport::~MSWriteExport ()
 
 KoFilter::ConversionStatus MSWriteExport::convert (const QCString &from, const QCString &to)
 {
-	kdDebug (30509) << "MSWriteExport $Date: 2004-02-14 17:58:46 +0100 (Sat, 14 Feb 2004) $ using LibMSWrite "
+	kdDebug (30509) << "MSWriteExport $Date: 2006-02-12 18:28:12 +0000 (Sun, 12 Feb 2006) $ using LibMSWrite "
 			  				<< MSWrite::Version << endl;
 
 	if (to != "application/x-mswrite" || from != "application/x-kword")
