@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU Library General Public License
    Version 2 along with this library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef NDEBUG
@@ -33,8 +33,8 @@
 #include <kdebug.h>
 #include <kgenericfactory.h>
 
-#include <koFilterChain.h>
-#include <koStore.h>
+#include <KoFilterChain.h>
+#include <KoStore.h>
 
 #include "list.h"
 #include "libmswrite.h"
@@ -483,7 +483,8 @@ public:
 						m_objectUpto, getNumObjects ());*/
 
 		MSWrite::List <WRIObject>::Iterator it;
-		for (it = m_objectList.begin (); it != m_objectList.end (); it++)
+		MSWrite::List <WRIObject>::Iterator end(m_objectList.end ());
+		for (it = m_objectList.begin (); it != end; ++it)
 		{
 			kdDebug (30509) << "outputting object \'" << (*it).m_nameInStore
 					  				<< "\'   (length: " << (*it).m_dataLength << ")"
@@ -1346,7 +1347,7 @@ MSWriteImport::~MSWriteImport ()
 
 KoFilter::ConversionStatus MSWriteImport::convert (const QCString &from, const QCString &to)
 {
-	kdDebug (30509) << "MSWriteImport $Date: 2004-02-14 17:58:46 +0100 (Sat, 14 Feb 2004) $ using LibMSWrite "
+	kdDebug (30509) << "MSWriteImport $Date: 2006-02-12 18:28:12 +0000 (Sun, 12 Feb 2006) $ using LibMSWrite "
 			  				<< MSWrite::Version << endl;
 
 	if (to != "application/x-kword" || from != "application/x-mswrite")
