@@ -17,7 +17,7 @@
 #include <qfontinfo.h>
 #include <stddef.h>
 #include <string.h>
-#include <koFilterChain.h>
+#include <KoFilterChain.h>
 #include <kgenericfactory.h>
 
 #include <qcstring.h>
@@ -30,8 +30,8 @@
 #include <kurl.h>
 #include <kmessagebox.h>
 
-#include <koPicture.h>
-#include <koFilterManager.h>
+#include <KoPicture.h>
+#include <KoFilterManager.h>
 
 #include "rtfimport.h"
 #include "rtfimport.moc"
@@ -146,7 +146,7 @@ static RTFProperty propertyTable[] =
 	PROP(	0L,		"expndtw",	ignoreKeyword,		0L, 0 ), // Expansion/compression of character inter-space not supported
 	MEMBER(	0L,		"f",		setNumericProperty,	state.format.font, 0 ),
 	MEMBER(	"@rtf",		"facingp",	setFlagProperty,	facingPages, true ),
-	PROP(	0L,		"fcharset",	ignoreKeyword,		0L, 0 ), // Not needed with Qt
+	PROP(	0L,		"fcharset",	setCharset,		0L, 0 ), // Not needed with Qt
 	PROP(	"@fonttbl",	"fdecor",	setFontStyleHint,	0L, QFont::Decorative ),
 	MEMBER(	0L,		"fi",		setNumericProperty,	state.layout.firstIndent, 0 ),
 	PROP(	"@fonttbl",	"fmodern",	setFontStyleHint,	0L, QFont::TypeWriter ),
@@ -867,6 +867,38 @@ void RTFImport::setFlagProperty( RTFProperty *property )
     ((bool *)this)[property->offset] = property->value;
 }
 
+void RTFImport::setCharset( RTFProperty *property )
+{
+    QCString cp;
+    switch(token.value) {
+        case 0: cp = "CP1252"; break; // ANSI_CHARSET
+        case 1: cp = "CP1252"; break; // DEFAULT_CHARSET
+        //case 2: cp = ""; break; // SYMBOL_CHARSET not supported yet.
+        case 77: cp = "Apple Roman"; break; // MAC_CHARSET
+        case 128: cp = "Shift-JIS"; break; // SHIFTJIS_CHARSET "CP932"
+        case 129: cp = "eucKR"; break; // HANGUL_CHARSET "CP949"
+        case 130: cp = "CP1361"; break; // JOHAB_CHARSET doesn't really seem to be supported by Qt :-(
+        case 134: cp = "GB2312"; break; // GB2312_CHARSET "CP936"
+        case 136: cp = "Big5-HKSCS"; break; // CHINESEBIG5_CHARSET "CP950"
+        case 161: cp = "CP1253"; break; // GREEK_CHARSET
+        case 162: cp = "CP1254"; break; // TURKISH_CHARSET
+        case 163: cp = "CP1258"; break; // VIETNAMESE_CHARSET
+        case 177: cp = "CP1255"; break; // HEBREW_CHARSET
+        case 178: cp = "CP1256"; break; // ARABIC_CHARSET / ARABICSIMPLIFIED_CHARSET
+        case 186: cp = "CP1257"; break; // BALTIC_CHARSET
+        case 204: cp = "CP1251"; break; // RUSSIAN_CHARSET / CYRILLIC_CHARSET
+        case 222: cp = "CP874"; break; // THAI_CHARSET
+        case 238: cp = "CP1250"; break; // EASTEUROPE_CHARSET / EASTERNEUROPE_CHARSET
+        case 255: cp = "CP850"; break; // OEM_CHARSET "IBM 850"
+        default: return;
+    }
+    QTextCodec* oldCodec = textCodec;
+    textCodec=QTextCodec::codecForName(cp);
+    kdDebug(30515) << "\\fcharset: charset: " << token.value << " codepage: "<< cp << " given: " << (textCodec?textCodec->name():QString("-none-")) << endl;
+    if ( ! textCodec )
+        textCodec = oldCodec;
+}
+
 void RTFImport::setNumericProperty( RTFProperty *property )
 {
     *((int *)(((char *)this) + property->offset)) = token.hasParam ? token.value : property->value;
