@@ -15,21 +15,21 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "ooutils.h"
-#include <koDocument.h>
-#include <koStyleStack.h>
+#include <KoDocument.h>
+#include <KoStyleStack.h>
 #include <qdom.h>
 #include <qcolor.h>
 #include <qimage.h>
-#include <koUnit.h>
+#include <KoUnit.h>
 #include <qregexp.h>
 #include <kdebug.h>
 #include <kzip.h>
-#include <kodom.h>
+#include <KoDom.h>
 #include <qxml.h>
 
 const char* const ooNS::office="http://openoffice.org/2000/office";
@@ -132,21 +132,26 @@ void OoUtils::importLineSpacing( QDomElement& parentElement, const KoStyleStack&
         if ( value != "normal" )
         {
             QDomElement lineSpacing = parentElement.ownerDocument().createElement( "LINESPACING" );
-            if ( value == "100%" )
-                lineSpacing.setAttribute("type","single");
-            else if( value=="150%")
-                lineSpacing.setAttribute("type","oneandhalf");
-            else if( value=="200%")
-                lineSpacing.setAttribute("type","double");
-            else if ( value.find('%') > -1 )
+
+            if ( value.endsWith("%" ) )
             {
-                double percent = value.toDouble();
-                lineSpacing.setAttribute("type", "multiple");
-                lineSpacing.setAttribute("spacingvalue", percent/100);
+                double percent = value.left(value.length()-1).toDouble();
+                if( percent == 100 )
+                    lineSpacing.setAttribute("type","single");
+                else if( percent == 150 )
+                    lineSpacing.setAttribute("type","oneandhalf");
+                else if( percent == 200 )
+                    lineSpacing.setAttribute("type","double");
+                else
+                {
+                  lineSpacing.setAttribute("type", "multiple");
+                  lineSpacing.setAttribute("spacingvalue", percent/100);
+                }
             }
-            else // fixed value (use KoUnit::parseValue to get it in pt)
+            else // fixed value (TODO use KoUnit::parseValue to get it in pt)
             {
                 kdWarning(30519) << "Unhandled value for fo:line-height: " << value << endl;
+                lineSpacing.setAttribute("type","single"); // fallback
             }
             parentElement.appendChild( lineSpacing );
         }
@@ -205,11 +210,11 @@ void OoUtils::importTabulators( QDomElement& parentElement, const KoStyleStack&
         return;
     QDomElement tabStops = styleStack.childNodeNS( ooNS::style, "tab-stops" );
     //kdDebug(30519) << k_funcinfo << tabStops.childNodes().count() << " tab stops in layout." << endl;
-    QDomElement tabStop;
-    forEachElement( tabStop, tabStops )
+    for ( QDomNode it = tabStops.firstChild(); !it.isNull(); it = it.nextSibling() )
     {
-        Q_ASSERT( tabStop.localName() == "tab-stop" );
-        const QString type = tabStop.attributeNS( ooNS::style, "type", QString::null ); // left, right, center or char
+        QDomElement tabStop = it.toElement();
+        Q_ASSERT( tabStop.tagName() == "style:tab-stop" );
+        QString type = tabStop.attributeNS( ooNS::style, "type", QString::null ); // left, right, center or char
 
         QDomElement elem = parentElement.ownerDocument().createElement( "TABULATOR" );
         int kOfficeType = 0;
