@@ -13,14 +13,14 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __XSLTEXPORT_H__
 #define __XSLTEXPORT_H__
 
-#include <koFilter.h>
+#include <KoFilter.h>
 
 class XSLTExport : public KoFilter
 {
