@@ -177,6 +177,10 @@ VGroup::save( QDomElement& element ) const
 void
 VGroup::saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles, int &index ) const
 {
+	// do not save deleted objects
+	if( state() == deleted )
+		return;
+
 	docWriter->startElement( "draw:g" );
 
 	// save objects:
