@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qhbuttongroup.h>
@@ -23,82 +23,92 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qwidget.h>
+#include <qtooltip.h>
 
 #include <kiconloader.h>
 #include <klocale.h>
-#include <koMainWindow.h>
+#include <KoMainWindow.h>
 
-#include "koUnitWidgets.h"
+#include "KoUnitWidgets.h"
 
 #include "karbon_part.h"
 #include "karbon_view.h"
 #include "vstroke.h"
-#include "vcolorslider.h"
 #include "vselection.h"
 #include "vstrokecmd.h"
 
 #include "vstrokedocker.h"
 
 VStrokeDocker::VStrokeDocker( KarbonPart* part, KarbonView* parent, const char* /*name*/ )
-	: VDocker( parent->shell() ), m_part ( part ), m_view( parent )
+	: QWidget(), m_part ( part ), m_view( parent )
 {
 	setCaption( i18n( "Stroke Properties" ) );
 
 	QPushButton *button;
-	mainWidget = new QWidget( this );
-	QGridLayout *mainLayout = new QGridLayout( mainWidget, 4, 2 );
+
+	QGridLayout *mainLayout = new QGridLayout( this, 4, 2 );
 	
-	QLabel* widthLabel = new QLabel( i18n ( "Width:" ), mainWidget );
+	QLabel* widthLabel = new QLabel( i18n ( "stroke width", "Width:" ), this );
 	mainLayout->addWidget( widthLabel, 0, 0 );
-	m_setLineWidth = new KoBuggyUnitDoubleSpinBox( mainWidget, 0.0, 1000.0, 0.5, 1.0, KoUnit::U_PT, 1 );
+	// set min/max/step and value in points, then set actual unit
+	m_setLineWidth = new KoUnitDoubleSpinBox( this, 0.0, 1000.0, 0.5, 1.0, KoUnit::U_PT, 2 );
+	m_setLineWidth->setUnit( part->unit() );
+    QToolTip::add( m_setLineWidth, i18n( "Set line width of actual selection" ) );
 	mainLayout->addWidget ( m_setLineWidth, 0, 1 );
 	connect( m_setLineWidth, SIGNAL( valueChanged( double ) ), this, SLOT( widthChanged() ) ); 
 	
-	QLabel* capLabel = new QLabel( i18n ( "Cap:" ), mainWidget );
+	QLabel* capLabel = new QLabel( i18n ( "Cap:" ), this );
 	mainLayout->addWidget( capLabel, 1, 0 );
-	m_capGroup = new QHButtonGroup( mainWidget );
-	m_capGroup->setFrameShape( NoFrame );
+	m_capGroup = new QHButtonGroup( this );
+	m_capGroup->setFrameShape( QFrame::NoFrame );
 	m_capGroup->setInsideMargin( 1 );
 	m_capGroup->setExclusive( true );
 	button = new QPushButton( "", m_capGroup );
 	button->setPixmap( SmallIcon( "cap_butt" ) );
 	button->setToggleButton( true );
+    QToolTip::add( button, i18n( "Butt cap" ) );
 	m_capGroup->insert( button );
 	button = new QPushButton( "", m_capGroup );
 	button->setPixmap( SmallIcon( "cap_round" ) );
 	button->setToggleButton( true );
+    QToolTip::add( button, i18n( "Round cap" ) );
 	m_capGroup->insert( button );
 	button = new QPushButton( "", m_capGroup );
 	button->setPixmap( SmallIcon( "cap_square" ) );
 	button->setToggleButton( true );
+    QToolTip::add( button, i18n( "Square cap" ) );
 	m_capGroup->insert( button );
 	mainLayout->addWidget( m_capGroup, 1, 1 );
 	connect( m_capGroup, SIGNAL( clicked( int ) ), this, SLOT( slotCapChanged( int ) ) );
 	
-	QLabel* joinLabel = new QLabel( i18n ( "Join:" ), mainWidget );
+	QLabel* joinLabel = new QLabel( i18n ( "Join:" ), this );
 	mainLayout->addWidget( joinLabel, 2, 0 );
 	
-	m_joinGroup = new QHButtonGroup( mainWidget );
-	m_joinGroup->setFrameShape( NoFrame );
+	m_joinGroup = new QHButtonGroup( this );
+	m_joinGroup->setFrameShape( QFrame::NoFrame );
 	m_joinGroup->setInsideMargin( 1 );
 	m_joinGroup->setExclusive( true );
 	button = new QPushButton( "", m_joinGroup );
 	button->setPixmap( SmallIcon( "join_miter" ) );
 	button->setToggleButton( true );
+    QToolTip::add( button, i18n( "Miter join" ) );
 	m_joinGroup->insert( button );
 	button = new QPushButton( "", m_joinGroup );
 	button->setPixmap( SmallIcon( "join_round" ) );
 	button->setToggleButton( true );
+    QToolTip::add( button, i18n( "Round join" ) );
 	m_joinGroup->insert( button );
 	button = new QPushButton( "", m_joinGroup );
 	button->setPixmap( SmallIcon( "join_bevel" ) );
 	button->setToggleButton( true );
+    QToolTip::add( button, i18n( "Bevel join" ) );
 	m_joinGroup->insert( button );
 	mainLayout->addWidget( m_joinGroup, 2, 1 );
 	connect( m_joinGroup, SIGNAL( clicked( int ) ), this, SLOT( slotJoinChanged( int ) ) );
 
+	mainLayout->setRowStretch( 3, 1 );
+	mainLayout->setColStretch( 1, 1 );
 	mainLayout->activate();
-	setWidget( mainWidget );
 
 	updateDocker();
 }
@@ -163,7 +173,7 @@ void VStrokeDocker::updateDocker()
 			m_joinGroup->setButton( 0 );
 	}
 	
-	m_setLineWidth->setValue( m_stroke.lineWidth() );
+	m_setLineWidth->changeValue( m_stroke.lineWidth() );
 	
 	connect( m_setLineWidth, SIGNAL( valueChanged( double ) ), this, SLOT( widthChanged() ) ); 
 	connect( m_capGroup, SIGNAL( clicked( int ) ), this, SLOT( slotCapChanged( int ) ) );
@@ -182,5 +192,17 @@ void VStrokeDocker::setStroke( const VStroke &stroke )
 	updateDocker();
 }
 
+void VStrokeDocker::setUnit( KoUnit::Unit unit )
+{
+	disconnect( m_setLineWidth, SIGNAL( valueChanged( double ) ), this, SLOT( widthChanged() ) ); 
+	disconnect( m_capGroup, SIGNAL( clicked( int ) ), this, SLOT( slotCapChanged( int ) ) );
+	disconnect( m_joinGroup, SIGNAL( clicked( int ) ), this, SLOT( slotJoinChanged( int ) ) );
+
+	m_setLineWidth->setUnit( unit );
+
+	connect( m_setLineWidth, SIGNAL( valueChanged( double ) ), this, SLOT( widthChanged() ) ); 
+	connect( m_capGroup, SIGNAL( clicked( int ) ), this, SLOT( slotCapChanged( int ) ) );
+	connect( m_joinGroup, SIGNAL( clicked( int ) ), this, SLOT( slotJoinChanged( int ) ) );
+}
 #include "vstrokedocker.moc"
 
