@@ -14,15 +14,13 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VSTYLEDOCKER_H__
 #define __VSTYLEDOCKER_H__
 
-#include "vdocker.h"
-
 #include <koIconChooser.h>
 #include <qwidget.h>
 
@@ -69,7 +67,7 @@ private:
 	VClipartIconItem* m_selectedItem;
 };
 
-class VStyleDocker : public VDocker
+class VStyleDocker : public QWidget
 {
 	Q_OBJECT
 
@@ -82,7 +80,6 @@ public slots:
 
 private:
 	virtual void mouseReleaseEvent( QMouseEvent *e );
-	QWidget *mainWidget;
 	QTabWidget *mTabWidget;
 	KarbonPart *m_part;
 	KarbonView *m_view;
