@@ -312,6 +312,12 @@ KarbonPart::loadOasis( const QDomDocument &doc, KoOasisStyles &styles, const QDo
 	QDomElement *master = styles.masterPages()[ masterPageName ];
 	if ( !master ) //last test...
 		master = styles.masterPages()[ "Default" ];
+	// last resort, use the first found master page style
+	if ( ! master )
+	{
+		QDictIterator<QDomElement> it( styles.masterPages() );
+		master = it.current();
+	}
 	Q_ASSERT( master );
 	const QDomElement *style = master ? styles.findStyle( master->attributeNS( KoXmlNS::style, "page-layout-name", QString::null ) ) : 0;
 	if( style )
