@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __KARBON_VIEW__
@@ -24,11 +24,12 @@
 #include <config.h>
 #endif
 
-#include "karbon_view_base.h"
+#include <KoView.h>
+#include <KoPoint.h>
 #include <ksharedptr.h>
 #include <kxmlguibuilder.h>
-#include <koUnit.h>
-
+#include <KoUnit.h>
+#include <koffice_export.h>
 class DCOPObject;
 class QLabel;
 
@@ -37,14 +38,18 @@ class KarbonPart;
 class KSelectAction;
 class KToggleAction;
 class KoContextHelpAction;
+class KoLineStyleAction;
 
 class KoUnitDoubleSpinComboBox;
 class KoRect;
-class KoRuler;
+class VRuler;
 
-class VColorDocker;
-class VDocumentDocker;
+class KoPaletteManager;
+class VDocumentTab;
+class VLayersTab;
+class VHistoryTab;
 class VStrokeDocker;
+class VColorDocker;
 class VStyleDocker;
 class VTransformDocker;
 
@@ -56,11 +61,14 @@ class VStateButton;
 class VStroke;
 class VStrokeFillPreview;
 class VCanvas;
+class VStrokeFillPreview;
+class VTypeButtonBox;
 
 class VTool;
 class VToolBox;
+class VToolController;
 
-class KarbonView : public KarbonViewBase, public KXMLGUIBuilder
+class KARBONCOMMON_EXPORT KarbonView : public KoView, public KXMLGUIBuilder
 {
 	Q_OBJECT
 
@@ -71,18 +79,21 @@ public:
 
 	virtual DCOPObject* dcopObject();
 
+	KarbonPart *part() const { return m_part; }
+
 	virtual void paintEverything( QPainter &p, const QRect &rect, bool transparent = false );
 
 	bool mouseEvent( QMouseEvent* event, const KoPoint & );
 	bool keyEvent( QEvent* event );
+	void dropEvent( QDropEvent *e );
 
-	virtual QWidget* canvas();
+	virtual QWidget* canvas() const;
 
 	VCanvas* canvasWidget() const { return m_canvas; }
 
 	virtual VPainterFactory* painterFactory() const { return m_painterFactory; }
 
-	KarbonPart* part() const { return (KarbonPart *)m_part; }
+	KoPaletteManager* paletteManager() { return m_pPaletteManager; };
 
 	// printing support, override from KoView
 	virtual void setupPrinter( KPrinter &/*printer*/ ) {}
@@ -96,8 +107,6 @@ public:
 
 	QLabel* statusMessage() const { return m_status; }
 
-	void setUnit( KoUnit::Unit _unit );
-
 	void setCursor( const QCursor & );
 
 	void repaintAll( const KoRect & );
@@ -106,7 +115,12 @@ public:
 	void setPos( const KoPoint& p );
 
 	void setViewportRect( const KoRect &rect );
-	virtual void setZoomAt( double zoom, const KoPoint & = KoPoint() );
+	void setZoomAt( double zoom, const KoPoint & = KoPoint() );
+
+	VToolController *toolController();
+
+	VStrokeFillPreview* strokeFillPreview()
+		{ return m_strokeFillPreview; }
 
 public slots:
 	// editing:
@@ -118,6 +132,7 @@ public slots:
 	void editDeleteSelection();
 	void editPurgeHistory();
 
+	void selectionDuplicate();
 	void selectionBringToFront();
 	void selectionSendToBack();
 	void selectionMoveUp();
@@ -129,6 +144,15 @@ public slots:
 	void selectionAlignVerticalCenter();
 	void selectionAlignVerticalBottom();
 
+	void selectionDistributeHorizontalCenter();
+	void selectionDistributeHorizontalGap();
+	void selectionDistributeHorizontalLeft();
+	void selectionDistributeHorizontalRight();
+	void selectionDistributeVerticalCenter();
+	void selectionDistributeVerticalGap();
+	void selectionDistributeVerticalBottom();
+	void selectionDistributeVerticalTop();
+
 	void fileImportGraphic();
 
 	void groupSelection();
@@ -140,8 +164,7 @@ public slots:
 	void viewZoomIn();
 	void viewZoomOut();
 
-	// TODO: remove this someday:
-	void dummyForTesting();
+	void setUnit( KoUnit::Unit _unit );
 
 	void configure();
 
@@ -152,22 +175,21 @@ public slots:
 
 	void slotActiveToolChanged( VTool * );
 
+	void togglePageMargins(bool);
 	void showRuler();
 	void showGrid();
+	bool showPageMargins();
 	void snapToGrid();
 
 	void showSelectionPopupMenu( const QPoint &pos );
 
 protected slots:
 	// Object related operations.
-	void objectTransform();
 
 	// View.
 	void viewModeChanged();
 	void zoomChanged( const KoPoint & = KoPoint() );
-	void viewColorManager();
-	void viewStrokeDocker();
-	void viewStyleDocker();
+	void setLineStyle( int );
 
 	// Toolbox dialogs.
 	void slotStrokeChanged( const VStroke& );
@@ -175,9 +197,6 @@ protected slots:
 
 	void canvasContentsMoving( int x, int y );
 
-	// Docker related operations
-	void colorDockerChanged();
-
 signals:
 	void zoomChanged( double );
 	void selectionChange();
@@ -186,7 +205,14 @@ signals:
 protected:
 	virtual void updateReadWrite( bool ) {}
 	virtual void resizeEvent( QResizeEvent* event );
-	virtual void dropEvent( QDropEvent *e );
+
+	void createDocumentTabDock();
+	void createLayersTabDock();
+	void createHistoryTabDock();
+	void createStrokeDock();
+	void createColorDock();
+	void createTransformDock();
+	void createResourceDock();
 
 	//KXMLGUIBuilder
 	virtual QWidget *createContainer( QWidget *parent, int index, const QDomElement &element, int &id );
@@ -195,13 +221,16 @@ protected:
 
 private:
 	void initActions();
+	void updateRuler();
 
+	KarbonPart		*m_part;
 	VCanvas			*m_canvas;
-	KoRuler			*m_horizRuler;
-	KoRuler			*m_vertRuler;
+	VRuler			*m_horizRuler;
+	VRuler			*m_vertRuler;
 
 	VPainterFactory		*m_painterFactory;
 	VStrokeFillPreview	*m_strokeFillPreview;
+	VTypeButtonBox		*m_typeButtonBox;
 
 	VToolBox		*m_toolbox;
 
@@ -213,31 +242,37 @@ private:
 	// actions:
 	KSelectAction		*m_zoomAction;
 	KSelectAction		*m_viewAction;
-	KAction			*m_configureAction;
+	KAction				*m_configureAction;
 	KToggleAction		*m_showRulerAction;
 	KToggleAction		*m_showGridAction;
 	KToggleAction		*m_snapGridAction;
+	KToggleAction		*m_showPageMargins;
 	KoContextHelpAction	*m_contextHelpAction;
-	KAction			*m_deleteSelectionAction;
+	KAction				*m_deleteSelectionAction;
 	// line width
 	KoUnitDoubleSpinComboBox *m_setLineWidth;
+	KoLineStyleAction	*m_lineStyleAction;
 
 	//dockers
+	KoPaletteManager	*m_pPaletteManager;
+	VDocumentTab		*m_DocumentTab;
+	VLayersTab			*m_LayersTab;
+	VHistoryTab			*m_HistoryTab;
 	VColorDocker		*m_ColorManager;
-	VDocumentDocker		*m_documentDocker;
 	VStrokeDocker		*m_strokeDocker;
 	VStyleDocker		*m_styleDocker;
 	VTransformDocker	*m_TransformDocker;
 
 	VSelectToolBar		*m_selectToolBar;
-	QLabel			*m_status;
-	QLabel			*m_cursorCoords;
 
 	// dcop
 	DCOPObject		*m_dcop;
 
 	//Status Bar
-	VSmallPreview		*m_smallPreview;
+	QLabel				*m_status;       // Ordinary status
+	QLabel				*m_cursorCoords; // Cursor coordinates
+	VSmallPreview		*m_smallPreview; // Stroke and Fill
+	VToolController	*m_toolController;
 };
 
 #endif
