@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __ROUNDCORNERSPLUGIN_H__
@@ -25,14 +25,14 @@
 #include <commands/vreplacingcmd.h>
 #include <koffice_export.h>
 
-class KarbonViewBase;
+class KarbonView;
 class VRoundCornersDlg;
 
 class KARBONBASE_EXPORT VRoundCornersPlugin : public KParts::Plugin
 {
 	Q_OBJECT
 public:
-	VRoundCornersPlugin( KarbonViewBase *parent, const char* name, const QStringList & );
+	VRoundCornersPlugin( KarbonView *parent, const char* name, const QStringList & );
 	virtual ~VRoundCornersPlugin();
 
 private slots:
