@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -60,6 +60,8 @@ art_render_pattern_render (ArtRenderCallback *self, ArtRender *render,
 
   y = y - render->y0;
 
+ if(theight == 0) return;
+
   for (x = 0; x < width; x++)
   {
 	  int x0 = sinangle * y + cosangle * x;
