@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 // kopainter/libart wrapper
@@ -58,8 +58,8 @@
 #include <kiconloader.h>
 #include <math.h>
 
-#include <koPoint.h>
-#include <koRect.h>
+#include <KoPoint.h>
+#include <KoRect.h>
 #include <karbon_factory.h>
 #include <karbon_resourceserver.h>
 
@@ -638,7 +638,7 @@ VKoPainter::applyPattern( ArtSVP *svp, bool fill )
 	pattern->theight = pat.tileHeight();
 	pattern->buffer = pat.pixels();
 	pattern->opacity = fill ? short( m_fill->color().opacity() * 255.0 ) : short( m_stroke->color().opacity() * 255.0 );
-	pattern->angle = atan2( dy, dx );
+	pattern->angle = atan2( -dy, dx );
 
 	if( x0 != x1 && y0 != y1 )
 	{
@@ -696,7 +696,7 @@ VKoPainter::applyGradient( ArtSVP *svp, bool fill )
 		linear->stops = buildStopArray( gradient, offsets );
 		linear->n_stops = offsets;
 
-		if( x0 != x1 && y0 != y1 )
+		if( x0 != x1 && y0 != y1 && offsets >= 0 )
 		{
 			render = art_render_new( x0, y0, x1, y1, m_buffer + 4 * int(x0) + m_width * 4 * int(y0), m_width * 4, 3, 8, ART_ALPHA_PREMUL, 0 );
 			int opacity = int( opa * 255.0 );
@@ -750,7 +750,7 @@ VKoPainter::applyGradient( ArtSVP *svp, bool fill )
 		radial->stops = buildStopArray( gradient, offsets );
 		radial->n_stops = offsets;
 
-		if( x0 != x1 && y0 != y1 )
+		if( x0 != x1 && y0 != y1 && offsets >= 0 )
 		{
 			render = art_render_new( x0, y0, x1, y1, m_buffer + 4 * x0 + m_width * 4 * y0, m_width * 4, 3, 8, ART_ALPHA_PREMUL, 0 );
 			int opacity = int( opa * 255.0 );
@@ -791,7 +791,7 @@ VKoPainter::applyGradient( ArtSVP *svp, bool fill )
 		conical->stops = buildStopArray( gradient, offsets );
 		conical->n_stops = offsets;
 
-		if( x0 != x1 && y0 != y1 )
+		if( x0 != x1 && y0 != y1 && offsets >= 0 )
 		{
 			render = art_render_new( x0, y0, x1, y1, m_buffer + 4 * x0 + m_width * 4 * y0, m_width * 4, 3, 8, ART_ALPHA_PREMUL, 0 );
 			int opacity = int( opa * 255.0 );
@@ -871,7 +871,7 @@ VKoPainter::drawNode( const KoPoint& p, int width )
 {
 	if( !m_bDrawNodes ) return;
 
-	KoPoint _p( m_matrix.map( QPoint( p.x() * m_zoomFactor, p.y() * m_zoomFactor ) ) );
+	KoPoint _p( m_matrix.map( QPoint( int( p.x() * m_zoomFactor ), int( p.y() * m_zoomFactor ) ) ) );
 	int x1 = int( _p.x() - width );
 	int x2 = int( _p.x() + width );
 	int y1 = int( _p.y() - width );
@@ -899,12 +899,15 @@ VKoPainter::drawImage( const QImage &image, const QWMatrix &affine )
 {
 	// set up world matrix
 	double affineresult[6];
-	affineresult[0] = ( m_matrix.m11() * affine.m11() ) * m_zoomFactor;
-	affineresult[1] = affine.m12();
-	affineresult[2] = affine.m21();
-	affineresult[3] = ( m_matrix.m22() * affine.m22() ) * m_zoomFactor;
+
+	affineresult[0] = affine.m11() * m_matrix.m11() * m_zoomFactor + affine.m12() * m_matrix.m21();
+	affineresult[1] = (affine.m11() * m_matrix.m12() + affine.m12() * m_matrix.m22() ) * m_zoomFactor;
+	affineresult[2] = (affine.m21() * m_matrix.m11() + affine.m22() * m_matrix.m21() ) * m_zoomFactor;
+	affineresult[3] = affine.m22() * m_matrix.m22() * m_zoomFactor + affine.m21() * m_matrix.m12();
 	affineresult[4] = m_matrix.dx() + affine.dx() * m_zoomFactor;
-	affineresult[5] = m_matrix.dy() - ( affine.dy() ) * m_zoomFactor;
+	affineresult[5] = m_matrix.dy() - affine.dy() * m_zoomFactor;
+	
+	//art_affine_scale( affineresult, m_zoomFactor, m_zoomFactor);
 	/*kdDebug(38000) << "affineresult[0] : " << affineresult[0] << endl;
 	kdDebug(38000) << "affineresult[1] : " << affineresult[1] << endl;
 	kdDebug(38000) << "affineresult[2] : " << affineresult[2] << endl;
