@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VQPAINTER_H__
@@ -67,6 +67,8 @@ public:
 	virtual void setBrush( const QColor & );
 	virtual void setBrush( Qt::BrushStyle style );
 
+	virtual void drawImage( const QImage &, const QWMatrix & );
+
 	// stack management
 	virtual void save();
 	virtual void restore();
