@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VPOLYGON_H__
@@ -32,8 +32,11 @@ public:
 	virtual QString name() const;
 
 	virtual void save( QDomElement& element ) const;
-	virtual void saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles ) const;
+	virtual void saveOasis( KoStore *store, KoXmlWriter *docWriter, KoGenStyles &mainStyles, int &index ) const;
 	virtual void load( const QDomElement& element );
+	virtual bool loadOasis( const QDomElement &element, KoOasisLoadingContext &context );
+
+	virtual VPath* clone() const;
 
 protected:
 	void init();
