@@ -13,31 +13,31 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VPOLYGONTOOL_H__
 #define __VPOLYGONTOOL_H__
 
 #include <kdialogbase.h>
-#include <knuminput.h>
 
 #include "vshapetool.h"
 
-//class KoUnitDoubleSpinBox;
+class KoUnitDoubleSpinBox;
 class KIntSpinBox;
 
 
 class VPolygonTool : public VShapeTool
 {
 public:
-	VPolygonTool( KarbonPart *part );
+	VPolygonTool( KarbonView *view );
 	virtual ~VPolygonTool();
 
-	virtual QString name() { return i18n( "Polygon Tool" ); }
+	virtual void setup(KActionCollection *collection);
 	virtual bool showDialog() const;
-	
+	virtual QString uiname() { return i18n( "Polygon Tool" ); }
+
 	virtual VPath *shape( bool interactive = false ) const;
 
 	void refreshUnit();
@@ -48,7 +48,7 @@ private:
 	class VPolygonOptionsWidget : public KDialogBase
 	{
 	public:
-		VPolygonOptionsWidget( KarbonPart *part, QWidget *parent = 0L, const char *name = 0L );
+		VPolygonOptionsWidget( KarbonView *view, QWidget *parent = 0L, const char *name = 0L );
 
 		double radius() const;
 		uint edges() const;
@@ -58,9 +58,9 @@ private:
 		void refreshUnit();
 
 	private:
-		KDoubleSpinBox	*m_radius;
-		KIntSpinBox	*m_edges;
-		KarbonPart      *m_part;
+		KoUnitDoubleSpinBox		*m_radius;
+		KIntSpinBox			*m_edges;
+		KarbonView		        *m_view;
 	};
 
 	VPolygonOptionsWidget* m_optionsWidget;
