@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qlabel.h>
@@ -28,11 +28,11 @@
 #include <karbon_part.h>
 #include <shapes/vspiral.h>
 #include "vspiraltool.h"
-#include "koUnitWidgets.h"
+#include "KoUnitWidgets.h"
 
 
 VSpiralTool::VSpiralOptionsWidget::VSpiralOptionsWidget( KarbonPart *part, QWidget* parent, const char* name )
-	: KDialogBase( parent, name, true, i18n( "Insert Spiral" ), Ok | Cancel ), m_part(part)
+	: KDialogBase( parent, name, true, i18n( "Insert Spiral" ), Ok | Cancel ), m_part( part )
 {
 	QGroupBox *group = new QGroupBox( 2, Qt::Horizontal, i18n( "Properties" ), this );
 
@@ -42,8 +42,7 @@ VSpiralTool::VSpiralOptionsWidget::VSpiralOptionsWidget( KarbonPart *part, QWidg
 	m_type->insertItem( i18n( "Rectangular" ), 1 );
 
 	new QLabel( i18n( "Radius:" ), group );
-	m_radius = new KDoubleSpinBox( 0.0, 1000.0, 0.5, 5.0, 2, group );
-	//m_radius = new KoBuggyUnitDoubleSpinBox( group, 0.0, 1000.0, 0.5, 50.0, KoUnit::U_MM );
+	m_radius = new KoUnitDoubleSpinBox( group, 0.0, 1000.0, 0.5, 50.0, KoUnit::U_MM );
 	refreshUnit();
 	new QLabel( i18n( "Segments:" ), group );
 	m_segments = new KIntSpinBox( group );
@@ -97,7 +96,7 @@ VSpiralTool::VSpiralOptionsWidget::type() const
 void
 VSpiralTool::VSpiralOptionsWidget::setRadius( double value )
 {
-	m_radius->setValue( value );
+	m_radius->changeValue( value );
 }
 
 void
@@ -121,14 +120,14 @@ VSpiralTool::VSpiralOptionsWidget::setClockwise( bool value )
 void
 VSpiralTool::VSpiralOptionsWidget::refreshUnit()
 {
-	m_radius->setSuffix( KoUnit::unitName( m_part->unit() ) );
+	m_radius->setUnit( m_part->unit() );
 }
 
-VSpiralTool::VSpiralTool( KarbonPart *part )
-	: VShapeTool( part, i18n( "Insert Spiral" ), true )
+VSpiralTool::VSpiralTool( KarbonView *view )
+	: VShapeTool( view, "tool_spiral", true )
 {
 	// create config dialog:
-	m_optionsWidget = new VSpiralOptionsWidget( part );
+	m_optionsWidget = new VSpiralOptionsWidget( view->part() );
 	m_optionsWidget->setSegments( 8 );
 	m_optionsWidget->setFade( 0.8 );
 	m_optionsWidget->setClockwise( true );
@@ -174,7 +173,7 @@ VSpiralTool::shape( bool interactive ) const
 			new VSpiral(
 				0L,
 				m_p,
-				KoUnit::fromUserValue( m_optionsWidget->radius(), view()->part()->unit() ),
+				m_optionsWidget->radius(),
 				m_optionsWidget->segments(),
 				m_optionsWidget->fade(),
 				m_optionsWidget->clockwise(),
@@ -198,3 +197,17 @@ VSpiralTool::showDialog() const
 	return m_optionsWidget->exec() == QDialog::Accepted;
 }
 
+void
+VSpiralTool::setup( KActionCollection *collection )
+{
+	m_action = static_cast<KRadioAction *>(collection -> action( name() ) );
+
+	if( m_action == 0 )
+	{
+		m_action = new KRadioAction( i18n( "Spiral Tool" ), "14_spiral", Qt::SHIFT+Qt::Key_H, this, SLOT( activate() ), collection, name() );
+		m_action->setToolTip( i18n( "Spiral" ) );
+		m_action->setExclusiveGroup( "shapes" );
+		//m_ownAction = true;
+	}
+}
+
