@@ -13,34 +13,33 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VSPIRALTOOL_H__
 #define __VSPIRALTOOL_H__
 
 #include <kdialogbase.h>
-#include <knuminput.h>
 #include <klocale.h>
 
 #include "vshapetool.h"
 
 class KComboBox;
-//class KoUnitDoubleSpinBox;
+class KoUnitDoubleSpinBox;
 class KDoubleNumInput;
 class KIntSpinBox;
-class KarbonPart;
+class KarbonView;
 
 class VSpiralTool : public VShapeTool
 {
 public:
-	VSpiralTool( KarbonPart *part );
+	VSpiralTool( KarbonView *view );
 	virtual ~VSpiralTool();
 
+	virtual void setup(KActionCollection *collection);
 	virtual bool showDialog() const;
-	virtual QString name() { return i18n( "Spiral Tool" ); }
-	virtual QString icon() { return "14_spiral"; }
+	virtual QString uiname() { return i18n( "Spiral Tool" ); }
 
 	virtual VPath* shape( bool interactive = false ) const;
 
@@ -67,9 +66,9 @@ private:
 		void refreshUnit();
 
 	private:
-		KDoubleSpinBox	*m_radius;
+		KoUnitDoubleSpinBox		*m_radius;
 		KIntSpinBox			*m_segments;
-		KDoubleNumInput		*m_fade;
+		KDoubleNumInput			*m_fade;
 		KComboBox			*m_type;
 		KComboBox			*m_clockwise;
 		KarbonPart			*m_part;
