@@ -13,15 +13,15 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VSELECTOBJECTS_H__
 #define __VSELECTOBJECTS_H__
 
 
-#include "koRect.h"
+#include "KoRect.h"
 
 #include "vcomposite.h"
 #include "vgroup.h"
@@ -29,7 +29,7 @@
 #include "vimage.h"
 #include "vvisitor.h"
 
-/***
+/**
  * This visitor visits a selection and selects objects that are contained
  * in a paramater selection rectangle. For composites it makes a more accurate test, if the
  * selection rectangle intersects with any part of the composite, it is selected.
@@ -39,16 +39,17 @@ class VSelectObjects : public VVisitor
 {
 public:
 	VSelectObjects( VObjectList& selection, bool select = true )
-		: m_selection( selection ), m_select( select ) {}
+		: m_selection( selection ), m_select( select ), m_insideGroups( false ) {}
 
 	VSelectObjects( VObjectList& selection, const KoRect& rect, bool select = true )
-		: m_selection( selection ), m_select( select ), m_rect( rect ) {}
+		: m_selection( selection ), m_select( select ), m_rect( rect ), m_rectMode( true ), m_insideGroups( false ) { }
 
-	virtual void visitVGroup( VGroup& group )
-		{ visitVObject( group ); }
+	VSelectObjects( VObjectList& selection, const KoPoint& point, bool select = true, bool insideGroups = false )
+		: m_selection( selection ), m_select( select ), m_point( point ), m_rectMode( false ), m_insideGroups( insideGroups )  {}
+
+	virtual void visitVGroup( VGroup& group );
 	virtual void visitVPath( VPath& composite );
-	virtual void visitVText( VText& text )
-		{ visitVObject( text ); }
+	virtual void visitVText( VText& text );
 	virtual void visitVImage( VImage& img )
 		{ visitVObject( img ); }
 	virtual void visitVLayer( VLayer& layer );
@@ -61,6 +62,9 @@ private:
 	bool m_select;
 
 	KoRect m_rect;
+	KoPoint m_point;
+	bool m_rectMode;
+	bool m_insideGroups;
 };
 
 #endif
