@@ -13,22 +13,22 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __VTRANSFORMNODES_H__
 #define __VTRANSFORMNODES_H__
 
 #include <qwmatrix.h>
-
+#include <koffice_export.h>
 #include "vvisitor.h"
 
 
 class VSegment;
 
 
-class VTransformNodes : public VVisitor
+class KARBONBASE_EXPORT VTransformNodes : public VVisitor
 {
 public:
 	VTransformNodes( const QWMatrix& m );
