@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "kchartColorConfigPage.h"
@@ -31,13 +31,18 @@
 #include <qhbox.h>
 #include <klistbox.h>
 #include "kchart_params.h"
+#include <kdebug.h>
+
+namespace KChart
+{
 
 KChartColorConfigPage::KChartColorConfigPage( KChartParams* params,
-                                              QWidget* parent, KoChart::Data *dat ) :
+                                              QWidget* parent, 
+					      KDChartTableData *dat ) :
     QWidget( parent ),
-    _params( params ),
-    index( 0 ),
-    data( dat )
+    m_params( params ),
+    m_data( dat ),
+    index( 0 )
 {
     QWhatsThis::add( this, i18n( "This page lets you configure the colors "
                                  "in which your chart is displayed. Each "
@@ -98,6 +103,7 @@ KChartColorConfigPage::KChartColorConfigPage( KChartParams* params,
     QWhatsThis::add( ytitleLA, wtstr );
     QWhatsThis::add( _ytitleCB, wtstr );
 
+#if 0
     QLabel* ytitle2LA = new QLabel( i18n( "Y-title color (2nd axis):" ), gb );
     ytitle2LA->setAlignment( AlignRight | AlignVCenter );
     grid->addWidget( ytitle2LA, 4, 0 );
@@ -110,29 +116,31 @@ KChartColorConfigPage::KChartColorConfigPage( KChartParams* params,
                   "overrides the setting <i>Title Color</i>." );
     QWhatsThis::add( ytitle2LA, wtstr );
     QWhatsThis::add( _ytitle2CB, wtstr );
+#endif
 
     QLabel* xlabelLA = new QLabel( i18n( "X-label color:" ), gb );
     xlabelLA->setAlignment( AlignRight | AlignVCenter );
-    grid->addWidget( xlabelLA, 5, 0 );
+    grid->addWidget( xlabelLA, 4, 0 );
     _xlabelCB = new KColorButton( gb );
     xlabelLA->setBuddy( _xlabelCB );
-    grid->addWidget( _xlabelCB, 5, 1 );
+    grid->addWidget( _xlabelCB, 4, 1 );
     wtstr = i18n( "Here you can configure the color that is used for "
-                  "labelling the X (horizontal) axis" );
+                  "labeling the X (horizontal) axis" );
     QWhatsThis::add( xlabelLA, wtstr );
     QWhatsThis::add( _xlabelCB, wtstr );
 
     QLabel* ylabelLA = new QLabel( i18n( "Y-label color:" ), gb );
     ylabelLA->setAlignment( AlignRight | AlignVCenter );
-    grid->addWidget( ylabelLA, 6, 0 );
+    grid->addWidget( ylabelLA, 5, 0 );
     _ylabelCB = new KColorButton( gb );
     ylabelLA->setBuddy( _ylabelCB );
-    grid->addWidget( _ylabelCB, 6, 1 );
+    grid->addWidget( _ylabelCB, 5, 1 );
     wtstr = i18n( "Here you can configure the color that is used for "
-                  "labelling the Y (vertical) axis" );
+                  "labeling the Y (vertical) axis" );
     QWhatsThis::add( ylabelLA, wtstr );
     QWhatsThis::add( _ylabelCB, wtstr );
 
+#if 0
     QLabel* ylabel2LA = new QLabel( i18n( "Y-label color (2nd axis):" ), gb );
     ylabel2LA->setAlignment( AlignRight | AlignVCenter );
     grid->addWidget( ylabel2LA, 7, 0 );
@@ -140,17 +148,19 @@ KChartColorConfigPage::KChartColorConfigPage( KChartParams* params,
     ylabel2LA->setBuddy( _ylabel2CB );
     grid->addWidget( _ylabel2CB, 7, 1 );
     wtstr = i18n( "Here you can configure the color that is used for "
-                  "labelling the second Y (vertical) axis. Of course, "
+                  "labeling the second Y (vertical) axis. Of course, "
                   "this setting only takes effect if the chart is "
                   "configured to have two vertical axes." );
     QWhatsThis::add( ylabel2LA, wtstr );
     QWhatsThis::add( _ylabel2CB, wtstr );
+#endif
 
     QHBox* dataColorHB = new QHBox( gb );
     grid->addMultiCellWidget( dataColorHB,  0, 7, 2, 2 );
     _dataColorLB = new KListBox(dataColorHB);
     _dataColorCB = new KColorButton( dataColorHB);
-
+    wtstr = i18n( "Choose a row/column in the list on the left and change its color using this button.");
+    QWhatsThis::add( _dataColorCB, wtstr );
     initDataColorList();
     connect( _dataColorLB, SIGNAL(highlighted(int )), this, SLOT(changeIndex(int)));
     connect( _dataColorLB, SIGNAL(doubleClicked ( QListBoxItem * )), this, SLOT(activeColorButton()));
@@ -182,7 +192,7 @@ KChartColorConfigPage::KChartColorConfigPage( KChartParams* params,
 
 void KChartColorConfigPage::changeIndex(int newindex)
 {
-    if(index>_params->maxDataColor())
+    if(index > m_params->maxDataColor())
         _dataColorLB->setEnabled(false);
     else
     {
@@ -204,25 +214,35 @@ void KChartColorConfigPage::activeColorButton()
 void KChartColorConfigPage::initDataColorList()
 {
     QStringList lst;
-    for(uint i =0;i<data->rows();i++)
+    for(uint i = 0; i < m_data->rows(); i++)
     {
-        extColor.resize( _params->maxDataColor() );
-
-        if(i<_params->maxDataColor())
-	{
-            _dataColorLB->insertItem(_params->legendText( i ).isEmpty() ? i18n("Series %1").arg(i+1) :_params->legendText( i ) );
-        	extColor[i] =_params->dataColor(i);
-	}
+        extColor.resize( m_params->maxDataColor() );
+        if(i<m_params->maxDataColor())
+        {
+            _dataColorLB->insertItem(m_params->legendText( i ).isEmpty() ? i18n("Series %1").arg(i+1) :m_params->legendText( i ) );
+            extColor[i] =m_params->dataColor(i);
+        }
     }
     _dataColorLB->setCurrentItem(0);
-    _dataColorCB->setColor( extColor[index]);
+
+	 //Fix crash when we didn't create data
+	if ( m_data->rows() == 0 )
+		_dataColorCB->setEnabled(false);
+	else
+    	_dataColorCB->setColor( extColor[index]);
 }
 
 
 void KChartColorConfigPage::apply()
 {
+	//Nothing to save
+	if ( m_data->rows() == 0 )
+		return;
+
     extColor[index] = _dataColorCB->color();
-    for(uint i =0;i<data->rows();i++)
-        if(i<_params->maxDataColor())
-            _params->setDataColor(i,extColor[i]);
+    for(uint i =0;i<m_data->rows();i++)
+        if(i<m_params->maxDataColor())
+            m_params->setDataColor(i,extColor[i]);
 }
+
+}  //KChart namespace
