@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 
@@ -32,6 +32,7 @@
 #include <qradiobutton.h>
 #include <qvbuttongroup.h>
 #include <kfontdialog.h>
+#include <qwhatsthis.h>
 
 #include "kdchart/KDChartAxisParams.h"
 #include "kchart_params.h"
@@ -54,13 +55,16 @@ KChartParameterConfigPage::KChartParameterConfigPage( KChartParams* params,
     QGridLayout *grid1 = new QGridLayout(gb1->layout(),9,1);
 
     grid = new QCheckBox( i18n( "Grid" ), gb1 );
+    QWhatsThis::add(grid, i18n("If this is checked, the grid is shown. If you uncheck this option, the grid will not be displayed anymore."));
     grid1->addWidget(grid, 0, 0);
 
     yaxis = new QCheckBox( i18n( "Y-axis" ), gb1);
+    QWhatsThis::add(yaxis, i18n("If this is checked, the Y-axis is shown. If you uncheck this option, the Y-axis and the Y grid lines will not be displayed anymore."));
     connect( yaxis, SIGNAL( clicked() ), this, SLOT( axisChanged() ) );
     grid1->addWidget(yaxis, 1, 0);
 
     xaxis = new QCheckBox( i18n( "X-axis" ), gb1 );
+    QWhatsThis::add(xaxis, i18n("If this is checked, the X-axis is shown. If you uncheck this option, the X-axis and the X grid lines will not be displayed anymore."));
     connect( xaxis, SIGNAL( clicked() ), this, SLOT( axisChanged() ) );
     grid1->addWidget(xaxis, 2, 0);
 
@@ -97,9 +101,11 @@ KChartParameterConfigPage::KChartParameterConfigPage( KChartParams* params,
 
     QHBoxLayout * bottom = new QHBoxLayout( this );
     xtitle= new QLineEdit( gb2 );
+    QWhatsThis::add(xtitle, i18n("Write the title for the X-axis here, if you want a title. The color for this title is set in the Colors tab, in the same dialog, and the font is set in the Font tab."));
     bottom->addWidget(xtitle);
     QBoxLayout * l = new QVBoxLayout( this );
     ytitle= new QLineEdit( gb2 );
+    QWhatsThis::add(ytitle, i18n("Write the title for the Y-axis here, if you want a title. The color for this title is set in the Colors tab, in the same dialog, and the font is set in the Font tab."));
     bottom->addWidget(ytitle);
 
     l->addLayout(top);
@@ -109,18 +115,23 @@ KChartParameterConfigPage::KChartParameterConfigPage( KChartParams* params,
     // Linear or logarithmic scale
     QVButtonGroup *scaletype = new QVButtonGroup(i18n("Scale Types"), gb2);
     lin = new QRadioButton( i18n("Linear scale"), scaletype);
+    QWhatsThis::add(lin, i18n("This sets the Y-axis to be linear. This is default."));
     log = new QRadioButton( i18n("Logarithmic scale"), scaletype);
+    QWhatsThis::add(log, i18n("This sets the Y-axis to be logarithmic."));
     grid2->addWidget(scaletype, 1, 0);
 
     // Decimal precision
     QVButtonGroup *precision = new QVButtonGroup(i18n("Precision for Numerical Left Axis"), gb2);
     grid2->addWidget(precision, 2, 0);
     QRadioButton * automatic_precision = new QRadioButton( i18n("Automatic precision"), precision);
+    QWhatsThis::add(automatic_precision, i18n("This sets the precision as automatic which means that KChart decides what precision to apply."));
     automatic_precision->setChecked(true);
     max = new QRadioButton( i18n("Decimal precision:"), precision);
+    QWhatsThis::add(max, i18n("This sets the Y-axis precision. For example, if you choose a precision of 2, the value 5 will be displayed as 5.00 alongside the Y-axis."));
     connect(automatic_precision, SIGNAL(toggled(bool)), this,
             SLOT(automatic_precision_toggled(bool)) );
     maximum_length = new QSpinBox(0, 15, 1, precision );
+    QWhatsThis::add(maximum_length, i18n("Set the precision you want to display for the Y-axis, if you choose Decimal precision. The range is 0 to 15; 2 being the default."));
     maximum_length->setValue(2);
 
 #if 0
@@ -237,7 +248,7 @@ void KChartParameterConfigPage::init()
 	log->setChecked(true);
     
      if ( _params->axisParams( KDChartAxisParams::AxisPosLeft ).axisDigitsBehindComma() ==
-            KDChartAxisParams::AXIS_LABELS_AUTO_DIGITS )
+            KDCHART_AXIS_LABELS_AUTO_DIGITS )
         maximum_length->setEnabled(false);
     else
     {
@@ -310,8 +321,8 @@ void KChartParameterConfigPage::apply()
 
     // Set the scale for the Y axis (linear / logarithmic)
     {
-	KDChartAxisParams  params
-	    = _params->axisParams( KDChartAxisParams::AxisPosLeft );
+        KDChartAxisParams  params;
+        params = _params->axisParams( KDChartAxisParams::AxisPosLeft );
 
         if (lin->isChecked())
             params.setAxisCalcMode(KDChartAxisParams::AxisCalcLinear);
@@ -321,7 +332,7 @@ void KChartParameterConfigPage::apply()
             {
                 // Since in this version of kdChart logarithmic scales only work for Line charts,
                 // lets switch now
-                _params->setChartType( KDChartParams::Line );
+                _params->setChartType( KChartParams::Line );
             }
             params.setAxisCalcMode(KDChartAxisParams::AxisCalcLogarithmic);
         }
@@ -329,7 +340,7 @@ void KChartParameterConfigPage::apply()
         if ( maximum_length->isEnabled() )
             params.setAxisDigitsBehindComma( maximum_length->value() );
         else
-            params.setAxisDigitsBehindComma(KDChartAxisParams::AXIS_LABELS_AUTO_DIGITS );
+            params.setAxisDigitsBehindComma( KDCHART_AXIS_LABELS_AUTO_DIGITS );
 
         _params->setAxisParams( KDChartAxisParams::AxisPosLeft, params );
     }
