@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __KCHARTPARAMETERPOLARCONFIGPAGE_H__
@@ -28,6 +28,9 @@ class QLineEdit;
 class QSpinBox;
 class QCheckBox;
 
+namespace KChart
+{
+
 class KChartParams;
 
 class KChartParameterPolarConfigPage : public QWidget
@@ -45,4 +48,6 @@ private:
     QSpinBox *angle, *lineWidth;
 };
 
+}  //KChart namespace
+
 #endif
