@@ -4,23 +4,13 @@
  */
 
 
-#include "kdchart/KDChart.h"
-#include "kchart_view.h"
-#include "kchart_factory.h"
-#include "kchart_part.h"
-#include "kchartWizard.h"
-#include "kchartDataEditor.h"
-#include "kchartConfigDialog.h"
-#include "KChartViewIface.h"
-#include "kchartPageLayout.h"
-#include "kchart_params.h"
-#include "kchartPrinterDlg.h"
-#include "csvimportdialog.h"
-
 #include <qfile.h>
 #include <qpainter.h>
 #include <qcursor.h>
 #include <qpopupmenu.h>
+#include <qpaintdevicemetrics.h>
+#include <qcstring.h> // For QByteArray
+
 #include <kaction.h>
 #include <kglobal.h>
 #include <klocale.h>
@@ -31,12 +21,24 @@
 #include <ktempfile.h>
 #include <dcopobject.h>
 #include <kxmlguifactory.h>
-#include <qpaintdevicemetrics.h>
-#include <qcstring.h> // For QByteArray
 #include <kfiledialog.h>
 #include <kmessagebox.h>
 
-#include <koTemplateCreateDia.h>
+#include <KoTemplateCreateDia.h>
+
+#include "kdchart/KDChart.h"
+#include "kchart_view.h"
+#include "kchart_factory.h"
+#include "kchart_part.h"
+#include "kchart_params.h"
+#include "kchartWizard.h"
+#include "kchartDataEditor.h"
+#include "kchartConfigDialog.h"
+#include "KChartViewIface.h"
+#include "kchartPageLayout.h"
+#include "kchartPrinterDlg.h"
+#include "csvimportdialog.h"
+
 
 using namespace std;
 
@@ -50,6 +52,10 @@ namespace KChart
 KChartView::KChartView( KChartPart* part, QWidget* parent, const char* name )
     : KoView( part, parent, name )
 {
+
+    // No flicker
+    setBackgroundMode( Qt::NoBackground );
+
     setInstance( KChartFactory::global() );
     if ( koDocument()->isReadWrite() )
         setXMLFile( "kchart.rc" );
@@ -73,9 +79,10 @@ KChartView::KChartView( KChartPart* part, QWidget* parent, const char* name )
                             this, SLOT( wizard() ),
                             actionCollection(), "wizard");
     m_edit = new KAction( i18n("Edit &Data..."), "edit", 0,
-                          this, SLOT( edit() ),
-                          actionCollection(), "edit");
-    m_config = new KAction( i18n( "&Configure Chart..." ), "configure", 0,
+                          this, SLOT( editData() ),
+                          actionCollection(), "editdata");
+    m_config = new KAction( i18n( "&Chart..." ), "configure", 0,
+
                             this, SLOT( slotConfig() ),
                             actionCollection(), "config" );
 
@@ -122,31 +129,31 @@ KChartView::KChartView( KChartPart* part, QWidget* parent, const char* name )
     m_chartpolar->setExclusiveGroup( "charttypes" );
 
     // Configuration KActions
-    m_colorConfig = new KAction( i18n( "&Configure Colors..." ), 0,
+    m_colorConfig = new KAction( i18n( "&Colors..." ), 0,
                             this, SLOT( slotConfigColor() ),
                             actionCollection(), "color_config" );
 
-    m_fontConfig = new KAction( i18n( "&Configure Font..." ), 0,
+    m_fontConfig = new KAction( i18n( "&Font..." ), 0,
                             this, SLOT( slotConfigFont() ),
                             actionCollection(), "font_config" );
 
-    m_backConfig = new KAction( i18n( "&Configure Background..." ), 0,
+    m_backConfig = new KAction( i18n( "&Background..." ), 0,
                             this, SLOT( slotConfigBack() ),
                             actionCollection(), "back_config" );
 
-    m_legendConfig = new KAction( i18n( "&Configure Legend..." ), 0,
+    m_legendConfig = new KAction( i18n( "&Legend..." ), 0,
                             this, SLOT( slotConfigLegend() ),
                             actionCollection(), "legend_config" );
 
-    m_subTypeChartConfig = new KAction( i18n( "&Configure Sub Type Chart..." ), 0,
+    m_subTypeChartConfig = new KAction( i18n( "Chart &Sub-type..." ), 0,
                             this, SLOT( slotConfigSubTypeChart() ),
                             actionCollection(), "legend_subtype" );
 
-    m_dataFormatConfig = new KAction( i18n( "&Configure Data Format..." ), 0,
+    m_dataFormatConfig = new KAction( i18n( "&Data Format..." ), 0,
                             this, SLOT( slotConfigDataFormat() ),
                             actionCollection(), "data_format" );
 
-    m_headerFooterConfig = new KAction( i18n( "&Configure Header Footer..." ), 0,
+    m_headerFooterConfig = new KAction( i18n( "&Header && Footer..." ), 0,
                             this, SLOT( slotConfigHeaderFooterChart() ),
                             actionCollection(), "headerfooter_subtype" );
 
@@ -185,18 +192,13 @@ DCOPObject* KChartView::dcopObject()
 
 void KChartView::paintEvent( QPaintEvent* /*ev*/ )
 {
-    QPainter painter;
-    painter.begin( this );
+    QPainter painter( this );
 
     // ### TODO: Scaling
 
     // Let the document do the drawing
-    // PENDING(kalle) Do double-buffering if we are a widget
-    //    part()->paintEverything( painter, ev->rect(), FALSE, this );
-    // paint everything
-    koDocument()->paintEverything( painter, rect(), FALSE, this );
-
-    painter.end();
+    // This calls KChartPart::paintContent, basically.
+    koDocument()->paintEverything( painter, rect(), false, this );
 }
 
 
@@ -212,22 +214,22 @@ void KChartView::updateReadWrite( bool /*readwrite*/ )
 // This opens a spreadsheet like editor with the data in it.
 //
 
-void KChartView::edit()
+void KChartView::editData()
 {
-    kchartDataEditor  ed(this);
-    //KChartParams     *params=((KChartPart*)koDocument())->params();
-
-    KoChart::Data    *dat = (( (KChartPart*)koDocument())->data());
+    kchartDataEditor   ed(this);
+    KChartParams      *params = ((KChartPart*)koDocument())->params();
+    KDChartTableData  *dat    = ((KChartPart*)koDocument())->data();
 
     kdDebug(35001) << "***Before calling editor: cols =" << dat->cols()
 		   << " , rows = "     << dat->rows()
 		   << " , usedCols = " << dat->usedCols()
 		   << "  usedRows = "  << dat->usedRows() << endl;
 
-    ed.setData(dat);
+    ed.setData( params, dat );
     ed.setRowLabels(((KChartPart*)koDocument())->rowLabelTexts());
     ed.setColLabels(((KChartPart*)koDocument())->colLabelTexts());
 
+    // Activate the Apply button in the editor.
     connect(&ed,  SIGNAL(applyClicked(kchartDataEditor *)),
 	    this, SLOT(applyEdit(kchartDataEditor *)));
 
@@ -239,7 +241,7 @@ void KChartView::edit()
     return;
 
     // Get the data and legend back.
-    ed.getData(dat);
+    ed.getData(params, dat);
     ed.getRowLabels(((KChartPart*)koDocument())->rowLabelTexts());
     ed.getColLabels(((KChartPart*)koDocument())->colLabelTexts());
     ((KChartPart*)koDocument())->setModified(true);
@@ -248,7 +250,7 @@ void KChartView::edit()
 		   << " , rows = "     << dat->rows()
 		   << " , usedCols = " << dat->usedCols()
 		   << "  usedRows = "  << dat->usedRows() << endl;
-    repaint();
+    update();
 }
 
 
@@ -257,24 +259,26 @@ void KChartView::applyEdit(kchartDataEditor *ed)
     if (!ed->modified())
 	return;
 
-    ed->getData(( (KChartPart*)koDocument())->data());
+    ed->getData( ((KChartPart*)koDocument())->params(), 
+		 ((KChartPart*)koDocument())->data() );
     ed->getRowLabels(((KChartPart*)koDocument())->rowLabelTexts());
     ed->getColLabels(((KChartPart*)koDocument())->colLabelTexts());
+
     ((KChartPart*)koDocument())->setModified(true);
 
-    repaint();
+    update();
 }
 
 
 void KChartView::wizard()
 {
     kdDebug(35001) << "Wizard called" << endl;
-    KChartWizard *wiz = new KChartWizard((KChartPart*)koDocument(), this, 
+    KChartWizard *wiz = new KChartWizard((KChartPart*)koDocument(), this,
 					 "KChart Wizard", true);
     kdDebug(35001) << "Executed. Now, display it" << endl;
     if (wiz->exec()) {
 	((KChartPart*)koDocument())->setModified(true);
-        repaint();
+        update();
         updateGuiTypeOfChart();
         kdDebug(35001) << "Ok, executed..." << endl;
     }
@@ -330,10 +334,10 @@ void KChartView::config(int flags)
 {
     // open a config dialog depending on the chart type
     KChartParams        *params = ((KChartPart*)koDocument())->params();
-    KoChart::Data       *dat    = ((KChartPart*)koDocument())->data();
-    KChartAuxiliary     *aux    = ((KChartPart*)koDocument())->auxdata();
+    KDChartTableData    *dat    = ((KChartPart*)koDocument())->data();
+
     KChartConfigDialog  *d      = new KChartConfigDialog( params, this, flags,
-							  dat, aux );
+							  dat );
 
     connect( d, SIGNAL( dataChanged() ),
              this, SLOT( slotRepaint() ) );
@@ -345,7 +349,7 @@ void KChartView::config(int flags)
 void KChartView::slotRepaint()
 {
     ((KChartPart*)koDocument())->setModified(true);
-    repaint();
+    update();
 }
 
 
@@ -365,7 +369,7 @@ void KChartView::loadConfig()
 
     updateGuiTypeOfChart();
     //refresh chart when you load config
-    repaint();
+    update();
 }
 
 
@@ -373,7 +377,7 @@ void KChartView::defaultConfig()
 {
     ((KChartPart*)koDocument())->defaultConfig(  );
     updateGuiTypeOfChart();
-    repaint();
+    update();
 }
 
 
@@ -383,13 +387,13 @@ void KChartView::pieChart()
 	forceAxisParams(false);
 	KChartParams  *params = ((KChartPart*)koDocument())->params();
 
-	params->setChartType( KDChartParams::Pie );
+	params->setChartType( KChartParams::Pie );
 	params->setThreeDPies(params->threeDBars());
 	params->setExplodeFactor( 0 );
 	params->setExplode( true );
 
 	updateButton();
-	repaint();
+	update();
 	((KChartPart*)koDocument())->setModified(true);
     }
     else
@@ -398,8 +402,9 @@ void KChartView::pieChart()
 
 void KChartView::forceAxisParams(bool lineMode) {
     KChartParams  *params = ((KChartPart*)koDocument())->params();
-    KDChartAxisParams  axisParams = params->axisParams( KDChartAxisParams::AxisPosLeft );
-    if(params->chartType() == KDChartParams::Line)
+    KDChartAxisParams  axisParams;
+    axisParams = params->axisParams( KDChartAxisParams::AxisPosLeft );
+    if(params->chartType() == KChartParams::Line)
         m_logarithmicScale = axisParams.axisCalcMode();
     if(lineMode) {
         if(m_logarithmicScale)
@@ -415,11 +420,11 @@ void KChartView::lineChart()
 	forceAxisParams(true);
 	KChartParams* params = ((KChartPart*)koDocument())->params();
 
-	params->setChartType( KDChartParams::Line );
+	params->setChartType( KChartParams::Line );
 	params->setLineChartSubType( KDChartParams::LineNormal );
 
 	updateButton();
-	repaint();
+	update();
 	((KChartPart*)koDocument())->setModified(true);
     }
     else
@@ -434,12 +439,12 @@ void KChartView::barsChart()
 	forceAxisParams(false);
 	KChartParams* params = ((KChartPart*)koDocument())->params();
 
-	params->setChartType( KDChartParams::Bar );
+	params->setChartType( KChartParams::Bar );
 	params->setBarChartSubType( KDChartParams::BarNormal );
 
 	updateButton();
     params->setThreeDBars( params->threeDPies() );
-	repaint();
+	update();
 	((KChartPart*)koDocument())->setModified(true);
     }
     else
@@ -453,11 +458,11 @@ void KChartView::areasChart()
 	forceAxisParams(false);
 	KChartParams* params = ((KChartPart*)koDocument())->params();
 
-	params->setChartType( KDChartParams::Area );
+	params->setChartType( KChartParams::Area );
 	params->setAreaChartSubType( KDChartParams::AreaNormal );
 
 	updateButton();
-	repaint();
+	update();
 	((KChartPart*)koDocument())->setModified(true);
     }
     else
@@ -472,11 +477,11 @@ void KChartView::hiLoChart()
 	forceAxisParams(false);
 	KChartParams* params = ((KChartPart*)koDocument())->params();
 
-	params->setChartType( KDChartParams::HiLo );
+	params->setChartType( KChartParams::HiLo );
 	params->setHiLoChartSubType( KDChartParams::HiLoNormal );
 
 	updateButton();
-	repaint();
+	update();
 	((KChartPart*)koDocument())->setModified(true);
     }
     else
@@ -490,10 +495,10 @@ void KChartView::ringChart()
 	forceAxisParams(false);
 	KChartParams* params = ((KChartPart*)koDocument())->params();
 
-	params->setChartType( KDChartParams::Ring );
+	params->setChartType( KChartParams::Ring );
 
 	updateButton();
-	repaint();
+	update();
 	((KChartPart*)koDocument())->setModified(true);
     }
     else
@@ -511,7 +516,7 @@ void KChartView::polarChart()
         params->setChartType( KDChartParams::Polar );
         params->setPolarChartSubType( KDChartParams::PolarNormal );
 
-        repaint();
+        update();
 	((KChartPart*)koDocument())->setModified(true);
     }
     else
@@ -528,7 +533,7 @@ void KChartView::bwChart()
         params->setChartType( KDChartParams::BoxWhisker );
         params->setBWChartSubType( KDChartParams::BWNormal );
 
-        repaint();
+        update();
 	((KChartPart*)koDocument())->setModified(true);
     }
     else
@@ -591,56 +596,67 @@ void KChartView::updateButton()
     // Disable sub chart config item.
     KChartParams* params = ((KChartPart*)koDocument())->params();
 
-    bool state=(params->chartType()==KDChartParams::Bar ||
-                params->chartType()==KDChartParams::Area ||
-                params->chartType()==KDChartParams::Line ||
-                params->chartType()==KDChartParams::HiLo ||
-                params->chartType()==KDChartParams::Polar);
+    bool state=(params->chartType()==KChartParams::Bar ||
+                params->chartType()==KChartParams::Area ||
+                params->chartType()==KChartParams::Line ||
+                params->chartType()==KChartParams::HiLo ||
+                params->chartType()==KChartParams::Polar);
     m_subTypeChartConfig->setEnabled(state);
 }
 
 
 void KChartView::slotConfigPageLayout()
 {
-    KChartParams* params = ((KChartPart*)koDocument())->params();
-    KChartPageLayout *dialog=new KChartPageLayout(params,this,"Page Layout");
+    KChartParams      *params = ((KChartPart*)koDocument())->params();
+    KChartPageLayout  *dialog = new KChartPageLayout(params, this,
+						     "Page Layout");
 
     connect( dialog, SIGNAL( dataChanged() ),
-             this, SLOT( slotRepaint() ) );
+             this,   SLOT( slotRepaint() ) );
 
     dialog->exec();
     delete dialog;
 }
 
+
 void KChartView::setupPrinter( KPrinter &printer )
 {
   if ( !printer.previewOnly() )
     printer.addDialogPage( new KChartPrinterDlg( 0, "KChart page" ) );
 }
 
+
 void KChartView::print(KPrinter &printer)
 {
-  printer.setFullPage( false );
-  QPainter painter;
-  painter.begin(&printer);
-  QPaintDeviceMetrics pdm( &printer );
-  int height, width;
-  if ( !printer.previewOnly() )
-  {
-    	int const scalex = printer.option("kde-kchart-printsizex").toInt();
-	int const scaley = printer.option("kde-kchart-printsizey").toInt();
-	// FIXME: Losing precision here.  First multiply, then divide.
-	width = (double)pdm.width()/100*scalex;
-	height = (double)pdm.height()/100*scaley;
-  }
-  else
-  { //fill the whole page
-	width = pdm.width();
-	height = pdm.height();
-  }
+    printer.setFullPage( false );
 
-  KDChart::print(&painter,((KChartPart*)koDocument())->params(),((KChartPart*)koDocument())->data(),0, new QRect(0,0, width, height));
-  painter.end();
+    QPainter painter;
+    painter.begin(&printer);
+    QPaintDeviceMetrics  pdm( &printer );
+
+    int  height;
+    int  width;
+    if ( !printer.previewOnly() ) {
+	int const scalex = printer.option("kde-kchart-printsizex").toInt();
+	int const scaley = printer.option("kde-kchart-printsizey").toInt();
+
+	width  = pdm.width()  * scalex / 100;
+	height = pdm.height() * scaley / 100;
+    }
+    else {
+	// Fill the whole page.
+	width  = pdm.width();
+	height = pdm.height();
+    }
+
+    QRect  rect(0, 0, width, height);
+    KDChart::print(&painter,
+		   ((KChartPart*)koDocument())->params(),
+		   ((KChartPart*)koDocument())->data(),
+		   0, 		// regions
+		   &rect);
+
+    painter.end();
 }
 
 
@@ -655,7 +671,7 @@ void KChartView::importData()
 						    0,
 						    i18n("Import Data"));
     kdDebug(35001) << "Filename = <" << filename << ">" << endl;
-    if (filename == "")
+    if (filename.isEmpty())
       return;
 
     // Check to see if we can read the file.
@@ -687,38 +703,38 @@ void KChartView::importData()
     bool  hasRowHeaders = ( rows > 1 && dialog->firstRowContainHeaders() );
     bool  hasColHeaders = ( cols > 1 && dialog->firstColContainHeaders() );
 
-    KoChart::Data  data( rows, cols );
+    KDChartTableData  data( rows, cols );
     data.setUsedRows( rows );
     data.setUsedCols( cols );
     for (uint row = 0; row < rows; row++) {
-      for (uint col = 0; col < cols; col++) {
-	bool     ok;
-	QString  tmp;
-	double   val;
+	for (uint col = 0; col < cols; col++) {
+	    bool     ok;
+	    QString  tmp;
+	    double   val;
 
-	// Get the text and convert to double unless in the headers.
-	tmp = dialog->text( row, col );
-	if ( ( row == 0 && hasRowHeaders )
-	     || ( col == 0 && hasColHeaders ) ) {
-	  kdDebug(35001) << "Setting header (" << row << "," << col
-			 << ") to value " << tmp << endl;
-	  data.setCell( row, col, KoChart::Value( tmp ) );
+	    // Get the text and convert to double unless in the headers.
+	    tmp = dialog->text( row, col );
+	    if ( ( row == 0 && hasRowHeaders )
+		 || ( col == 0 && hasColHeaders ) ) {
+		kdDebug(35001) << "Setting header (" << row << "," << col
+			       << ") to value " << tmp << endl;
+		data.setCell( row, col, tmp );
+	    }
+	    else {
+		val = tmp.toDouble(&ok);
+		if (!ok)
+		    val = 0.0;
+
+		kdDebug(35001) << "Setting (" << row << "," << col
+			       << ") to value " << val << endl;
+
+		// and do the actual setting.
+		data.setCell( row, col, val );
+	    }
 	}
-	else {
-	  val = tmp.toDouble(&ok);
-	  if (!ok)
-	    val = 0.0;
-
-	  kdDebug(35001) << "Setting (" << row << "," << col
-			 << ") to value " << val << endl;
-
-	  // and do the actual setting.
-	  data.setCell( row, col, KoChart::Value( val ) );
-	}
-      }
     }
 
-    ((KChartPart*)koDocument())->doSetData( data, 
+    ((KChartPart*)koDocument())->doSetData( data,
 					    hasRowHeaders, hasColHeaders );
 }
 
