@@ -1,5 +1,5 @@
 /* -*- Mode: C++ -*-
-   $Id: KDGanttView.h 380679 2005-01-21 06:27:11Z danders $
+   $Id: KDGanttView.h 523435 2006-03-28 08:01:15Z mlaurent $
    KDChart - a multi-platform charting engine
 */
 
@@ -324,7 +324,7 @@ public:
     virtual void lvStartDrag (KDGanttViewItem*);
     virtual bool lvDragMoveEvent (QDragMoveEvent * e,KDGanttViewItem*, KDGanttViewItem*);
     virtual void lvDragEnterEvent (QDragEnterEvent * e );
-    QSize sizeHint();
+    virtual QSize sizeHint() const;
     KDGanttViewItem* getItemByName( const QString& name ) const;
     QDateTime getDateTimeForCoordX(int coordX, bool global = true ) const;
     KDGanttViewItem* getItemByListViewPos( const QPoint& pos ) const;
