@@ -12,7 +12,6 @@
 ** This header file defines the interface that the SQLite library
 ** presents to client programs.
 **
-** @(#) $Id: sqlite3.h 410099 2005-05-06 17:52:07Z staniek $
 */
 #ifndef _SQLITE3_H_
 #define _SQLITE3_H_
@@ -160,6 +159,10 @@ int sqlite3_exec(
 #define SQLITE_ROW         100  /* sqlite3_step() has another row ready */
 #define SQLITE_DONE        101  /* sqlite3_step() has finished executing */
 
+/* js: Used in sqlite3OsOpenReadWrite() */
+#define SQLITE_CANTOPEN_WITH_LOCKED_READWRITE 0x1001 /* Cannot open with locked read/write access */
+#define SQLITE_CANTOPEN_WITH_LOCKED_WRITE     0x1002 /* Cannot open with locked write access */
+
 /*
 ** Each entry in an SQLite table has a unique integer key.  (The key is
 ** the value of the INTEGER PRIMARY KEY column if there is such a column,
@@ -501,13 +504,30 @@ void *sqlite3_commit_hook(sqlite3*, int(*)(void*), void*);
 ** with the sqlite3* handle should be released by passing it to
 ** sqlite3_close() when it is no longer required.
 */
+#define SQLITE_OPEN_READONLY 3
+#define SQLITE_OPEN_READ_WRITE_LOCKED 2
+#define SQLITE_OPEN_WRITE_LOCKED 1
+#define SQLITE_OPEN_NO_LOCKED 0
 int sqlite3_open(
   const char *filename,   /* Database filename (UTF-8) */
-  sqlite3 **ppDb          /* OUT: SQLite db handle */
+  sqlite3 **ppDb,         /* OUT: SQLite db handle */
+  int exclusiveFlag,      /* If SQLITE_OPEN_READONLY, readonly mode is used, */
+                          /* If SQLITE_OPEN_READ_WRITE_LOCKED, exclusive read/write access is required, */
+                          /* If SQLITE_OPEN_WRITE_LOCKED, exclusive write access is required, 
+                             If SQLITE_OPEN_NO_LOCKED, no locking is performed. */
+  int allowReadonly       /* If 1 and read/write opening fails, 
+                             try opening in read-only mode */
 );
+
 int sqlite3_open16(
   const void *filename,   /* Database filename (UTF-16) */
-  sqlite3 **ppDb          /* OUT: SQLite db handle */
+  sqlite3 **ppDb,         /* OUT: SQLite db handle */
+  int exclusiveFlag,      /* If SQLITE_OPEN_READONLY, readonly mode is used, */
+                          /* If SQLITE_OPEN_READ_WRITE_LOCKED, exclusive read/write access is required, */
+                          /* If SQLITE_OPEN_WRITE_LOCKED, exclusive write access is required, 
+                             If SQLITE_OPEN_NO_LOCKED, no locking is performed. */
+  int allowReadonly       /* If 1 and read/write opening fails, 
+                             try opening in read-only mode */
 );
 
 /*
