@@ -14,23 +14,25 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include "kexipart.h"
-
 #include "kexipartinfo.h"
 #include "kexipartitem.h"
+#include "kexistaticpart.h"
 #include "kexidialogbase.h"
 #include "kexiviewbase.h"
 
 #include "kexipartguiclient.h"
 #include "keximainwindow.h"
-#include "kexipartdatasource.h"
+//#include "kexipartdatasource.h"
 #include "kexi.h"
 
 #include <kexidb/connection.h>
+#include <kexiutils/identifier.h>
+#include <kexiutils/utils.h>
 
 #include <qwidgetstack.h>
 
@@ -39,6 +41,7 @@
 #include <kmessagebox.h>
 
 namespace KexiPart {
+//! @internal
 class PartPrivate
 {
 public:
@@ -57,6 +60,7 @@ using namespace KexiPart;
 Part::Part(QObject *parent, const char *name, const QStringList &)
 : QObject(parent, name)
 , m_guiClient(0)
+, m_registeredPartID(-1) //no registered ID by default
 , d(new PartPrivate())
 {
 	m_info = 0;
@@ -65,6 +69,18 @@ Part::Part(QObject *parent, const char *name, const QStringList &)
 	m_newObjectsAreDirty = false;
 }
 
+Part::Part(QObject* parent, StaticInfo *info)
+: QObject(parent, "StaticPart")
+, m_guiClient(0)
+, m_registeredPartID(-1) //no registered ID by default
+, d(new PartPrivate())
+{
+	m_info = info;
+	m_supportedViewModes = Kexi::DesignViewMode;
+	m_mainWin = 0;
+	m_newObjectsAreDirty = false;
+}
+
 Part::~Part()
 {
 	delete d;
@@ -78,9 +94,10 @@ void Part::createGUIClients(KexiMainWindow *win)
 		m_guiClient = new GUIClient(m_mainWin, this, false);
 
 		//default actions for part's gui client:
-		KAction *act = new KAction(m_names["instance"]+"...", info()->createItemIcon(), 0, this, 
-			SLOT(slotCreate()), this, (info()->objectName()+"part_create").latin1());
-		act->plug( m_mainWin->findPopupMenu("create") );
+		KAction *act = new KAction(m_names["instanceCaption"]+"...", info()->createItemIcon(), 0, this, 
+			SLOT(slotCreate()), m_mainWin->actionCollection(), 
+			KexiPart::nameForCreateAction(*info()));
+		act->plug( m_mainWin->findPopupMenu("insert") );
 //		new KAction(m_names["instance"]+"...", info()->itemIcon(), 0, this, 
 //		SLOT(create()), m_guiClient->actionCollection(), (info()->objectName()+"part_create").latin1());
 		//let init specific actions for parts
@@ -183,7 +200,8 @@ void Part::setActionAvailable(const char *action_name, bool avail)
 	m_mainWin->setActionAvailable(action_name, avail);
 }
 
-KexiDialogBase* Part::openInstance(KexiMainWindow *win, KexiPart::Item &item, int viewMode )
+KexiDialogBase* Part::openInstance(KexiMainWindow *win, KexiPart::Item &item, int viewMode,
+	QMap<QString,QString>* staticObjectArgs)
 {
 	//now it's the time for creating instance actions
 	if (!d->instanceActionsInitialized) {
@@ -209,9 +227,9 @@ KexiDialogBase* Part::openInstance(KexiMainWindow *win, KexiPart::Item &item, in
 	sdata.setCaption( item.caption() );
 	sdata.setDescription( item.description() );
 
-//js TODO: apply settings for caption displaying method; there can be option for
-//- displaying item.caption() as caption, if not empty, without instanceName
-//- displaying the same as above in tabCaption (or not)
+/*! @todo js: apply settings for caption displaying method; there can be option for
+ - displaying item.caption() as caption, if not empty, without instanceName
+ - displaying the same as above in tabCaption (or not) */
 //	dlg->setCaption( capt );
 //	dlg->setTabCaption( item.name() );
 	dlg->setId(item.identifier()); //not needed, but we did it
@@ -234,11 +252,12 @@ KexiDialogBase* Part::openInstance(KexiMainWindow *win, KexiPart::Item &item, in
 				&& dlg->tempData()->proposeOpeningInTextViewModeBecauseOfProblems)
 			{
 				//ask
-//TODO: use message handler for this to enable non-gui apps
+				KexiUtils::removeWaitCursor();
+//! @todo use message handler for this to enable non-gui apps
 				if (KMessageBox::No==KMessageBox::questionYesNo(0, 
 					((viewMode == Kexi::DesignViewMode) 
-					 ? i18n("Object \"%1\" could not be opened in Design View.")
-					 : i18n("Object could not be opened in Data View.")).arg(item.name())+"\n"
+					 ? i18n("Object \"%1\" could not be opened in Design View.").arg(item.name())
+					 : i18n("Object could not be opened in Data View."))+"\n"
 					+ i18n("Do you want to open it in Text View?"), 0, 
 					KStdGuiItem::open(), KStdGuiItem::cancel()))
 				{
@@ -251,19 +270,23 @@ KexiDialogBase* Part::openInstance(KexiMainWindow *win, KexiPart::Item &item, in
 			}
 		}
 		if (!dlg->m_schemaData) {
-			m_status = Kexi::ObjectStatus( dlg->mainWin()->project()->dbConnection(), 
-				i18n("Failed loading object's definition."), i18n("Data may be corrupted."));
+			if (!m_status.error())
+				m_status = Kexi::ObjectStatus( dlg->mainWin()->project()->dbConnection(), 
+					i18n("Could not load object's definition."), i18n("Object design may be corrupted."));
+			m_status.append( 
+				Kexi::ObjectStatus(i18n("You can delete \"%1\" object and create it again.")
+				.arg(item.name()), QString::null) );
+
 			dlg->close();
 			delete dlg;
 			return 0;
 		}
 	}
 
-//	bool cancelled;
 	bool switchingFailed = false;
-	tristate res = dlg->switchToViewMode( viewMode );
+	tristate res = dlg->switchToViewMode( viewMode, staticObjectArgs );
 	if (!res) {
-		//js TODO ERROR???
+		//dlg has an error info
 		switchingFailed = true;
 	}
 	if (~res)
@@ -295,7 +318,8 @@ void Part::slotCreate()
 	emit newObjectRequest( m_info );
 }
 
-KexiDB::SchemaData* Part::loadSchemaData(KexiDialogBase * /*dlg*/, const KexiDB::SchemaData& sdata, int viewMode)
+KexiDB::SchemaData* Part::loadSchemaData(KexiDialogBase * /*dlg*/, const KexiDB::SchemaData& sdata, 
+	int /*viewMode*/)
 {
 	KexiDB::SchemaData *new_schema = new KexiDB::SchemaData();
 	*new_schema = sdata;
@@ -305,7 +329,8 @@ KexiDB::SchemaData* Part::loadSchemaData(KexiDialogBase * /*dlg*/, const KexiDB:
 bool Part::loadDataBlock( KexiDialogBase *dlg, QString &dataString, const QString& dataID)
 {
 	if (!dlg->mainWin()->project()->dbConnection()->loadDataBlock( dlg->id(), dataString, dataID )) {
-		m_status = Kexi::ObjectStatus( dlg->mainWin()->project()->dbConnection(), i18n("Failed loading object's data."), i18n("Data identifier: \"%1\".").arg(dataID) );
+		m_status = Kexi::ObjectStatus( dlg->mainWin()->project()->dbConnection(), 
+			i18n("Could not load object's data."), i18n("Data identifier: \"%1\".").arg(dataID) );
 		m_status.append( *dlg );
 		return false;
 	}
@@ -333,9 +358,34 @@ KexiDialogTempData* Part::createTempData(KexiDialogBase* dialog)
 	return new KexiDialogTempData(dialog);
 }
 
-QString Part::i18nMessage(const QCString& englishMessage) const
+QString Part::i18nMessage(const QCString& englishMessage, KexiDialogBase* dlg) const
 {
-	return englishMessage;
+	Q_UNUSED(dlg);
+	return QString(englishMessage).startsWith(":") ? QString::null : englishMessage;
+}
+
+void Part::setupCustomPropertyPanelTabs(KTabWidget *, KexiMainWindow*)
+{
+}
+
+QCString Part::instanceName() const
+{
+	// "instanceName" should be already valid identifier but we're using
+	// KexiUtils::string2Identifier() to be sure translators did it right.
+	return KexiUtils::string2Identifier(m_names["instanceName"]).lower().latin1();
+}
+
+QString Part::instanceCaption() const
+{
+	return m_names["instanceCaption"];
+}
+
+tristate Part::rename(KexiMainWindow *win, KexiPart::Item &item, const QString& newName)
+{
+	Q_UNUSED(win);
+	Q_UNUSED(item);
+	Q_UNUSED(newName);
+	return true;
 }
 
 //-------------------------------------------------------------------------
