@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2004 Cedric Pasteur <cedric.pasteur@free.fr>
+   Copyright (C) 2005 Jaroslaw Staniek <js@iidea.pl>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -13,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <kdebug.h>
@@ -47,14 +48,14 @@
 #include <kdialogbase.h>
 #include <ktextedit.h>
 #include <ktabwidget.h>
+#include <kfontdialog.h>
 
 #include <kdeversion.h>
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,1,9) && !defined(Q_WS_WIN)
 # include <kactioncollection.h>
 #endif
 
-#include "kexipropertyeditor.h"
-#include "objpropbuffer.h"
+#include "widgetpropertyset.h"
 #include "objecttree.h"
 #include "widgetlibrary.h"
 #include "form.h"
@@ -67,26 +68,64 @@
 #include "pixmapcollection.h"
 #include "events.h"
 #include "utils.h"
+#include "kfdpixmapedit.h"
+#include <koproperty/editor.h>
+#include <koproperty/property.h>
+#include <koproperty/factory.h>
 
 #include "formmanager.h"
 
+#define KFD_NO_STYLES //disables; styles support needs improvements
+
+namespace KFormDesigner {
+
+//! @internal
+class PropertyFactory : public KoProperty::CustomPropertyFactory
+{
+	public:
+		PropertyFactory(QObject *parent) 
+		: KoProperty::CustomPropertyFactory(parent)
+//			m_manager(manager)
+		{
+		}
+		virtual ~PropertyFactory() {}
+
+		KoProperty::CustomProperty* createCustomProperty(KoProperty::Property *) { return 0;}
+
+		KoProperty::Widget* createCustomWidget(KoProperty::Property *prop)
+		{
+			return new KFDPixmapEdit(prop);
+		}
+};
+
+}
+
 using namespace KFormDesigner;
 
-FormManager::FormManager(QObject *parent,
-	const QStringList& supportedFactoryGroups, int options, const char *name)
+static KStaticDeleter<FormManager> m_managerDeleter;
+FormManager* FormManager::_self = 0L;
+
+FormManager::FormManager(QObject *parent, int options, const char *name)
    : QObject(parent, name)
 #ifdef KEXI_SHOW_DEBUG_ACTIONS
    , m_uiCodeDialog(0)
    , m_options(options)
 #endif
+   , m_objectBlockingPropertyEditorUpdating(0)
+   , m_isRedoing(false)
 {
+	Q_UNUSED(options);
+#ifdef KEXI_STANDALONE
+	KGlobal::locale()->insertCatalogue("standalone_kformdesigner");
+#else
 	KGlobal::locale()->insertCatalogue("kformdesigner");
+#endif
 
 	connect( kapp, SIGNAL( settingsChanged(int) ), SLOT( slotSettingsChanged(int) ) );
 	slotSettingsChanged(KApplication::SETTINGS_SHORTCUTS);
 
-	m_lib = new WidgetLibrary(this, supportedFactoryGroups);
-	m_buffer = new ObjectPropertyBuffer(this, this, "buffer");
+//moved to createWidgetLibrary()	m_lib = new WidgetLibrary(this, supportedFactoryGroups);
+	m_propSet = new WidgetPropertySet(this);
 
 	m_editor = 0;
 	m_active = 0;
@@ -94,57 +133,79 @@ FormManager::FormManager(QObject *parent,
 	m_drawingSlot = false;
 	m_collection = 0;
 	m_connection = 0;
-
-	m_domDoc.appendChild(m_domDoc.createElement("UI"));
-
 	m_popup = 0;
-
 	m_treeview = 0;
 	m_editor = 0;
+	m_domDoc.appendChild(m_domDoc.createElement("UI"));
 
 	m_deleteWidgetLater_list.setAutoDelete(true);
 	connect( &m_deleteWidgetLater_timer, SIGNAL(timeout()), this, SLOT(deleteWidgetLaterTimeout()));
-	connect( this, SIGNAL(connectionCreated(KFormDesigner::Form*, KFormDesigner::Connection&)), 
+	connect( this, SIGNAL(connectionCreated(KFormDesigner::Form*, KFormDesigner::Connection&)),
 		this, SLOT(slotConnectionCreated(KFormDesigner::Form*, KFormDesigner::Connection&)));
+
+	// register kfd custom editors
+	KoProperty::FactoryManager::self()->registerFactoryForEditor(KoProperty::Pixmap, 
+		new PropertyFactory(KoProperty::FactoryManager::self()));
 }
 
 FormManager::~FormManager()
 {
+	m_managerDeleter.setObject(_self, 0, false); //safe
 	delete m_popup;
 	delete m_connection;
 #ifdef KEXI_SHOW_DEBUG_ACTIONS
 	delete m_uiCodeDialog;
 #endif
+//	delete m_propFactory;
+}
+
+
+FormManager* FormManager::self()
+{
+	return _self;
+}
+
+WidgetLibrary* 
+FormManager::createWidgetLibrary(FormManager* m, const QStringList& supportedFactoryGroups)
+{
+	if(!_self)
+		m_managerDeleter.setObject( _self, m );
+	return new WidgetLibrary(_self, supportedFactoryGroups);
 }
 
 void
-FormManager::setEditors(KexiPropertyEditor *editor, ObjectTreeView *treeview)
+FormManager::setEditor(KoProperty::Editor *editor)
 {
 	m_editor = editor;
-	m_treeview = treeview;
 
 	if(editor)
-		editor->setBuffer(m_buffer);
+		editor->changeSet(m_propSet->set());
+}
 
-	if(treeview)
-		connect(m_buffer, SIGNAL(nameChanged(const QString&, const QString&)), treeview, SLOT(renameItem(const QString&, const QString&)));
+void
+FormManager::setObjectTreeView(ObjectTreeView *treeview)
+{
+	m_treeview = treeview;
+	if (m_treeview)
+		connect(m_propSet, SIGNAL(widgetNameChanged(const QCString&, const QCString&)),
+			m_treeview, SLOT(renameItem(const QCString&, const QCString&)));
 }
 
 ActionList
-FormManager::createActions(KActionCollection *parent)
+FormManager::createActions(WidgetLibrary *lib, KActionCollection *parent)
 {
 	m_collection = parent;
 
-	ActionList actions = m_lib->addCreateWidgetActions(parent, this, SLOT(insertWidget(const QCString &)));
+	ActionList actions = lib->addCreateWidgetActions(parent, this, SLOT(insertWidget(const QCString &)));
 
 	if (m_options & HideSignalSlotConnections)
 		m_dragConnection = 0;
 	else {
-		m_dragConnection = new KToggleAction(i18n("Connect Signals/Slots"), 
+		m_dragConnection = new KToggleAction(i18n("Connect Signals/Slots"),
 			"signalslot", KShortcut(0), this, SLOT(startCreatingConnection()), parent,
 			"drag_connection");
 		//to be exclusive with any 'widget' action
-		m_dragConnection->setExclusiveGroup("LibActionWidgets"); 
+		m_dragConnection->setExclusiveGroup("LibActionWidgets");
 		m_dragConnection->setChecked(false);
 		actions.append(m_dragConnection);
 	}
@@ -182,7 +243,7 @@ FormManager::createActions(KActionCollection *parent)
 	m_style->setMenuAccelsEnabled(true);
 	actions.append(m_style);
 
-	m_lib->addCustomWidgetActions( parent );
+	lib->addCustomWidgetActions( parent );
 
 	return actions;
 }
@@ -208,7 +269,9 @@ FormManager::redo()
 	if(!activeForm() || !activeForm()->objectTree())
 		return;
 
+	m_isRedoing = true;
 	activeForm()->commandHistory()->redo();
+	m_isRedoing = false;
 }
 
 void
@@ -217,10 +280,12 @@ FormManager::insertWidget(const QCString &classname)
 	if(m_drawingSlot)
 		stopCreatingConnection();
 
+	m_inserting = true;
+
 	Form *form;
 	for(form = m_forms.first(); form; form = m_forms.next())
 	{
-		form->d->cursors = new QMap<QString, QCursor>();
+//		form->d->cursors = new QMap<QString, QCursor>();
 		if (form->toplevelContainer())
 			form->widget()->setCursor(QCursor(CrossCursor));
 		QObjectList *l = form->widget()->queryList( "QWidget" );
@@ -228,16 +293,16 @@ FormManager::insertWidget(const QCString &classname)
 		{
 			if( ((QWidget*)o)->ownCursor() )
 			{
-				form->d->cursors->insert(o->name(), ((QWidget*)o)->cursor());
-				((QWidget*)o)->setCursor(QCursor(Qt::CrossCursor));
+//				form->d->cursors->insert(o->name(), ((QWidget*)o)->cursor());
+				form->d->cursors.insert(o, static_cast<QWidget*>(o)->cursor());
+				static_cast<QWidget*>(o)->setCursor(QCursor(Qt::CrossCursor));
 			}
 
 		}
 		delete l;
 	}
 
-	m_inserting = true;
-	m_insertClass = classname;
+	m_selectedClass = classname;
 	m_pointer->setChecked(false);
 }
 
@@ -249,6 +314,7 @@ FormManager::stopInsert()
 	if(!m_inserting)
 		return;
 
+//#ifndef KEXI_NO_CURSOR_PROPERTY
 	Form *form;
 	for(form = m_forms.first(); form; form = m_forms.next())
 	{
@@ -256,13 +322,21 @@ FormManager::stopInsert()
 		QObjectList *l = form->widget()->queryList( "QWidget" );
 		for(QObject *o = l->first(); o; o = l->next())
 		{
-			if( ((QWidget*)o)->ownCursor())
-				((QWidget*)o)->setCursor( (*(form->d->cursors))[o->name()] ) ;
+			static_cast<QWidget*>(o)->unsetCursor();
+#if 0
+			if( ((QWidget*)o)->ownCursor()) {
+				QMap<QObject*,QCursor>::ConstIterator curIt( form->d->cursors.find(o) );
+				if (curIt!=form->d->cursors.constEnd())
+					static_cast<QWidget*>(o)->setCursor( *curIt );
+//				((QWidget*)o)->setCursor( (*(form->d->cursors))[o->name()] ) ;
+			}
+#endif
 		}
 		delete l;
-		delete (form->d->cursors);
-		form->d->cursors = 0;
+//		delete (form->d->cursors);
+//		form->d->cursors = 0;
 	}
+//#endif
 	m_inserting = false;
 	m_pointer->setChecked(true);
 }
@@ -279,6 +353,9 @@ FormManager::slotPointerClicked()
 void
 FormManager::startCreatingConnection()
 {
+	if (m_options & HideSignalSlotConnections)
+		return;
+
 	if(m_inserting)
 		stopInsert();
 
@@ -286,7 +363,7 @@ FormManager::startCreatingConnection()
 	Form *form;
 	for(form = m_forms.first(); form; form = m_forms.next())
 	{
-		form->d->cursors = new QMap<QString, QCursor>();
+//		form->d->cursors = new QMap<QString, QCursor>();
 		form->d->mouseTrackers = new QStringList();
 		if (form->toplevelContainer())
 		{
@@ -296,10 +373,11 @@ FormManager::startCreatingConnection()
 		QObjectList *l = form->widget()->queryList( "QWidget" );
 		for(QObject *o = l->first(); o; o = l->next())
 		{
-			QWidget *w = (QWidget*)o;
+			QWidget *w = static_cast<QWidget*>(o);
 			if( w->ownCursor() )
 			{
-				form->d->cursors->insert(w->name(), w->cursor());
+				form->d->cursors.insert(w, w->cursor());
+//				form->d->cursors->insert(w->name(), w->cursor());
 				w->setCursor(QCursor(PointingHandCursor ));
 			}
 			if(w->hasMouseTracking())
@@ -318,17 +396,28 @@ FormManager::startCreatingConnection()
 void
 FormManager::resetCreatedConnection()
 {
+	if (m_options & HideSignalSlotConnections)
+		return;
+
 	delete m_connection;
 	m_connection = new Connection();
 
-	if(m_active && m_active->formWidget())
+	if(m_active && m_active->formWidget()) {
+		Form *ff = (Form*)m_active;
+		FormWidget *fw = 0;
+		if (ff)
+			fw = ff->formWidget();
 		m_active->formWidget()->clearForm();
-	m_active->widget()->repaint();
+	}
+	if (m_active && m_active->widget())
+		m_active->widget()->repaint();
 }
 
 void
 FormManager::stopCreatingConnection()
 {
+	if (m_options & HideSignalSlotConnections)
+		return;
 	if(!m_drawingSlot)
 		return;
 
@@ -344,13 +433,17 @@ FormManager::stopCreatingConnection()
 		for(QObject *o = l->first(); o; o = l->next())
 		{
 			QWidget *w = (QWidget*)o;
-			if( w->ownCursor())
-				w->setCursor( (*(form->d->cursors))[o->name()] ) ;
+			if( w->ownCursor()) {
+				QMap<QObject*,QCursor>::ConstIterator curIt( form->d->cursors.find(o) );
+				if (curIt!=form->d->cursors.constEnd())
+					static_cast<QWidget*>(o)->setCursor( *curIt );
+			}
+//				w->setCursor( (*(form->d->cursors))[o->name()] ) ;
 			w->setMouseTracking( !form->d->mouseTrackers->grep(w->name()).isEmpty() );
 		}
 		delete l;
-		delete (form->d->cursors);
-		form->d->cursors = 0;
+//		delete (form->d->cursors);
+//		form->d->cursors = 0;
 		delete (form->d->mouseTrackers);
 		form->d->mouseTrackers = 0;
 	}
@@ -372,12 +465,15 @@ FormManager::snapWidgetsToGrid()
 void
 FormManager::windowChanged(QWidget *w)
 {
+	kdDebug() << "FormManager::windowChanged(" 
+		<< (w ? (QString(w->className())+" "+w->name()) : QString("0")) << ")" << endl;
+
 	if(!w)
 	{
 		m_active = 0;
 		if(m_treeview)
 			m_treeview->setForm(0);
-		showPropertyBuffer(0);
+		emit propertySetSwitched(0);
 		if(isCreatingConnection())
 			stopCreatingConnection();
 
@@ -393,13 +489,14 @@ FormManager::windowChanged(QWidget *w)
 		{
 			if(m_treeview)
 				m_treeview->setForm(form);
-			if(m_buffer)
-				m_buffer->setCollection(form->pixmapCollection());
+			//if(m_propSet)
+			//	m_propList->setCollection(form->pixmapCollection());
 
 			kdDebug() << "FormManager::windowChanged() active form is " << form->objectTree()->name() << endl;
 
 			if(m_collection)
 			{
+#ifndef KFD_NO_STYLES
 				// update the 'style' action
 				KSelectAction *m_style = (KSelectAction*)m_collection->action("change_style", "KSelectAction");
 				const QString currentStyle = form->widget()->style().name();
@@ -415,6 +512,7 @@ FormManager::windowChanged(QWidget *w)
 						break;
 					}
 				}
+#endif
 			}
 
 			if((form != previousActive) && isCreatingConnection())
@@ -425,40 +523,48 @@ FormManager::windowChanged(QWidget *w)
 			emit  dirty(form, form->isModified());
 			// update actions state
 			m_active->emitActionSignals();
-			//uodate the buffer too
+			//update the buffer too
 			form->emitSelectionSignals();
+
+			showPropertySet( propertySet(), true );
 			return;
 		}
 	}
 
 	for(form = m_preview.first(); form; form = m_preview.next())
 	{
-		kdDebug() << "FormManager::windowChanged() active preview form is " << form->widget()->name() << endl;
+		kdDebug() << (form->widget() ? form->widget()->name() : "") << endl;
+		if(form->toplevelContainer() && form->widget() == w) {
+			kdDebug() << "FormManager::windowChanged() active preview form is " << form->widget()->name() << endl;
 
-		if(m_collection)
-		{
-			// update the 'style' action
-			KSelectAction *m_style = (KSelectAction*)m_collection->action("change_style", "KSelectAction");
-			const QString currentStyle = form->widget()->style().name();
-			const QStringList styles = m_style->items();
-
-			int idx = 0;
-			QStringList::ConstIterator endIt = styles.constEnd();
-			for (QStringList::ConstIterator it = styles.constBegin(); it != endIt; ++it, ++idx)
+			if(m_collection)
 			{
-				if ((*it).lower() == currentStyle) {
-					kdDebug() << "Updating the style to " << currentStyle << endl;
-					m_style->setCurrentItem(idx);
-					break;
+#ifndef KFD_NO_STYLES
+				// update the 'style' action
+				KSelectAction *m_style = (KSelectAction*)m_collection->action("change_style", "KSelectAction");
+				const QString currentStyle = form->widget()->style().name();
+				const QStringList styles = m_style->items();
+
+				int idx = 0;
+				QStringList::ConstIterator endIt = styles.constEnd();
+				for (QStringList::ConstIterator it = styles.constBegin(); it != endIt; ++it, ++idx)
+				{
+					if ((*it).lower() == currentStyle) {
+						kdDebug() << "Updating the style to " << currentStyle << endl;
+						m_style->setCurrentItem(idx);
+						break;
+					}
 				}
+#endif
+
+				resetCreatedConnection();
+				m_active = form;
+
+				emit dirty(form, false);
+				emitNoFormSelected();
+				showPropertySet(0);
+				return;
 			}
-
-			resetCreatedConnection();
-			m_active = form;
-
-			emit dirty(form, false);
-			emitNoFormSelected();
-			showPropertyBuffer(0);
 		}
 	}
 	//m_active = 0;
@@ -493,7 +599,7 @@ FormManager::deleteForm(Form *form)
 
 	if(m_forms.count() == 0) {
 		m_active = 0;
-		showPropertyBuffer(0);
+		emit propertySetSwitched(0);
 	}
 }
 
@@ -519,14 +625,15 @@ FormManager::initForm(Form *form)
 
 	m_active = form;
 
-	connect(form, SIGNAL(selectionChanged(QWidget*, bool)), m_buffer, SLOT(setSelectedWidget(QWidget*, bool)));
+	connect(form, SIGNAL(selectionChanged(QWidget*, bool)), m_propSet, SLOT(setSelectedWidget(QWidget*, bool)));
 	if(m_treeview)
 	{
 		connect(form, SIGNAL(selectionChanged(QWidget*, bool)), m_treeview, SLOT(setSelectedWidget(QWidget*, bool)));
 		connect(form, SIGNAL(childAdded(ObjectTreeItem* )), m_treeview, SLOT(addItem(ObjectTreeItem*)));
 		connect(form, SIGNAL(childRemoved(ObjectTreeItem* )), m_treeview, SLOT(removeItem(ObjectTreeItem*)));
 	}
-	connect(m_buffer, SIGNAL(nameChanged(const QString&, const QString&)), form, SLOT(changeName(const QString&, const QString&)));
+	connect(m_propSet, SIGNAL(widgetNameChanged(const QCString&, const QCString&)),
+		form, SLOT(changeName(const QCString&, const QCString&)));
 
 	form->setSelectedWidget(form->widget());
 	windowChanged(form->widget());
@@ -538,30 +645,49 @@ FormManager::previewForm(Form *form, QWidget *container, Form *toForm)
 	if(!form || !container || !form->objectTree())
 		return;
 	QDomDocument domDoc;
-	FormIO::saveFormToDom(form, domDoc);
+	if (!FormIO::saveFormToDom(form, domDoc))
+		return;
 
 	Form *myform;
 	if(!toForm)
-		myform = new Form(this, form->objectTree()->name().latin1());
+		myform = new Form(form->library(), form->objectTree()->name().latin1(), 
+			false/*!designMode, we need to set it early enough*/);
 	else
 		myform = toForm;
 	myform->createToplevel(container);
 	container->setStyle( &(form->widget()->style()) );
-	FormIO::loadFormFromDom(myform, container, domDoc);
+
+	if (!FormIO::loadFormFromDom(myform, container, domDoc)) {
+		delete myform;
+		return;
+	}
 
 	myform->setDesignMode(false);
 	m_preview.append(myform);
 	container->show();
 }
 
+/*
+bool
+FormManager::loadFormFromDomInternal(Form *form, QWidget *container, QDomDocument &inBuf)
+{
+	return FormIO::loadFormFromDom(myform, container, domDoc);
+}
+
+bool
+FormManager::saveFormToStringInternal(Form *form, QString &dest, int indent)
+{
+	return KFormDesigner::FormIO::saveFormToString(form, dest, indent);
+}*/
+
 bool
 FormManager::isTopLevel(QWidget *w)
 {
 	if(!activeForm() || !activeForm()->objectTree())
 		return false;
 
-	kdDebug() << "FormManager::isTopLevel(): for: " << w->name() << " = "
-		<< activeForm()->objectTree()->lookup(w->name())<< endl;
+//	kdDebug() << "FormManager::isTopLevel(): for: " << w->name() << " = "
+//		<< activeForm()->objectTree()->lookup(w->name())<< endl;
 
 	ObjectTreeItem *item = activeForm()->objectTree()->lookup(w->name());
 	if(!item)
@@ -713,12 +839,12 @@ FormManager::createContextMenu(QWidget *w, Container *container, bool popupAtCur
 	const bool toplevelWidgetSelected = activeForm()->widget() == w;
 	const uint widgetsCount = container->form()->selectedWidgets()->count();
 	const bool multiple = widgetsCount > 1;
-	const bool enableRemove = w != m_active->widget();
+	//const bool enableRemove = w != m_active->widget();
 	// We only enablelayout creation if more than one widget with the same parent are selected
 	const bool enableLayout = multiple || w == container->widget();
 
 	m_menuWidget = w;
-	QString n = m_lib->displayName(w->className());
+	QString n = container->form()->library()->displayName(w->className());
 //	QValueVector<int> menuIds();
 
 	if (!m_popup) {
@@ -734,10 +860,11 @@ FormManager::createContextMenu(QWidget *w, Container *container, bool popupAtCur
 		if(w == container->form()->widget())
 			m_popup->insertTitle(SmallIcon("form"), i18n("Form: ") + w->name());
 		else
-			m_popup->insertTitle(SmallIcon(m_lib->icon(w->className())), n + ": " + w->name() );
+			m_popup->insertTitle( SmallIcon(
+				container->form()->library()->iconName(w->className())), n + ": " + w->name() );
 	}
 	else
-		m_popup->insertTitle(SmallIcon("multiple_obj"), i18n("Multiple Widgets") 
+		m_popup->insertTitle(SmallIcon("multiple_obj"), i18n("Multiple Widgets")
 		+ QString(" (%1)").arg(widgetsCount));
 
 	KAction *a;
@@ -782,13 +909,14 @@ FormManager::createContextMenu(QWidget *w, Container *container, bool popupAtCur
 		// add all the widgets that can have focus
 		for(ObjectTreeListIterator it( container->form()->tabStopsIterator() ); it.current(); ++it)
 		{
-			int index = sub->insertItem( SmallIcon(m_lib->icon(it.current()->className().latin1())),
+			int index = sub->insertItem( 
+				SmallIcon(container->form()->library()->iconName(it.current()->className().latin1())),
 				it.current()->name());
 			if(it.current()->widget() == buddy)
 				sub->setItemChecked(index, true);
 		}
 
-		int id = m_popup->insertItem(i18n("Choose Buddy..."), sub);
+		/*int id =*/ m_popup->insertItem(i18n("Choose Buddy..."), sub);
 //		menuIds->append(id);
 		connect(sub, SIGNAL(activated(int)), this, SLOT(buddyChoosed(int)));
 
@@ -825,8 +953,8 @@ FormManager::createContextMenu(QWidget *w, Container *container, bool popupAtCur
 		if (separatorNeeded) {
 			lastID = m_popup->insertSeparator();
 		}
-		const int oldIndex = m_popup->count()-1;
-		m_lib->createMenuActions(w->className(), w, m_popup, container);
+		const uint oldIndex = m_popup->count()-1;
+		container->form()->library()->createMenuActions(w->className(), w, m_popup, container);
 		if (oldIndex == (m_popup->count()-1)) {
 //			for (uint i=oldIndex; i<m_popup->count(); i++) {
 //				int id = m_popup->idAt( i );
@@ -840,7 +968,7 @@ FormManager::createContextMenu(QWidget *w, Container *container, bool popupAtCur
 			}
 		}
 	}
-	
+
 	//show the popup at the selected widget
 	QPoint popupPos;
 	if (popupAtCursor) {
@@ -882,6 +1010,9 @@ FormManager::buddyChoosed(int id)
 void
 FormManager::menuSignalChoosed(int id)
 {
+	if (m_options & HideSignalSlotConnections)
+		return;
+
 	//if(!m_menuWidget)
 	//	return;
 	if(m_drawingSlot && m_sigSlotMenu)
@@ -904,12 +1035,13 @@ FormManager::menuSignalChoosed(int id)
 void
 FormManager::slotConnectionCreated(Form *form, Connection &connection)
 {
+	if (m_options & HideSignalSlotConnections)
+		return;
 	if(!form)
 		return;
 
 	Connection *c = new Connection(connection);
 	form->connectionBuffer()->append(c);
-
 }
 
 void
@@ -942,17 +1074,33 @@ FormManager::layoutVSplitter()
 	createLayout(Container::VSplitter);
 }
 
+void
+FormManager::layoutHFlow()
+{
+	createLayout(Container::HFlow);
+}
+
+void
+FormManager::layoutVFlow()
+{
+	createLayout(Container::VFlow);
+}
+
 void
 FormManager::createLayout(int layoutType)
 {
 	WidgetList *list = m_active->selectedWidgets();
 	// if only one widget is selected (a container), we modify its layout
+	if (list->isEmpty()) {//sanity check
+		kdWarning() << "FormManager::createLayout(): list is empty!" << endl;
+		return;
+	}
 	if(list->count() == 1)
 	{
 		ObjectTreeItem *item = m_active->objectTree()->lookup(list->first()->name());
-		if(!item || !item->container() || !(*m_buffer)["layout"])
+		if(!item || !item->container() || !m_propSet->contains("layout"))
 			return;
-		(*m_buffer)["layout"] = Container::layoutTypeToString(layoutType);
+		(*m_propSet)["layout"] = Container::layoutTypeToString(layoutType);
 		return;
 	}
 
@@ -982,7 +1130,7 @@ FormManager::breakLayout()
 	Container *container = activeForm()->activeContainer();
 	QCString c( container->widget()->className() );
 
-	if((c == "Grid") || (c == "VBox") || (c == "HBox"))
+	if((c == "Grid") || (c == "VBox") || (c == "HBox") || (c == "HFlow") || (c == "VFlow"))
 	{
 		KCommand *com = new BreakLayoutCommand(container);
 		m_active->addCommand(com, true);
@@ -990,19 +1138,40 @@ FormManager::breakLayout()
 	else // normal container
 	{
 		if(activeForm()->selectedWidgets()->count() == 1)
-			(*m_buffer)["layout"] = "NoLayout";
+			(*m_propSet)["layout"] = "NoLayout";
 		else
 			container->setLayout(Container::NoLayout);
 	}
 }
 
 void
-FormManager::showPropertyBuffer(ObjectPropertyBuffer *buff)
+FormManager::showPropertySet(WidgetPropertySet *propSet, bool forceReload)
 {
-	if(m_editor)
-		m_editor->setBuffer(buff);
+	if (m_objectBlockingPropertyEditorUpdating)
+		return;
 
-	emit bufferSwitched(buff);
+	if(m_editor)
+		m_editor->changeSet(propSet ? propSet->set() : 0);
+
+	emit propertySetSwitched(propSet ? propSet->set(): 0, forceReload);
+}
+
+void
+FormManager::blockPropertyEditorUpdating(void *blockingObject)
+{
+	if (!blockingObject || m_objectBlockingPropertyEditorUpdating)
+		return;
+	m_objectBlockingPropertyEditorUpdating = blockingObject;
+}
+
+void
+FormManager::unblockPropertyEditorUpdating(void *blockingObject, WidgetPropertySet *propSet)
+{
+	if (!blockingObject || m_objectBlockingPropertyEditorUpdating!=blockingObject)
+		return;
+
+	m_objectBlockingPropertyEditorUpdating = 0;
+	showPropertySet(propSet, true/*forceReload*/);
 }
 
 void
@@ -1012,7 +1181,7 @@ FormManager::editTabOrder()
 		return;
 	QWidget *topLevel = m_active->widget()->topLevelWidget();
 	TabStopDialog dlg(topLevel);
-	const bool oldAutoTabStops = m_active->autoTabStops();
+	//const bool oldAutoTabStops = m_active->autoTabStops();
 	if (dlg.exec(m_active) == QDialog::Accepted) {
 		//inform about changing "autoTabStop" property
 		// -- this will be received eg. by Kexi, so custom "autoTabStop" property can be updated
@@ -1051,6 +1220,8 @@ FormManager::editFormPixmapCollection()
 void
 FormManager::editConnections()
 {
+	if (m_options & HideSignalSlotConnections)
+		return;
 	if(!activeForm() || !activeForm()->objectTree())
 		return;
 
@@ -1199,7 +1370,7 @@ FormManager::selectAll()
 	if(!activeForm() || !activeForm()->objectTree())
 		return;
 
-	activeForm()->resetSelection();
+	activeForm()->selectFormWidget();
 	for(ObjectTreeItem *it = activeForm()->objectTree()->children()->first(); it; it = activeForm()->objectTree()->children()->next())
 		activeForm()->setSelectedWidget(it->widget(), true);
 }
@@ -1211,7 +1382,7 @@ FormManager::clearWidgetContent()
 		return;
 
 	for(QWidget *w = activeForm()->selectedWidgets()->first(); w; w = activeForm()->selectedWidgets()->next())
-		m_lib->clearWidgetContent(w->className(), w);
+		activeForm()->library()->clearWidgetContent(w->className(), w);
 }
 
 void
@@ -1237,7 +1408,10 @@ FormManager::showFormUICode()
 		return;
 
 	QString uiCode;
-	KFormDesigner::FormIO::saveFormToString(activeForm(), uiCode, 3);
+	if (!FormIO::saveFormToString(activeForm(), uiCode, 3)) {
+		//! @todo show err?
+		return;
+	}
 
 	if (!m_uiCodeDialog) {
 		m_uiCodeDialog = new KDialogBase(0, "uiwindow", true, i18n("Form's UI Code"),
@@ -1303,11 +1477,23 @@ FormManager::emitWidgetSelected( KFormDesigner::Form* form, bool multiple )
 	enableAction("format_raise", true);
 	enableAction("format_lower", true);
 
+	WidgetList *wlist = form->selectedWidgets();
+	bool fontEnabled = false;
+	for (WidgetListIterator it(*wlist); it.current(); ++it) {
+		if (-1 != it.current()->metaObject()->findProperty("font", true)) {
+			fontEnabled = true;
+			break;
+		}
+	}
+	enableAction("format_font", fontEnabled);
+
 	// If the widgets selected is a container, we enable layout actions
 	bool containerSelected = false;
 	if(!multiple)
 	{
-		KFormDesigner::ObjectTreeItem *item = form->objectTree()->lookup( form->selectedWidgets()->first()->name() );
+		KFormDesigner::ObjectTreeItem *item = 0;
+		if (form->selectedWidgets()->first())
+			form->objectTree()->lookup( form->selectedWidgets()->first()->name() );
 		if(item && item->container())
 			containerSelected = true;
 	}
@@ -1320,7 +1506,7 @@ FormManager::emitWidgetSelected( KFormDesigner::Form* form, bool multiple )
 	enableAction("layout_hsplitter", twoSelected);
 	enableAction("layout_vsplitter", twoSelected);
 
-	KFormDesigner::Container *container = activeForm()->activeContainer();
+	KFormDesigner::Container *container = activeForm() ? activeForm()->activeContainer() : 0;
 	if (container)
 		enableAction("break_layout", (container->layoutType() != KFormDesigner::Container::NoLayout));
 
@@ -1336,7 +1522,7 @@ FormManager::emitFormWidgetSelected( KFormDesigner::Form* form )
 	enableAction("edit_delete", false);
 	enableAction("clear_contents", false);
 
-		// Disable format functions
+	// Disable format functions
 	enableAction("align_menu", false);
 	enableAction("align_to_left", false);
 	enableAction("align_to_right", false);
@@ -1346,6 +1532,8 @@ FormManager::emitFormWidgetSelected( KFormDesigner::Form* form )
 	enableAction("format_raise", false);
 	enableAction("format_lower", false);
 
+	enableAction("format_font", false);
+
 	enableFormActions();
 
 	const bool twoSelected = form->selectedWidgets()->count()==2;
@@ -1375,7 +1563,8 @@ FormManager::emitNoFormSelected()
 
 	// Disable 'Tools' actions
 	enableAction("pixmap_collection", false);
-	enableAction("form_connections", false);
+	if (!(m_options & HideSignalSlotConnections))
+		enableAction("form_connections", false);
 	enableAction("taborder", false);
 	enableAction("change_style", activeForm()!=0);
 
@@ -1394,7 +1583,8 @@ FormManager::enableFormActions()
 {
 	// Enable 'Tools' actions
 	enableAction("pixmap_collection", true);
-	enableAction("form_connections", true);
+	if (!(m_options & HideSignalSlotConnections))
+		enableAction("form_connections", true);
 	enableAction("taborder", true);
 	enableAction("change_style", true);
 
@@ -1451,4 +1641,63 @@ FormManager::emitRedoEnabled(bool enabled, const QString &text)
 	emit redoEnabled(enabled, text);
 }
 
+void
+FormManager::changeFont()
+{
+	if (!m_active)
+		return;
+	WidgetList *wlist = m_active->selectedWidgets();
+	WidgetList widgetsWithFontProperty;
+	QWidget *widget;
+	QFont font;
+	bool oneFontSelected = true;
+	for (WidgetListIterator it(*wlist); (widget = it.current()); ++it) {
+		if (m_active->library()->isPropertyVisible(widget->className(), widget, "font")) {
+			widgetsWithFontProperty.append(widget);
+			if (oneFontSelected) {
+				if (widgetsWithFontProperty.count()==1)
+					font = widget->font();
+				else if (font != widget->font())
+					oneFontSelected = false;
+			}
+		}
+	}
+	if (widgetsWithFontProperty.isEmpty())
+		return;
+	if (!oneFontSelected) //many different fonts selected: pick a font from toplevel conatiner
+		font = m_active->widget()->font();
+
+	if (1==widgetsWithFontProperty.count()) {
+		//single widget's settings
+		widget = widgetsWithFontProperty.first();
+		KoProperty::Property &fontProp = m_propSet->property("font");
+		if (QDialog::Accepted != KFontDialog::getFont(font, false, m_active->widget()))
+			return;
+		fontProp = font;
+		return;
+	}
+	//multiple widgets
+	int diffFlags=0;
+	if (QDialog::Accepted != KFontDialog::getFontDiff(font, diffFlags, false, m_active->widget())
+		|| 0==diffFlags)
+		return;
+	//update font
+	for (WidgetListIterator it(widgetsWithFontProperty); (widget = it.current()); ++it) {
+		QFont prevFont( widget->font() );
+		if (diffFlags & KFontChooser::FontDiffFamily)
+			prevFont.setFamily( font.family() );
+		if (diffFlags & KFontChooser::FontDiffStyle) {
+			prevFont.setBold( font.bold() );
+			prevFont.setItalic( font.italic() );
+		}
+		if (diffFlags & KFontChooser::FontDiffSize)
+			prevFont.setPointSize( font.pointSize() );
+/*! @todo this modification is not added to UNDO BUFFER:
+          do it when KoProperty::Set supports multiple selections */
+		widget->setFont( prevFont );
+		//temporary fix for dirty flag:
+		emit dirty(m_active, true);
+	}
+}
+
 #include "formmanager.moc"
