@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KEXIDB_QUERY_H
@@ -56,6 +56,16 @@ class KEXI_DB_EXPORT QueryColumnInfo
 		~QueryColumnInfo()
 		{
 		}
+		//! \return alias if it's not empty, field's name otherwise.
+		inline QCString aliasOrName() const { 
+			return alias.isEmpty() ? field->name().latin1() : (const char*)alias; 
+		}
+
+		//! \return field's caption if it's not empty, field's alias otherwise.
+		//! If alias is also empty - returns field's name.
+		inline QString captionOrAliasOrName() const {
+			return field->caption().isEmpty() ? QString(aliasOrName()) : field->caption(); }
+
 		Field *field;
 		QCString alias;
 		bool visible : 1;
@@ -72,8 +82,12 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 
 		/*! Creates query schema object that is equivalent to "SELECT * FROM table" 
 		 sql command. Schema of \a table is used to contruct this query -- 
-		 it is defined just by defining "all-tables query asterisk" (see QueryAsterisk)
-		 item. Properties such as the name and caption of the query are inherited 
+		 it is defined just adding all the fields to the query in natural order.
+		 To avoid problems (e.g. with fields added outside of Kexi using ALTER TABLE) 
+		 we do not use "all-tables query asterisk" (see QueryAsterisk) item to achieve 
+		 this effect. 
+
+		 Properties such as the name and caption of the query are inherited 
 		 from table schema.
 
 		 We consider that query schema based on \a table is not (a least yet) stored 
@@ -193,6 +207,22 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		/*! \return true if the query uses \a table. */
 		bool contains(TableSchema *table) const;
 
+		/*! Convenience function. 
+		 \return table field by searching through all tables in this query.
+		 The field does not need to be included on the list of query columns.
+		 Similarly, query aliases are not taken into account.
+
+		 \a tableDotFieldName string must contain table name and field name 
+		 with '.' character between them, e.g. "mytable.myfield". 
+		 0 is returned if the query has no such 
+		 table defined of the table has no such field defined.
+
+		 QuerySchema::table("mytable")->field("myfield") could be 
+		 alternative for findTableField("mytable.myfield") but it can crash
+		 if "mytable" is not defined in the query.
+		*/
+		Field* findTableField(const QString &tableDotFieldName) const;
+
 		/*! \return alias of a column at \a position or null string 
 		 If there is no alias for this column
 		 or if there is no such column within the query defined. 
@@ -323,7 +353,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		   will return the same pointer.
 		 - Calling field("T.A") will return the same pointer as field("A").
 		 */
-		Field* field(const QString& name);
+		virtual Field* field(const QString& name);
 
 		/* Like QuerySchema::field(const QString& name) but returns not only Field
 		 object for \a name but entire QueryColumnInfo object. */
@@ -333,22 +363,36 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		 but in a case when there are asterisks defined for the query,
 		 it does not expand QueryAsterisk objects to field lists but return every
 		 asterisk as-is.
-		 This could be inconvenient when you need just full expanded list of fields,
+		 This could be inconvenient when you need just a fully expanded list of fields,
 		 so this method does the work for you. 
 
+		 If \a unique is true, each field is returned in the vector only once 
+		 (first found field is selected).
+		 Note however, that the same field can be returned more than once if it has attached 
+		 a different alias.
+		 For example, let t is TABLE( a, b ) and let query be defined 
+		 by "SELECT *, a AS alfa FROM t" statement. Either fieldsExpanded(true) and fieldsExpanded(false)
+		 will return [ a, b, a (alfa) ] list.
+		 On the other hand, for query defined by "SELECT *, a FROM t" statement,
+		 fieldsExpanded(true) will return [ a, b ] list 
+		 and fieldsExpanded(false) will return [ a, b, a ] list.
+
+		 By default, all fields are returned in the vector even 
+		 if there are multiple occurences of one or more.
+
 		 Note: You should assign the resulted vector in your space - it will be shared 
 		 and implicity copied on any modification.
 		 This method's result is cached by QuerySchema object.
 @todo js: UPDATE CACHE!
 		*/
-		QueryColumnInfo::Vector fieldsExpanded();//QValueList<bool> *detailedVisibility = 0);
+		QueryColumnInfo::Vector fieldsExpanded(bool unique = false); //QValueList<bool> *detailedVisibility = 0);
 
 		/*! \return a map for fast lookup of query columns' order.
 		 This is exactly opposite information compared to vector returned 
 		 by fieldsExpanded(). This method's result is cached by QuerySchema object.
 @todo js: UPDATE CACHE!
 		*/
-		QMap<QueryColumnInfo*,uint> fieldsOrder();
+		QMap<QueryColumnInfo*,int> fieldsOrder();
 
 		/*! \return table describing order of primary key (PKEY) fields within the query.
 		 Indexing is performed against vector returned by fieldsExpanded().
@@ -372,7 +416,7 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 		 @see example for pkeyFieldsCount().
 @todo js: UPDATE CACHE!
 		*/
-		QValueVector<uint> pkeyFieldsOrder();
+		QValueVector<int> pkeyFieldsOrder();
 
 		/*! \return number of master table's primary key fields included in this query.
 		 This method is useful to quickly check whether the vector returned by pkeyFieldsOrder()
@@ -429,6 +473,27 @@ class KEXI_DB_EXPORT QuerySchema : public FieldList, public SchemaData
 
 		/*! \return WHERE expression or 0 if this query has no WHERE expression */
 		BaseExpr *whereExpression() const;
+	
+		/*! Adds a part to WHERE expression. 
+		 Simplifies creating of WHERE expression, if used instead 
+		 of setWhereExpression(BaseExpr *expr). */
+		void addToWhereExpression(KexiDB::Field *field, const QVariant& value, int relation = '=');
+
+		/*! Sets a list of columns for ORDER BY section of the query. 
+		 Each name on the list must be a field or alias present within the query 
+		 and must not be covered by aliases. If one or more names cannot be found within 
+		 the query, the method will have no effect. Any previous ORDER BY settings will be removed. 
+		 */
+		void setOrderByColumnList(const QStringList& columnNames);
+
+		/*! Convenience method, similar to setOrderByColumnList(const QStringList&). */
+		void setOrderByColumnList(const QString& column1, const QString& column2 = QString::null, 
+			const QString& column3 = QString::null, const QString& column4 = QString::null, 
+			const QString& column5 = QString::null);
+
+		/*! \return a list of columns contained in ORDER BY section of the query. 
+		 @see setOrderBy(const QStringList&) */
+		QueryColumnInfo::Vector orderByColumnList() const;
 
 	protected:
 		void init();
