@@ -13,15 +13,19 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "KexiDBTitlePage.h"
 
-KexiDBTitlePage::KexiDBTitlePage( QWidget* parent, const char* name )
-    : KexiDBTitlePageBase( parent, name )
+#include <qlabel.h>
+
+KexiDBTitlePage::KexiDBTitlePage( const QString& labelText, QWidget* parent, const char* name )
+ : KexiDBTitlePageBase( parent, name )
 {
+	if (!labelText.isEmpty())
+		label->setText(labelText);
 }
 
 KexiDBTitlePage::~KexiDBTitlePage()
