@@ -13,15 +13,16 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #include "kexiformdataiteminterface.h"
+#include <kexidb/queryschema.h>
 
 KexiFormDataItemInterface::KexiFormDataItemInterface()
  : KexiDataItemInterface()
- , m_field(0)
+ , m_columnInfo(0)
 {
 }
 
@@ -35,3 +36,8 @@ void KexiFormDataItemInterface::undoChanges()
 	setValueInternal(QString::null, false);
 //	m_disable_signalValueChanged = false;
 }
+
+KexiDB::Field* KexiFormDataItemInterface::field() const
+{
+	return m_columnInfo->field;
+}
