@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KEXIFORMVIEW_H
@@ -27,6 +27,7 @@
 #include <widget/kexidataawareview.h>
 
 #include "kexiformpart.h"
+#include <core/kexiblobbuffer.h>
 
 class KexiFormPart;
 class KexiMainWindow;
@@ -34,6 +35,7 @@ class KexiDBForm;
 class KexiTableItem;
 class KexiTableViewData;
 class KexiFormScrollView;
+namespace KexiDB { class Cursor; }
 
 //! The KexiFormView lass provides a data-driven (record-based) form view .
 /*! The KexiFormView can display data provided "by hand"
@@ -46,7 +48,7 @@ class KexiFormScrollView;
 
  @see KexiDataTable
 */
-class KexiFormView : public KexiDataAwareView
+class KEXIFORMUTILS_EXPORT KexiFormView : public KexiDataAwareView
 {
 	Q_OBJECT
 
@@ -71,14 +73,50 @@ class KexiFormView : public KexiDataAwareView
 
 		KFormDesigner::Form* form() const;
 
+		/*! Assigns \a id local (static) BLOB's identifier for \a widget widget.
+		 Previously assigned BLOB will be usassigned. 
+		 If \a id is 0, BLOB is unassigned and no new is assigned. 
+
+		 This method is called when a widget supporting BLOB data 
+		 (currently, images from KexiDBImageBox, within KexiDBFactory) has BLOB assigned by identifier \a id.
+		 BLOB identifiers are defined by KexiBLOBBuffer (KexiBLOBBuffer::self() instance).
+		
+		 The data collected by this method is used on form's design saving (in design mode). 
+		 Local BLOBs are retrieved KexiBLOBBuffer::self() and stored in "kexi__blobs" 'system' table.
+		 Note that db-aware BLOBs (non local) are not handled this way.
+		*/
+		void setUnsavedLocalBLOB(QWidget *widget, KexiBLOBBuffer::Id_t id);
+
 	public slots:
 		/*! Reimplemented to update resize policy. */
 		virtual void show();
 
+		/*! Inserts autofields onto the form at \a pos position.
+		 \a sourceMimeType can be "kexi/table" or "kexi/query", 
+		 \a sourceName is a name of a table or query, \a fields is a list of fields to insert (one or more)
+		 Fields are inserted using standard KFormDesigner::InsertWidgetCommand framework, 
+		 so undo/redo is available for this operation.
+
+		 If multiple fields are provided, they will be aligned vertically.
+		 If \a pos is QPoint(-1,-1) (the default), position is computed automatically
+		 based on a position last inserted field using this method. 
+		 If this method has not been called yet, position of QPoint(40, 40) will be set.
+
+		 Called by:
+		 - slotHandleDropEvent() when field(s) are dropped from the data source pane onto the form
+		 - KexiFormManager is a used clicked "Insert fields" button on the data source pane. */
+		void insertAutoFields(const QString& sourceMimeType, const QString& sourceName,
+			const QStringList& fields, const QPoint& pos = QPoint(-1,-1));
+
 	protected slots:
-		void managerPropertyChanged(KexiPropertyBuffer *b);
+		void slotPropertySetSwitched(KoProperty::Set *b, bool forceReload = false);
 		void slotDirty(KFormDesigner::Form *f, bool isDirty);
 		void slotFocus(bool in);
+		void slotHandleDragMoveEvent(QDragMoveEvent* e);
+
+		//! Handles field(s) dropping from the data source pane onto the form
+		//! @see insertAutoFields()
+		void slotHandleDropEvent(QDropEvent* e);
 
 //moved to formmanager		void slotWidgetSelected(KFormDesigner::Form *form, bool multiple);
 //moved to formmanager		void slotFormWidgetSelected(KFormDesigner::Form *form);
@@ -90,14 +128,14 @@ class KexiFormView : public KexiDataAwareView
 	protected:
 		virtual tristate beforeSwitchTo(int mode, bool &dontStore);
 		virtual tristate afterSwitchFrom(int mode);
-		virtual KexiPropertyBuffer* propertyBuffer() { return m_buffer; }
+		virtual KoProperty::Set* propertySet() { return m_propertySet; }
 
 		virtual KexiDB::SchemaData* storeNewData(const KexiDB::SchemaData& sdata, bool &cancel);
-		virtual tristate storeData();
+		virtual tristate storeData(bool dontAsk = false);
 
 		KexiFormPart::TempData* tempData() const {
-			return static_cast<KexiFormPart::TempData*>(parentDialog()->tempData()); }
-		KexiFormPart* formPart() const { return static_cast<KexiFormPart*>(part()); }
+			return dynamic_cast<KexiFormPart::TempData*>(parentDialog()->tempData()); }
+		KexiFormPart* formPart() const { return dynamic_cast<KexiFormPart*>(part()); }
 
 //moved to formmanager		void disableWidgetActions();
 //moved to formmanager		void enableFormActions();
@@ -106,7 +144,8 @@ class KexiFormView : public KexiDataAwareView
 
 		void initForm();
 		void loadForm();
-
+		void updateAutoFieldsDataSource();
+		
 		virtual void resizeEvent ( QResizeEvent * );
 
 		void initDataSource();
@@ -129,13 +168,16 @@ class KexiFormView : public KexiDataAwareView
 		/*! @internal */
 		void deleteQuery();
 
+		/*! @internal */
+		void updateDataSourcePage();
+
 		/*! Reimplemented after KexiViewBase.
 		 Updates actions (e.g. availability). */
 // todo		virtual void updateActions(bool activated);
 
 		KexiDBForm *m_dbform;
 		KexiFormScrollView *m_scrollView;
-		KexiPropertyBuffer *m_buffer;
+		KoProperty::Set *m_propertySet;
 
 		/*! Database cursor used for data retrieving.
 		 It is shared between subsequent Data view sessions (just reopened on switch),
@@ -158,6 +200,20 @@ class KexiFormView : public KexiDataAwareView
 		 Our form's area will be resized more than once.
 		 We will resize form widget itself later (in resizeEvent()). */
 		int m_delayedFormContentsResizeOnShow;
+
+		//! Used in setFocusInternal()
+		QGuardedPtr<QWidget> m_setFocusInternalOnce;
+
+	
+		/*! Stores geometry of widget recently inserted using insertAutoFields() method.
+		 having this information, we'r eable to compute position for a newly 
+		 inserted widget in insertAutoFields() is such position has not been specified.
+		 (the position is specified when a widget is inserted with mouse drag & dropping
+		 but not with clicking of 'Insert fields' button from Data Source pane) */
+		QRect m_widgetGeometryForRecentInsertAutoFields;
+
+		//! Used in setUnsavedLocalBLOBs()
+		QMap<QWidget*, KexiBLOBBuffer::Id_t> m_unsavedLocalBLOBs;
 };
 
 #endif
