@@ -70,10 +70,10 @@
 #endif
 
 /*! @internal */
-class KexiQueryDesignerGuiEditorPrivate
+class KexiQueryDesignerGuiEditor::Private
 {
 public:
-	KexiQueryDesignerGuiEditorPrivate()
+	Private()
 		: fieldColumnIdentifiers(101, false/*case insens.*/)
 	{
 		droppedNewItem = 0;
@@ -114,7 +114,7 @@ public:
 KexiQueryDesignerGuiEditor::KexiQueryDesignerGuiEditor(
 	KexiMainWindow *mainWin, QWidget *parent, const char *name)
  : KexiViewBase(mainWin, parent, name)
- , d( new KexiQueryDesignerGuiEditorPrivate() )
+ , d( new Private() )
 {
 	d->conn = mainWin->project()->dbConnection();
 
