@@ -643,7 +643,7 @@ void KexiDataAwareObjectInterface::setCursorPosition(int row, int col/*=-1*/, bo
 
 bool KexiDataAwareObjectInterface::acceptRowEdit()
 {
-	if (!m_rowEditing)
+	if (!m_rowEditing || /*sanity*/!m_data->rowEditBuffer())
 		return true;
 	if (m_inside_acceptEditor) {
 		m_internal_acceptsRowEditAfterCellAccepting = true;
@@ -1171,7 +1171,7 @@ void KexiDataAwareObjectInterface::deleteCurrentRow()
 KexiTableItem *KexiDataAwareObjectInterface::insertEmptyRow(int row)
 {
 	if ( !acceptRowEdit() || !isEmptyRowInsertingEnabled() 
-		|| (row!=-1 && row >= (rows()+isInsertingEnabled()?1:0) ) )
+		|| (row!=-1 && row >= ((int)rows()+(isInsertingEnabled()?1:0) ) ) )
 		return 0;
 
 	KexiTableItem *newItem = m_data->createItem(); //new KexiTableItem(m_data->columns.count());
@@ -1440,11 +1440,12 @@ void KexiDataAwareObjectInterface::slotAboutToDeleteRow(KexiTableItem& item,
 void KexiDataAwareObjectInterface::slotRowDeleted()
 {
 	if (m_rowWillBeDeleted >= 0) {
-		if (m_rowWillBeDeleted > 0 && m_rowWillBeDeleted >= rows())
-			m_rowWillBeDeleted--; //move up
+		if (m_rowWillBeDeleted > 0 && m_rowWillBeDeleted >= (rows()-1) && !m_spreadSheetMode)
+			m_rowWillBeDeleted = rows()-1; //move up if it's the last row
 		updateWidgetContentsSize();
 
-		setCursorPosition(m_rowWillBeDeleted, m_curCol, true/*forceSet*/);
+		if (! (m_spreadSheetMode && m_rowWillBeDeleted>=(rows()-1)))
+			setCursorPosition(m_rowWillBeDeleted, m_curCol, true/*forceSet*/);
 		if (m_verticalHeader)
 			m_verticalHeader->removeLabel();
 
@@ -1470,6 +1471,9 @@ bool KexiDataAwareObjectInterface::deleteItem(KexiTableItem *item)/*, bool moveC
 
 	QString msg, desc;
 //	bool current = (item == d->pCurrentItem);
+	const bool lastRowDeleted = m_spreadSheetMode && m_data->last() == item; //we need to know this so we
+	                                                                         //can return to the last row 
+	                                                                         //after reinserting it
 	if (!m_data->deleteRow(*item, true /*repaint*/)) {
 		//error
 		if (m_data->result()->desc.isEmpty())
@@ -1485,9 +1489,11 @@ bool KexiDataAwareObjectInterface::deleteItem(KexiTableItem *item)/*, bool moveC
 
 //	repaintAfterDelete();
 	if (m_spreadSheetMode) { //append empty row for spreadsheet mode
-			m_data->append(m_data->createItem());//new KexiTableItem(m_data->columns.count()));
-			if (m_verticalHeader)
-				m_verticalHeader->addLabels(1);
+		m_data->append(m_data->createItem());//new KexiTableItem(m_data->columns.count()));
+		if (m_verticalHeader)
+			m_verticalHeader->addLabels(1);
+		if (lastRowDeleted) //back to the last row
+			setCursorPosition(rows()-1, m_curCol, true/*forceSet*/);
 	}
 	return true;
 }
