@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
    Copyright (C) 2002   Lucijan Busch <lucijan@gmx.at>
-   Daniel Molkentin <molkentin@kde.org>
-   Copyright (C) 2003-2004 Jaroslaw Staniek <js@iidea.pl>
+   Copyright (C) 2003   Daniel Molkentin <molkentin@kde.org>
+   Copyright (C) 2003-2005 Jaroslaw Staniek <js@iidea.pl>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  
    Original Author:  Till Busch <till@bux.at>
    Original Project: buX (www.bux.at)
@@ -24,13 +24,14 @@
 
 #include "kexitableviewdata.h"
 
-#include <kexivalidator.h>
+#include <kexiutils/validator.h>
 
 #include <kexidb/field.h>
 #include <kexidb/queryschema.h>
 #include <kexidb/roweditbuffer.h>
 #include <kexidb/cursor.h>
 #include <kexidb/utils.h>
+#include <kexi.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -75,6 +76,24 @@ KexiTableViewColumn::KexiTableViewColumn(const QString& name, KexiDB::Field::Typ
 	init();
 }
 
+KexiTableViewColumn::KexiTableViewColumn(const QString& name, KexiDB::Field::Type ctype, const QString& caption,
+	const QString& description)
+: fieldinfo(0)
+{
+	m_field = new KexiDB::Field(
+		name, ctype,
+		KexiDB::Field::NoConstraints,
+		KexiDB::Field::NoOptions,
+		0, 0,
+		QVariant(),
+		caption, description);
+
+	isDBAware = false;
+	m_fieldOwned = true;
+	m_captionAliasOrName = m_field->captionOrName();
+	init();
+}
+
 KexiTableViewColumn::KexiTableViewColumn(
 	const KexiDB::QuerySchema &query, KexiDB::QueryColumnInfo& fi)
 //	const KexiDB::QuerySchema &query, KexiDB::Field& f)
@@ -97,11 +116,14 @@ KexiTableViewColumn::KexiTableViewColumn(
 		//todo: compute other auto-name?
 	}
 	init();
-	//setup column's readonly flag: true if this is parent table's field
-	m_readOnly = (query.masterTable()!=fieldinfo->field->table());
-	kdDebug() << "KexiTableViewColumn: query.masterTable()==" 
-		<< (query.masterTable() ? query.masterTable()->name() : "notable") << ", fieldinfo->field->table()=="
-		<< (fieldinfo->field->table() ? fieldinfo->field->table()->name()  : "notable") << endl;
+	//setup column's readonly flag: 
+	// true if it's not from parent table's field or if the query itself is coming read-only connection
+	m_readOnly = (query.masterTable()!=fieldinfo->field->table())
+		|| (query.connection() && query.connection()->isReadOnly());
+//	kdDebug() << "KexiTableViewColumn: query.masterTable()==" 
+//		<< (query.masterTable() ? query.masterTable()->name() : "notable") << ", fieldinfo->field->table()=="
+//		<< (fieldinfo->field->table() ? fieldinfo->field->table()->name()  : "notable") << endl;
+
 //	m_visible = query.isFieldVisible(&f);
 }
 
@@ -131,7 +153,7 @@ void KexiTableViewColumn::init()
 	m_relatedDataEditable = false;
 }
 
-void KexiTableViewColumn::setValidator( KexiValidator* v )
+void KexiTableViewColumn::setValidator( KexiUtils::Validator* v )
 {
 	if (m_validator) {//remove old one
 		if (!m_validator->parent()) //destroy if has no parent
@@ -204,6 +226,7 @@ KexiTableViewData::KexiTableViewData(KexiDB::Cursor *c)
 {
 	init();
 	m_cursor = c;
+	m_containsROWIDInfo = m_cursor->containsROWIDInfo();
 
 	KexiDB::QueryColumnInfo::Vector vector 
 		= m_cursor->query()->fieldsExpanded();
@@ -238,6 +261,7 @@ KexiTableViewData::KexiTableViewData(
 KexiTableViewData::~KexiTableViewData()
 {
 	emit destroying();
+	clearInternal();
 }
 
 void KexiTableViewData::init(
@@ -299,6 +323,7 @@ void KexiTableViewData::init()
 	m_globalColumnsIDs.resize(100);
 
 	m_autoIncrementedColumn = -2;
+	m_containsROWIDInfo = false;
 }
 
 void KexiTableViewData::addColumn( KexiTableViewColumn* col )
@@ -353,11 +378,28 @@ void KexiTableViewData::setSorting(int column, bool ascending)
 		return;
 	}
 
-	const int t = columns.at(m_key)->field()->type();
-	if (t == KexiDB::Field::Boolean || KexiDB::Field::isNumericType(t))
-		cmpFunc = &KexiTableViewData::cmpInt;
+	const KexiDB::Field *field = columns.at(m_key)->field();
+	const int t = field->type();
+	if (KexiDB::Field::isFPNumericType(t))
+		cmpFunc = &KexiTableViewData::cmpDouble;
+	else if (t==KexiDB::Field::BigInteger) {
+		if (field->isUnsigned())
+			cmpFunc = &KexiTableViewData::cmpULongLong;
+		else
+			cmpFunc = &KexiTableViewData::cmpLongLong;
+	}
+	else if (t == KexiDB::Field::Integer && field->isUnsigned())
+		cmpFunc = &KexiTableViewData::cmpUInt;
+	else if (t == KexiDB::Field::Boolean || KexiDB::Field::isNumericType(t))
+		cmpFunc = &KexiTableViewData::cmpInt; //other integers
+	else if (t == KexiDB::Field::Date)
+		cmpFunc = &KexiTableViewData::cmpDate;
+	else if (t == KexiDB::Field::Time)
+		cmpFunc = &KexiTableViewData::cmpTime;
+	else if (t == KexiDB::Field::DateTime)
+		cmpFunc = &KexiTableViewData::cmpDateTime;
 	else
-		cmpFunc = &KexiTableViewData::cmpStr;
+		cmpFunc = &KexiTableViewData::cmpStr; //text or anything else
 }
 
 int KexiTableViewData::compareItems(Item item1, Item item2)
@@ -365,15 +407,68 @@ int KexiTableViewData::compareItems(Item item1, Item item2)
 	return ((this->*cmpFunc) (item1, item2));
 }
 
+//! compare NULLs : NULL is smaller than everything
+#define CMP_NULLS(item1, item2) \
+	m_leftTmp = ((KexiTableItem *)item1)->at(m_key); \
+	if (m_leftTmp.isNull()) \
+		return -m_order; \
+	m_rightTmp = ((KexiTableItem *)item2)->at(m_key); \
+	if (m_rightTmp.isNull()) \
+		return m_order
+
+#define CAST_AND_COMPARE(casting, item1, item2) \
+	CMP_NULLS(item1, item2); \
+	if (m_leftTmp.casting() < m_rightTmp.casting()) \
+		return -m_order; \
+	if (m_leftTmp.casting() > m_rightTmp.casting()) \
+		return m_order; \
+	return 0
+
 int KexiTableViewData::cmpInt(Item item1, Item item2)
 {
-	return m_order* (((KexiTableItem *)item1)->at(m_key).toInt() - ((KexiTableItem *)item2)->at(m_key).toInt());
+	CAST_AND_COMPARE(toInt, item1, item2);
+}
+
+int KexiTableViewData::cmpUInt(Item item1, Item item2)
+{
+	CAST_AND_COMPARE(toUInt, item1, item2);
+}
+
+int KexiTableViewData::cmpLongLong(Item item1, Item item2)
+{
+	CAST_AND_COMPARE(toLongLong, item1, item2);
+}
+
+int KexiTableViewData::cmpULongLong(Item item1, Item item2)
+{
+	CAST_AND_COMPARE(toULongLong, item1, item2);
+}
+
+int KexiTableViewData::cmpDouble(Item item1, Item item2)
+{
+	CAST_AND_COMPARE(toDouble, item1, item2);
+}
+
+int KexiTableViewData::cmpDate(Item item1, Item item2)
+{
+	CAST_AND_COMPARE(toDate, item1, item2);
+}
+
+int KexiTableViewData::cmpDateTime(Item item1, Item item2)
+{
+	CAST_AND_COMPARE(toDateTime, item1, item2);
+}
+
+int KexiTableViewData::cmpTime(Item item1, Item item2)
+{
+	CAST_AND_COMPARE(toDate, item1, item2);
 }
 
 int KexiTableViewData::cmpStr(Item item1, Item item2)
 {
-	const QString &as =((KexiTableItem *)item1)->at(m_key).toString();
-	const QString &bs =((KexiTableItem *)item2)->at(m_key).toString();
+	CMP_NULLS(item1, item2);
+	const QString &as = m_leftTmp.toString();
+	const QString &bs = m_rightTmp.toString();
 
 	const QChar *a = as.unicode();
 	const QChar *b = bs.unicode();
@@ -381,9 +476,9 @@ int KexiTableViewData::cmpStr(Item item1, Item item2)
 	if ( a == b )
 		return 0;
 	if ( a == 0 )
-		return 1;
-	if ( b == 0 )
 		return -1;
+	if ( b == 0 )
+		return 1;
 
 	unsigned short au;
 	unsigned short bu;
@@ -481,7 +576,7 @@ bool KexiTableViewData::updateRowEditBufferRef(KexiTableItem *item,
 //get a new value (of present in the buffer), or the old one, otherwise
 //(taken here for optimization)
 #define GET_VALUE if (!val) { \
-	val = m_cursor ? rowEditBuffer()->at( *it_f.current()->fieldinfo ) : rowEditBuffer()->at( *f ); \
+	val = m_cursor ? m_pRowEditBuffer->at( *it_f.current()->fieldinfo ) : m_pRowEditBuffer->at( *f ); \
 	if (!val) \
 		val = &(*it_r); /* get old value */ \
 	}
@@ -507,7 +602,7 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
 			if (val->isNull() && !f->isAutoIncrement()) {
 				//NOT NULL violated
 				m_result.msg = i18n("\"%1\" column requires a value to be entered.")
-					.arg(f->captionOrName()) + "\n\n" + KexiValidator::msgYouCanImproveData();
+					.arg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
 				m_result.desc = i18n("The column's constraint is declared as NOT NULL.");
 				m_result.column = col;
 				return false;
@@ -518,7 +613,7 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
 			if (!f->isAutoIncrement() && (val->isNull() || KexiDB::isEmptyValue( f, *val ))) {
 				//NOT EMPTY violated
 				m_result.msg = i18n("\"%1\" column requires a value to be entered.")
-					.arg(f->captionOrName()) + "\n\n" + KexiValidator::msgYouCanImproveData();
+					.arg(f->captionOrName()) + "\n\n" + Kexi::msgYouCanImproveData();
 				m_result.desc = i18n("The column's constraint is declared as NOT EMPTY.");
 				m_result.column = col;
 				return false;
@@ -528,8 +623,11 @@ bool KexiTableViewData::saveRow(KexiTableItem& item, bool insert, bool repaint)
 
 	if (m_cursor) {//db-aware
 		if (insert) {
-			if (!m_cursor->insertRow( static_cast<KexiDB::RowData&>(item), *rowEditBuffer() )) {
-				m_result.msg = i18n("Row inserting failed.") + "\n\n" + KexiValidator::msgYouCanImproveData();
+			if (!m_cursor->insertRow( static_cast<KexiDB::RowData&>(item), *m_pRowEditBuffer, 
+				m_containsROWIDInfo/*also retrieve ROWID*/ )) 
+			{
+				m_result.msg = i18n("Row inserting failed.") + "\n\n" 
+					+ Kexi::msgYouCanImproveData();
 				KexiDB::getHTMLErrorMesage(m_cursor, &m_result);
 
 /*			if (desc)
@@ -543,8 +641,13 @@ js: TODO: use KexiMainWindowImpl::showErrorMessage(const QString &title, KexiDB:
 			}
 		}
 		else {
-			if (!m_cursor->updateRow( static_cast<KexiDB::RowData&>(item), *rowEditBuffer() )) {
-				m_result.msg = i18n("Row changing failed.") + "\n\n" + KexiValidator::msgYouCanImproveData();
+//			if (m_containsROWIDInfo)
+//				ROWID = item[columns.count()].toULongLong();
+			if (!m_cursor->updateRow( static_cast<KexiDB::RowData&>(item), *m_pRowEditBuffer,
+					m_containsROWIDInfo/*use ROWID*/))
+			{
+				m_result.msg = i18n("Row changing failed.") + "\n\n" + Kexi::msgYouCanImproveData();
+//! @todo set m_result.column if possible
 				KexiDB::getHTMLErrorMesage(m_cursor, m_result.desc);
 				return false;
 			}
@@ -562,6 +665,9 @@ js: TODO: use KexiMainWindowImpl::showErrorMessage(const QString &title, KexiDB:
 			}
 		}
 	}
+	
+	m_pRowEditBuffer->clear();
+
 	if (repaint)
 		emit rowRepaintRequested(item);
 	return true;
@@ -571,7 +677,7 @@ bool KexiTableViewData::saveRowChanges(KexiTableItem& item, bool repaint)
 {
 	kdDebug() << "KexiTableViewData::saveRowChanges()..." << endl;
 	m_result.clear();
-	emit aboutToUpdateRow(&item, rowEditBuffer(), &m_result);
+	emit aboutToUpdateRow(&item, m_pRowEditBuffer, &m_result);
 	if (!m_result.success)
 		return false;
 
@@ -606,7 +712,7 @@ bool KexiTableViewData::deleteRow(KexiTableItem& item, bool repaint)
 
 	if (m_cursor) {//db-aware
 		m_result.success = false;
-		if (!m_cursor->deleteRow( static_cast<KexiDB::RowData&>(item) )) {
+		if (!m_cursor->deleteRow( static_cast<KexiDB::RowData&>(item), m_containsROWIDInfo/*use ROWID*/ )) {
 			m_result.msg = i18n("Row deleting failed.");
 /*js: TODO: use KexiDB::errorMessage() for description (desc) as in KexiTableViewData::saveRow() */
 			KexiDB::getHTMLErrorMesage(m_cursor, &m_result);
@@ -627,6 +733,8 @@ bool KexiTableViewData::deleteRow(KexiTableItem& item, bool repaint)
 
 void KexiTableViewData::deleteRows( const QValueList<int> &rowsToDelete, bool repaint )
 {
+	Q_UNUSED( repaint );
+
 	if (rowsToDelete.isEmpty())
 		return;
 	int last_r=0;
@@ -654,9 +762,17 @@ void KexiTableViewData::insertRow(KexiTableItem& item, uint index, bool repaint)
 void KexiTableViewData::clearInternal()
 {
 	clearRowEditBuffer();
-	qApp->processEvents( 1 );
+//	qApp->processEvents( 1 );
 //TODO: this is time consuming: find better data model
-	KexiTableViewDataBase::clear();
+//	KexiTableViewDataBase::clear();
+	const uint c = count();
+	for (uint i=0; i<c; i++) {
+		removeLast();
+#ifndef KEXI_NO_PROCESS_EVENTS
+		if (i % 1000 == 0)
+			qApp->processEvents( 1 );
+#endif
+	}
 }
 
 bool KexiTableViewData::deleteAllRows(bool repaint)
@@ -695,17 +811,24 @@ void KexiTableViewData::preloadAllRows()
 	if (!m_cursor)
 		return;
 
-	const uint fcount = m_cursor->fieldCount();
+	const uint fcount = m_cursor->fieldCount() + (m_containsROWIDInfo ? 1 : 0);
 	m_cursor->moveFirst();
 	for (int i=0;!m_cursor->eof();i++) {
 		KexiTableItem *item = new KexiTableItem(fcount);
 		m_cursor->storeCurrentRow(*item);
 		append( item );
 		m_cursor->moveNext();
-		if ((i % 100) == 0)
+#ifndef KEXI_NO_PROCESS_EVENTS
+		if ((i % 1000) == 0)
 			qApp->processEvents( 1 );
+#endif
 	}
 }
 
+bool KexiTableViewData::isReadOnly() const
+{
+	return m_readOnly || (m_cursor && m_cursor->connection()->isReadOnly());
+}
+
 #include "kexitableviewdata.moc"
 
