@@ -14,12 +14,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef KIVIO_FACTORY_H
 #define KIVIO_FACTORY_H
 
-#include <koFactory.h>
+#include <KoFactory.h>
 #include <koffice_export.h>
 class KInstance;
 class KAboutData;
