@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef __kivio_page_h__
 #define __kivio_page_h__
@@ -32,10 +32,9 @@ class QDomElement;
 
 class KivioLayer;
 class KoPoint;
-class KivioGuideLines;
 class DCOPObject;
 
-#include <koDocument.h>
+#include <KoDocument.h>
 
 #include <qpen.h>
 #include <qptrlist.h>
@@ -44,7 +43,7 @@ class DCOPObject;
 #include <qrect.h>
 #include <qpalette.h>
 #include <qwidget.h>
-#include <koPoint.h>
+#include <KoPoint.h>
 
 #include "kivio_stencil.h"
 #include <koffice_export.h>
@@ -86,7 +85,7 @@ class KIVIO_EXPORT KivioPage : public QObject
     virtual DCOPObject* dcopObject();
 
     QString pageName()const { return m_strName; }
-    bool setPageName( const QString& name, bool init = FALSE );
+    bool setPageName( const QString& name, bool init = false );
 
     virtual QDomElement save( QDomDocument& );
     virtual void saveOasis(KoStore* store, KoXmlWriter* docWriter, KoGenStyles* styles);
@@ -112,9 +111,10 @@ class KIVIO_EXPORT KivioPage : public QObject
     KoPageLayout paperLayout()const { return m_pPageLayout; }
     void setPaperLayout(const KoPageLayout&);
 
-    void paintContent( KivioPainter& painter, const QRect& rect, bool transparent, QPoint, KoZoomHandler*, bool );
+    void paintContent( KivioPainter& painter, const QRect& rect, bool transparent, QPoint, KoZoomHandler*, bool, bool );
     void printContent( KivioPainter& painter, int xdpi = 0, int ydpi = 0 );
     void printSelected( KivioPainter& painter, int xdpi = 0, int ydpi = 0 );
+    void printContent(KivioPainter& painter, KoZoomHandler* zoomHandler);
 
     bool isStencilSelected( KivioStencil * );
     void selectAllStencils();
@@ -147,7 +147,6 @@ class KIVIO_EXPORT KivioPage : public QObject
     void insertLayer( int, KivioLayer * );
     KivioLayer *layerAt( int );
     void takeLayer( KivioLayer *pLayer );
-    KivioGuideLines* guideLines()const{ return gLines; }
 
     /*
     * Stencil routines
@@ -160,7 +159,10 @@ class KIVIO_EXPORT KivioPage : public QObject
     KoPoint snapToTarget( const KoPoint& p, double thresh, bool& hit );
 
     void setHidePage(bool _hide);
-    
+
+    QValueList<double> horizontalGuideLines() const { return m_hGuideLines; }
+    QValueList<double> verticalGuideLines() const { return m_vGuideLines; }
+
   public slots:
     void deleteSelectedStencils();
     void groupSelectedStencils();
@@ -175,6 +177,9 @@ class KIVIO_EXPORT KivioPage : public QObject
     
     void setPaintSelected(bool paint = true);
 
+    void setGuideLines(const QValueList<double> hGuideLines, const QValueList<double> vGuideLines);
+    void addGuideLine(Qt::Orientation orientation, double position);
+
   signals:
     void sig_updateView( KivioPage *_page );
     void sig_updateView( KivioPage *_page, const QRect& );
@@ -191,6 +196,9 @@ class KIVIO_EXPORT KivioPage : public QObject
     QDomElement saveLayout( QDomDocument & );
     bool loadLayout( const QDomElement & );
 
+    void saveGuideLines(QDomElement& element);
+    void loadGuideLines(const QDomElement& element);
+
     QString m_strName;
 
     KivioMap *m_pMap;
@@ -208,8 +216,10 @@ class KIVIO_EXPORT KivioPage : public QObject
 
     KoPageLayout m_pPageLayout;
 
-    KivioGuideLines* gLines;
     DCOPObject* m_dcop;
+
+    QValueList<double> m_hGuideLines;
+    QValueList<double> m_vGuideLines;
 };
 
 #endif
