@@ -2,7 +2,7 @@
 #define KIVIO_STENCIL_GEOMETRY_PANEL_H
 
 #include <qwidget.h>
-#include <koUnit.h>
+#include <KoUnit.h>
 
 class KoPageLayout;
 class KoUnitDoubleSpinBox;
