@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef KIVIOARROWHEADACTION_H
@@ -52,7 +52,7 @@ class KivioArrowHeadAction : public KActionMenu
     void endChanged(int);
 
   protected:
-    void loadArrowHeads(KPopupMenu* combo, bool endArrow);
+    void loadArrowHeads(KPopupMenu* combo);
 
   protected:
     KPopupMenu* m_popup;
