@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef KIVIO_BASE_TARGET_STENCIL_H
 #define KIVIO_BASE_TARGET_STENCIL_H
@@ -31,8 +31,6 @@ class KivioFillStyle;
 class KivioIntraStencilData;
 class KivioLineStyle;
 class KivioPage;
-class KivioPoint;
-class KivioRect;
 class KivioStencilSpawner;
 class KivioTextStyle;
 
