@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef KIVIO_SML_STENCIL_H
 #define KIVIO_SML_STENCIL_H
@@ -134,6 +134,7 @@ public:
     virtual void setText( const QString & );
 
     virtual QFont textFont();
+    virtual QColor textColor();
 
     virtual KivioCollisionType checkForCollision( KoPoint *, double );
 
@@ -161,8 +162,21 @@ public:
     virtual QString text(const QString& name);
 
     virtual void addConnectorTarget(const KoPoint&);
+    virtual void removeConnectorTarget(const KoPoint&);
 
     virtual bool hasTextBox() const;
+
+    virtual QColor textColor(const QString& textBoxName);
+    virtual void setTextColor(const QString& textBoxName, const QColor& color);
+
+    virtual QFont textFont(const QString& textBoxName);
+    virtual void setTextFont(const QString& textBoxName, const QFont& font);
+
+    virtual int hTextAlign(const QString& textBoxName);
+    virtual int vTextAlign(const QString& textBoxName);
+
+    virtual void setHTextAlign(const QString& textBoxName, int align);
+    virtual void setVTextAlign(const QString& textBoxName, int align);
 };
 
 #endif
