@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 #ifndef KIVIO_STENCIL_FACTORY_H
 #define KIVIO_STENCIL_FACTORY_H
@@ -29,13 +29,13 @@ class QPixmap;
 #include <koffice_export.h>
 class KIVIO_EXPORT KivioStencilFactory : public QObject
 {
-	Q_OBJECT
-    public:
-	KivioStencilFactory(QObject *parent=0, const char*name=0, const QStringList& args = QStringList()) :
-		QObject(parent, name){;}
-	virtual KivioStencil *NewStencil(const QString& name) =0;
-	virtual KivioStencil *NewStencil()=0;
-    	virtual QPixmap *GetIcon()=0;
-    	virtual KivioStencilSpawnerInfo *GetSpawnerInfo()=0;
+  Q_OBJECT
+  public:
+    KivioStencilFactory(QObject *parent=0, const char*name=0, const QStringList& args = QStringList())
+      : QObject(parent, name) { Q_UNUSED(args) }
+    virtual KivioStencil *NewStencil(const QString& name) =0;
+    virtual KivioStencil *NewStencil()=0;
+    virtual QPixmap *GetIcon()=0;
+    virtual KivioStencilSpawnerInfo *GetSpawnerInfo()=0;
 };
 #endif
