@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 /**************************************************************************************
  *
@@ -38,9 +38,10 @@
 #include <kactionclasses.h>
 #include <kpopupmenu.h>
 #include <kdebug.h>
-#include <kozoomhandler.h>
-#include <koPoint.h>
+#include <KoZoomHandler.h>
+#include <KoPoint.h>
 #include <klocale.h>
+#include <KoGuides.h>
 #include "kivio_command.h"
 
 #include <qwmatrix.h>
@@ -51,16 +52,18 @@ SelectTool::SelectTool( KivioView* parent ) : Kivio::MouseTool(parent, "Selectio
 {
   view()->pluginManager()->setDefaultTool(this);
 
-  m_selectAction = new KRadioAction(i18n("&Select"), "select", Key_Space, actionCollection(), "select");
+  KShortcut selectShortCut(Key_Space);
+  selectShortCut.setSeq(1, QKeySequence(Key_Escape));
+  m_selectAction = new KRadioAction(i18n("&Select"), "select", selectShortCut, actionCollection(), "select");
   connect(m_selectAction, SIGNAL(toggled(bool)), this, SLOT(setActivated(bool)));
 
-  m_textEditAction = new KAction(i18n("&Edit Text..."), "text", Key_F2, this, SLOT(editStencilText()), actionCollection(), "editText");
-  m_textFormatAction = new KAction(i18n("Format &Text..."), 0, 0, view(), SLOT(textFormat()), actionCollection(), "formatText");
+  m_textEditAction = new KAction(i18n("&Edit Text..."), "text", Key_F2,
+                                 this, SLOT(editStencilText()), actionCollection(), "editText");
   (void) new KAction(i18n("Format &Stencils && Connectors..."), 0, 0, view(), SLOT(stencilFormat()),
                           actionCollection(), "formatStencil");
   m_arrowHeadAction = new KAction(i18n("Format &Arrowheads..."), 0, 0, view(), SLOT(arrowHeadFormat()),
                                   actionCollection(), "formatConnector");
-  
+
   m_mode = stmNone;
   m_pResizingStencil = NULL;
   m_pCustomDraggingStencil = NULL;
@@ -105,7 +108,7 @@ bool SelectTool::processEvent(QEvent* e)
       if( m->button() == RightButton ) {
         showPopupMenu(m->globalPos());
       } else if( m->button() == LeftButton ) {
-        if((m->state() & ControlButton) || (m->state() & ShiftButton)) {
+        if(m->state() & ControlButton) {
           m_controlKey = true;
         } else {
           m_controlKey = false;
@@ -147,7 +150,7 @@ void SelectTool::setActivated(bool a)
 {
   if(a) {
     m_selectAction->setChecked(true);
-    view()->canvasWidget()->setCursor(arrowCursor);
+    view()->canvasWidget()->unsetCursor();
     m_mode = stmNone;
     emit activated(this);
   } else if(m_selectAction->isChecked()) {
@@ -289,6 +292,8 @@ bool SelectTool::startDragging(const QPoint &pos, bool onlySelected)
       pPage->unselectAllStencils();
 
     pPage->selectStencil( pStencil );
+    // Update the auto guidelines
+    view()->canvasWidget()->updateAutoGuideLines();
   }
 
   // Create a new painter object
@@ -357,6 +362,10 @@ bool SelectTool::startCustomDragging(const QPoint &pos, bool selectedOnly )
   m_mode = stmCustomDragging;
 
   m_customDragID = colType;
+  m_customDragOrigPoint = pStencil->customIDPoint(m_customDragID);
+
+  view()->canvasWidget()->setShowConnectorTargets(true);
+  view()->canvasWidget()->repaint();
 
   // Create a new painter object
   canvas->beginUnclippedSpawnerPainter();
@@ -516,31 +525,46 @@ void SelectTool::continueDragging(const QPoint &pos, bool ignoreGridGuides)
   if(!ignoreGridGuides) {
     // First attempt a snap-to-grid
     p.setCoords(newX, newY);
-    
+
     p = canvas->snapToGrid(p);
-  
+
     newX = p.x();
     newY = p.y();
-  
+
     // Now the guides override the grid so we attempt to snap to them
+    // The bottom
     p.setCoords(m_selectedRect.x() + dx + m_selectedRect.width(), m_selectedRect.y() + dy + m_selectedRect.height());
     p = canvas->snapToGuides(p, snappedX, snappedY);
-  
+
     if(snappedX) {
       newX = p.x() - m_selectedRect.width();
     }
-  
+
     if(snappedY) {
       newY = p.y() - m_selectedRect.height();
     }
-  
+
+    // The middle
+    p.setCoords(m_selectedRect.x() + dx + (m_selectedRect.width() / 2.0),
+                m_selectedRect.y() + dy + (m_selectedRect.height() / 2.0));
+    p = canvas->snapToGuides(p, snappedX, snappedY);
+
+    if(snappedX) {
+      newX = p.x() - (m_selectedRect.width() / 2.0);
+    }
+
+    if(snappedY) {
+      newY = p.y() - (m_selectedRect.height() / 2.0);
+    }
+
+    // The top
     p.setCoords(m_selectedRect.x() + dx, m_selectedRect.y() + dy);
     p = canvas->snapToGuides(p, snappedX, snappedY);
-  
+
     if(snappedX) {
       newX = p.x();
     }
-  
+
     if(snappedY) {
       newY = p.y();
     }
@@ -585,7 +609,7 @@ void SelectTool::continueCustomDragging(const QPoint &pos)
   }
 
   if(!hit) {
-    pagePoint = canvas->snapToGrid( pagePoint );
+    pagePoint = canvas->snapToGridAndGuides( pagePoint );
   }
 
   KivioCustomDragData data;
@@ -598,22 +622,28 @@ void SelectTool::continueCustomDragging(const QPoint &pos)
   data.scale = view()->zoomHandler()->zoomedResolutionY();
 
 
-  // Undraw the old stencils
-  if(!m_firstTime) {
-    canvas->drawStencilXOR(m_pCustomDraggingStencil);
-  } else {
-    m_pCustomDraggingStencil->setHidden(true);
-    canvas->repaint();
-    m_firstTime = false;
+  if(m_pCustomDraggingStencil->type() != kstConnector){
+    // Undraw the old stencils
+    if(!m_firstTime) {
+      canvas->drawStencilXOR(m_pCustomDraggingStencil);
+    } else {
+      m_pCustomDraggingStencil->setHidden(true);
+      canvas->repaint();
+      m_firstTime = false;
+    }
   }
 
-
   // Custom dragging can only occur on one stencil
   if( m_pCustomDraggingStencil )
     m_pCustomDraggingStencil->customDrag( &data );
 
   // Draw the stencils
-  canvas->drawStencilXOR(m_pCustomDraggingStencil);
+  if(m_pCustomDraggingStencil->type() != kstConnector){
+    canvas->drawStencilXOR(m_pCustomDraggingStencil);
+  } else {
+    view()->canvasWidget()->repaint();
+  }
+
   view()->updateToolBars();
 }
 
@@ -845,7 +875,7 @@ void SelectTool::changeMouseCursor(const QPoint &pos)
     pStencil = canvas->activePage()->selectedStencils()->next();
   }
 
-  canvas->setCursor( arrowCursor );
+  canvas->unsetCursor();
 }
 
 
@@ -964,6 +994,7 @@ void SelectTool::mouseRelease(const QPoint &pos)
 
   m_mode = stmNone;
 
+  view()->canvasWidget()->guideLines().repaintAfterSnapping();
   view()->doc()->updateView(view()->activePage());
 }
 
@@ -1027,8 +1058,11 @@ void SelectTool::endCustomDragging(const QPoint&)
 {
   KivioCanvas* canvas = view()->canvasWidget();
   m_pCustomDraggingStencil->setHidden(false);
+  KivioCustomDragCommand* cmd = new KivioCustomDragCommand(i18n("Move Connector Point"), view()->activePage(),
+      m_pCustomDraggingStencil, m_customDragID, m_customDragOrigPoint,
+      m_pCustomDraggingStencil->customIDPoint(m_customDragID));
+  view()->doc()->addCommand(cmd);
   m_customDragID = 0;
-  canvas->drawStencilXOR(m_pCustomDraggingStencil);
   KivioStencil *pStencil = canvas->activePage()->selectedStencils()->first();
 
   while( pStencil )
@@ -1041,6 +1075,9 @@ void SelectTool::endCustomDragging(const QPoint&)
   }
 
   canvas->endUnclippedSpawnerPainter();
+
+  canvas->setShowConnectorTargets(false);
+  canvas->repaint();
 }
 
 void SelectTool::endResizing(const QPoint&)
@@ -1080,10 +1117,8 @@ void SelectTool::showPopupMenu( const QPoint &pos )
 
     if(view()->activePage()->checkForTextBoxesInSelection()) {
       m_textEditAction->setEnabled(true);
-      m_textFormatAction->setEnabled(true);
     } else {
       m_textEditAction->setEnabled(false);
-      m_textFormatAction->setEnabled(false);
     }
   }
 
@@ -1219,6 +1254,7 @@ void SelectTool::keyPress(QKeyEvent* e)
   }
   
   endDragging(QPoint());
+  canvas->guideLines().repaintAfterSnapping();
   canvas->setFocus();
 }
 
