@@ -753,6 +753,16 @@ QString Project::uniqueNodeId(int seed) {
     return QString("%1").arg(i);
 }
 
+bool Project::removeId(const QString &id) {
+    kdDebug()<<k_funcinfo<<"id="<<id<<endl;
+    return (m_parent ? m_parent->removeId(id) : nodeIdDict.remove(id)); 
+}
+    /// Insert the node with identity id
+void Project::insertId(const QString &id, const Node *node) {
+    kdDebug()<<k_funcinfo<<"id="<<id<<": "<<node->name()<<endl;
+    m_parent ? m_parent->insertId(id, node) : nodeIdDict.insert(id, node);
+}
+
 ResourceGroup *Project::group(QString id) {
     return findResourceGroup(id);
 }
@@ -1012,6 +1022,16 @@ MainSchedule *Project::createSchedule(QString name, Schedule::Type type) {
     return sch;
 }
 
+bool Project::removeCalendarId(const QString &id) {
+    kdDebug()<<k_funcinfo<<"id="<<id<<endl;
+    return calendarIdDict.remove(id); 
+}
+
+void Project::insertCalendarId(const QString &id, const Calendar *calendar) { 
+    kdDebug()<<k_funcinfo<<"id="<<id<<": "<<calendar->name()<<endl;
+    calendarIdDict.insert(id, calendar);
+}
+        
 #ifndef NDEBUG
 void Project::printDebug(bool children, QCString indent) {
 
