@@ -1367,9 +1367,8 @@ QImage KisImage::convertToQImage(Q_INT32 x1,
     QImage img = dev->convertToQImage(profile, x1, y1, w, h, exposure);
 
     if (!img.isNull()) {
-
 #ifdef __BIG_ENDIAN__
-        uchar * data = img.bits();
+    uchar * data = img.bits();
         for (int i = 0; i < w * h; ++i) {
             uchar r, g, b, a;
             a = data[0];
@@ -1447,6 +1446,22 @@ QImage KisImage::convertToQImage(const QRect& r, const QSize& scaledImageSize, K
     QImage image = colorSpace()->convertToQImage(scaledImageData, r.width(), r.height(), profile, INTENT_PERCEPTUAL, exposure);
     delete [] scaledImageData;
 
+#ifdef __BIG_ENDIAN__
+    uchar * data = image.bits();
+    for (int i = 0; i < image.width() * image.height(); ++i) {
+      uchar r, g, b, a;
+      a = data[0];
+      b = data[1];
+      g = data[2];
+      r = data[3];
+      data[0] = r;
+      data[1] = g;
+      data[2] = b;
+      data[3] = a;
+      data += 4;
+    }
+#endif
+    
     if (paintFlags & PAINT_BACKGROUND) {
         m_bkg->paintBackground(image, r, scaledImageSize, QSize(imageWidth, imageHeight));
         image.setAlphaBuffer(false);
