@@ -18,37 +18,40 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
+#include <dcopclient.h>
+#include <kapplication.h>
+#include <kdebug.h>
+
+#include "kspread_doc.h"
+#include "kspread_map.h"
+#include "kspread_sheet.h"
+
 #include "KSpreadMapIface.h"
 
-#include "kspread_map.h"
-#include "kspread_doc.h"
+using namespace KSpread;
 
-#include <kapplication.h>
-#include <dcopclient.h>
-#include <kdebug.h>
-
-KSpreadMapIface::KSpreadMapIface( KSpreadMap* map )
+MapIface::MapIface( Map* map )
     : DCOPObject( map )
 {
     m_map = map;
 }
 
-DCOPRef KSpreadMapIface::sheet( const QString& name )
+DCOPRef MapIface::sheet( const QString& name )
 {
-    KSpreadSheet* t = m_map->findSheet( name );
+    Sheet* t = m_map->findSheet( name );
     if ( !t )
         return DCOPRef();
 
     return DCOPRef( kapp->dcopClient()->appId(), t->dcopObject()->objId() );
 }
 
-DCOPRef KSpreadMapIface::sheetByIndex( int index )
+DCOPRef MapIface::sheetByIndex( int index )
 {
-    KSpreadSheet* t = m_map->sheetList().at( index );
+    Sheet* t = m_map->sheetList().at( index );
     if ( !t )
     {
         kdDebug(36001) << "+++++ No table found at index " << index << endl;
@@ -60,63 +63,63 @@ DCOPRef KSpreadMapIface::sheetByIndex( int index )
     return DCOPRef( kapp->dcopClient()->appId(), t->dcopObject()->objId() );
 }
 
-int KSpreadMapIface::sheetCount() const
+int MapIface::sheetCount() const
 {
     return m_map->count();
 }
 
-QStringList KSpreadMapIface::sheetNames() const
+QStringList MapIface::sheetNames() const
 {
     QStringList names;
 
-    QPtrList<KSpreadSheet>& lst = m_map->sheetList();
-    QPtrListIterator<KSpreadSheet> it( lst );
+    QPtrList<Sheet>& lst = m_map->sheetList();
+    QPtrListIterator<Sheet> it( lst );
     for( ; it.current(); ++it )
         names.append( it.current()->name() );
 
     return names;
 }
 
-QValueList<DCOPRef> KSpreadMapIface::sheets()
+QValueList<DCOPRef> MapIface::sheets()
 {
     QValueList<DCOPRef> t;
 
-    QPtrList<KSpreadSheet>& lst = m_map->sheetList();
-    QPtrListIterator<KSpreadSheet> it( lst );
+    QPtrList<Sheet>& lst = m_map->sheetList();
+    QPtrListIterator<Sheet> it( lst );
     for( ; it.current(); ++it )
         t.append( DCOPRef( kapp->dcopClient()->appId(), it.current()->dcopObject()->objId() ) );
 
     return t;
 }
 
-DCOPRef KSpreadMapIface::insertSheet( const QString& name )
+DCOPRef MapIface::insertSheet( const QString& name )
 {
     if ( m_map->findSheet( name ) )
         return sheet( name );
 
-    KSpreadSheet* t = m_map->addNewSheet ();
+    Sheet* t = m_map->addNewSheet ();
     t->setSheetName( name );
 
     return sheet( name );
 }
 
-bool KSpreadMapIface::processDynamic(const QCString &fun, const QByteArray &/*data*/,
+bool MapIface::processDynamic(const QCString &fun, const QByteArray &/*data*/,
                                      QCString& replyType, QByteArray &replyData)
 {
     // Does the name follow the pattern "foobar()" ?
     uint len = fun.length();
     if ( len < 3 )
-        return FALSE;
+        return false;
 
     if ( fun[ len - 1 ] != ')' || fun[ len - 2 ] != '(' )
-        return FALSE;
+        return false;
 
-    KSpreadSheet* t = m_map->findSheet( fun.left( len - 2 ).data() );
+    Sheet* t = m_map->findSheet( fun.left( len - 2 ).data() );
     if ( !t )
-        return FALSE;
+        return false;
 
     replyType = "DCOPRef";
     QDataStream out( replyData, IO_WriteOnly );
     out << DCOPRef( kapp->dcopClient()->appId(), t->dcopObject()->objId() );
-    return TRUE;
+    return true;
 }
