@@ -15,33 +15,40 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef __kspread_condition_h__
 #define __kspread_condition_h__
 
-#include "kspread_global.h"
-
-#include <qvaluelist.h>
 #include <qdom.h>
+#include <qvaluelist.h>
+
 #include <koffice_export.h>
-class KSpreadCell;
-class KSpreadStyle;
-class KoGenStyle;
+
+#include "kspread_global.h"
 
 class QColor;
 class QFont;
 class QString;
+class KoGenStyle;
+
+namespace KSpread
+{
+class Cell;
+class Style;
 
 /**
  * Structure to indicate the condition we're testing on a cell and the special
  * font and color that will be applied if it's true
  */
-class KSPREAD_EXPORT KSpreadConditional
+class KSPREAD_EXPORT Conditional
 {
 public:
+  enum Type { None, Equal, Superior, Inferior, SuperiorEqual,
+              InferiorEqual, Between, Different, DifferentTo };
+
   double         val1;
   double         val2;
   QString *      strVal1;
@@ -49,20 +56,20 @@ public:
   QColor  *      colorcond;
   QFont   *      fontcond;
   QString *      styleName;
-  KSpreadStyle * style;
-  Conditional    cond;
+  Style *        style;
+  Type           cond;
 
-  KSpreadConditional();
-  ~KSpreadConditional();
-  KSpreadConditional( const KSpreadConditional& );
-  KSpreadConditional& operator=( const KSpreadConditional& );
+  Conditional();
+  ~Conditional();
+  Conditional( const Conditional& );
+  Conditional& operator=( const Conditional& );
 };
 
 
 /**
  * Manages a set of conditions for a cell
  */
-class KSpreadConditions
+class Conditions
 {
  public:
 
@@ -70,8 +77,8 @@ class KSpreadConditions
    * Constructor.  There is no default constructor - you must use this one
    * with the owner cell as a parameter
    */
-  KSpreadConditions( const KSpreadCell * ownerCell );
-  virtual ~KSpreadConditions();
+  Conditions( const Cell * ownerCell );
+  virtual ~Conditions();
 
   /**
    * Use this function to see what conditions actually apply currently
@@ -83,17 +90,17 @@ class KSpreadConditions
    *
    * @return true if one of the conditions is true, false if not.
    */
-  bool currentCondition( KSpreadConditional & condition );
+  bool currentCondition( Conditional & condition );
 
   /**
    * Retrieve the current list of conditions we're checking
    */
-  QValueList<KSpreadConditional> conditionList() const;
+  QValueList<Conditional> conditionList() const;
 
   /**
    * Replace the current list of conditions with this new one
    */
-  void setConditionList( const QValueList<KSpreadConditional> & list );
+  void setConditionList( const QValueList<Conditional> & list );
 
   /**
    * Saves the conditions to a DOM tree structure.
@@ -115,23 +122,24 @@ class KSpreadConditions
   /**
    * returns the style that matches first (or NULL if no condition matches)
    */
-  KSpreadStyle * matchedStyle() const { return m_matchedStyle; }
+  Style * matchedStyle() const { return m_matchedStyle; }
 
   void checkMatches();
 
  private:
-  KSpreadConditions() {}
+  Conditions() {}
 
-    QString saveOasisConditionValue(KSpreadConditional &cond);
-    void loadOasisConditionValue( const QString &styleCondition, KSpreadConditional &newCondition );
-    void loadOasisValidationValue( const QStringList &listVal, KSpreadConditional &newCondition );
-    void loadOasisCondition( QString &valExpression, KSpreadConditional &newCondition );
+    QString saveOasisConditionValue(Conditional &cond);
+    void loadOasisConditionValue( const QString &styleCondition, Conditional &newCondition );
+    void loadOasisValidationValue( const QStringList &listVal, Conditional &newCondition );
+    void loadOasisCondition( QString &valExpression, Conditional &newCondition );
 
 
-  const KSpreadCell * m_cell;
-  QValueList<KSpreadConditional> m_condList;
-  KSpreadStyle * m_matchedStyle;
+  const Cell * m_cell;
+  QValueList<Conditional> m_condList;
+  Style * m_matchedStyle;
 };
 
+} // namespace KSpread
 
 #endif /*defined __kspread_condition_h__  */
