@@ -21,43 +21,13 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KSPREAD_DOC
 #define KSPREAD_DOC
 
-class KoOasisSettings;
-class KCommand;
-
-class KSpreadDoc;
-class KSpreadInterpreter;
-class KSpreadView;
-class KSpreadMap;
-class KSpreadSheet;
-class KSpreadStyleManager;
-class KSpreadUndoAction;
-class KSPLoadingInfo;
-
-class KoStore;
-class KoCommandHistory;
-class KoXmlWriter;
-
-class View;
-
-class DCOPObject;
-
-class QDomDocument;
-
-class KSpellConfig;
-
-#include <koDocument.h>
-#include <kozoomhandler.h>
-#include <koGenStyles.h>
-#include <koUnit.h>
-
-#include <kcompletion.h>
 #include <qmap.h>
 #include <qobject.h>
 #include <qpainter.h>
@@ -65,27 +35,30 @@ class KSpellConfig;
 #include <qstring.h>
 #include <qvaluelist.h>
 
-#include <kspread_global.h>
+#include <kcompletion.h>
 
-#include <koscript_context.h>
+#include <KoDocument.h>
+#include <KoZoomHandler.h>
+
+#include "kspread_global.h"
+
+class KCommand;
+
+class KoCommandHistory;
+class KoGenStyles;
+class KoOasisSettings;
+class KoPicture;
+class KoPictureCollection;
+class KoPictureKey;
+class KoStore;
+class KoXmlWriter;
+
+class DCOPObject;
+class QDomDocument;
+class KSpellConfig;
 
 #define MIME_TYPE "application/x-kspread"
 
-struct Reference
-{
-    QString sheet_name;
-    QString ref_name;
-    QRect rect;
-};
-
-class KSpreadPlugin
-{
- public:
-  KSpreadPlugin() {}
-  virtual ~KSpreadPlugin() {}
-  virtual QDomElement saveXML( QDomDocument & doc ) const = 0;
-};
-
 namespace KSpread
 {
 class Damage;
@@ -93,15 +66,35 @@ class ValueParser;
 class ValueConverter;
 class ValueFormatter;
 class ValueCalc;
-}
+class Sheet;
+class Doc;
+class View;
+class Map;
+class Region;
+class StyleManager;
+class UndoAction;
+class KSPLoadingInfo;
+class EmbeddedObject;
 
+struct Reference
+{
+    QString sheet_name;
+    QString ref_name;
+    QRect rect;
+};
 
-class DocPrivate;
+class Plugin
+{
+ public:
+  Plugin() {}
+  virtual ~Plugin() {}
+  virtual QDomElement saveXML( QDomDocument & doc ) const = 0;
+};
 
 /**
  * This class holds the data that makes up a spreadsheet.
  */
-class KSPREAD_EXPORT KSpreadDoc : public KoDocument, public KoZoomHandler
+class KSPREAD_EXPORT Doc : public KoDocument, public KoZoomHandler
 {
   Q_OBJECT
   Q_PROPERTY( bool getShowRowHeader READ getShowRowHeader )
@@ -119,27 +112,36 @@ class KSPREAD_EXPORT KSpreadDoc : public KoDocument, public KoZoomHandler
   Q_PROPERTY( bool showStatusBar READ showStatusBar WRITE setShowStatusBar )
   Q_PROPERTY( bool showFormulaBar READ showFormulaBar WRITE setShowFormulaBar )
   Q_PROPERTY( bool showTabBar READ showTabBar WRITE setShowTabBar )
+  Q_PROPERTY( int undoRedoLimit READ undoRedoLimit WRITE setUndoRedoLimit )
 
 public:
 
   /**
    * Creates a new document.
    */
-  KSpreadDoc( QWidget *parentWidget = 0, const char *widgetName = 0, QObject* parent = 0,
+  Doc( QWidget *parentWidget = 0, const char *widgetName = 0, QObject* parent = 0,
   const char* name = 0, bool singleViewMode = false );
 
   /**
    * Destroys the document.
    */
-  ~KSpreadDoc();
-
-    enum { STYLE_PAGE = 20, STYLE_COLUMN, STYLE_ROW, STYLE_CELL, STYLE_PAGEMASTER, STYLE_USERSTYLE, STYLE_DEFAULTSTYLE,  STYLE_NUMERIC_NUMBER};
+  ~Doc();
 
+  /**
+   * Possible values for the "type" argument of the KoGenStyle constructor.
+   */
+  enum { STYLE_PAGE = 20,
+         STYLE_COLUMN,
+         STYLE_ROW,
+         STYLE_CELL_USER,
+         STYLE_CELL_AUTO,
+         STYLE_PAGEMASTER,
+         STYLE_NUMERIC_NUMBER };
 
   /**
    * Returns list of all documents.
    */
-  static QValueList<KSpreadDoc*> documents();
+  static QValueList<Doc*> documents();
 
   /**
    * Returns the MIME type of KSpread document.
@@ -147,13 +149,13 @@ public:
   virtual QCString mimeType() const { return MIME_TYPE; }
 
   KLocale *locale () const;
-  KSpreadMap *map () const;
-  KSpreadStyleManager *styleManager () const;
-  KSpread::ValueParser *parser () const;
-  KSpread::ValueFormatter *formatter () const;
-  KSpread::ValueConverter *converter () const;
-  KSpread::ValueCalc *calc () const;
-  
+  Map *map () const;
+  StyleManager *styleManager () const;
+  ValueParser *parser () const;
+  ValueFormatter *formatter () const;
+  ValueConverter *converter () const;
+  ValueCalc *calc () const;
+
   /**
    * Adds a command to the command history. The command itself
    * would not be executed.
@@ -162,10 +164,10 @@ public:
 
   /*
    * Adds an undo object. This is the same as addCommand, except
-   * that it accepts KSpreadUndo instance. Once every undo object
+   * that it accepts Undo instance. Once every undo object
    * is converted to KCommand, this function will be obsoleted.
    */
-  void addCommand( KSpreadUndoAction* command );
+  void addCommand( UndoAction* command );
 
   /**
    * Undoes the last operation.
@@ -194,26 +196,11 @@ public:
 
   /**
    * Returns the command history for the document. This is used
-   * in KSpreadView for updating the actions (i.e through
+   * in View for updating the actions (i.e through
    * signal KoCommandHistory::commandExecuted)
    */
   KoCommandHistory* commandHistory();
 
-  /**
-   * Returns the unit used to display margins.
-   */
-  KoUnit::Unit unit() const;
-
-  /**
-   * \deprecated Use unit().
-   */
-  KoUnit::Unit getUnit() const { return unit(); }
-
-  /**
-   * Sets the unit used to display margins.
-   */
-  void setUnit( KoUnit::Unit u );
-
   /**
    * Returns the name of the unit used to display margins.
    * For example, if unit() returns KoUnit::U_MM, then
@@ -221,11 +208,6 @@ public:
    */
   QString unitName() const;
 
-  /**
-   * \deprecated Use unitName().
-   */
-  QString getUnitName() const { return unitName(); }
-
   /**
    * Returns the syntax version of the currently opened file
    */
@@ -373,22 +355,6 @@ public:
    */
   bool getShowFormulaBar() const { return showFormulaBar(); }
 
-  /**
-   * If b is true, comment indicator is visible, otherwise
-   * it will be hidden.
-   */
-  void setShowCommentIndicator( bool b );
-
-  /**
-   * Returns true if comment indicator is visible.
-   */
-  bool showCommentIndicator() const;
-
-  /**
-   * \deprecated Use showCommentIndicator().
-   */
-  bool getShowCommentIndicator() const { return showCommentIndicator(); }
-
   /**
    * If b is true, an error message will pop up whenever error occurs.
    */
@@ -425,7 +391,7 @@ public:
    * get custom kspell config
    */
   void setKSpellConfig(KSpellConfig _kspell);
-  KSpellConfig * getKSpellConfig() const;
+  KSpellConfig * getKSpellConfig();
 
   bool dontCheckUpperWord() const;
   void setDontCheckUpperWord(bool _b);
@@ -436,9 +402,30 @@ public:
   QColor pageBorderColor() const;
   void changePageBorderColor( const QColor  & _color);
 
+  virtual bool completeSaving( KoStore* _store );
 
   virtual QDomDocument saveXML();
 
+  enum SaveFlag { SaveAll, SaveSelected }; // kpresenter and kword have have SavePage too
+
+  bool savingWholeDocument();
+
+    /**
+     * Save the whole document, or just the selection, into OASIS format
+     * When saving the selection, also return the data as plain text and/or plain picture,
+     * which are used to insert into the KMultipleDrag drag object.
+     *
+     * @param store the KoStore to save into
+     * @param manifestWriter pointer to a koxmlwriter to add entries to the manifest
+     * @param saveFlag either the whole document, or only the selected text/objects.
+     * @param plainText must be set when saveFlag==SaveSelected.
+     *        It returns the plain text format of the saved data, when available.
+     * @param picture must be set when saveFlag==SaveSelected.
+     *        It returns the selected picture, when exactly one picture was selected.
+     */
+  bool saveOasisHelper( KoStore* store, KoXmlWriter* manifestWriter, SaveFlag saveFlag,
+                        QString* plainText = 0, KoPicture* picture = 0 );
+
   virtual bool saveOasis( KoStore* store, KoXmlWriter* manifestWriter );
   void saveOasisDocumentStyles( KoStore* store, KoGenStyles& mainStyles ) const;
   virtual int supportedSpecialFormats() const;
@@ -471,42 +458,30 @@ public:
    */
   void newZoomAndResolution( bool updateViews, bool forPrint );
 
-  /**
-   * @return the KScript Interpreter used by this document.
-   */
-  KSpreadInterpreter* interpreter()const;
-
-  /**
-   * Kills the interpreter and creates a new one and
-   * reloads all scripts. This is useful if they have been
-   * edited and the changes should take effect.
-   */
-  void resetInterpreter();
-
-  /**
-   * @return a context that can be used for evaluating formulas.
-   *         This function does remove any exception from the context.
-   */
-  KSContext & context();
-
   // virtual void printMap( QPainter & _painter );
 
   void enableUndo( bool _b );
   void enableRedo( bool _b );
 
   /**
-   * @return TRUE if the document is currently loading.
+   * @return true if the document is currently loading.
    */
   bool isLoading() const;
 
+  /**
+     Prevents painting. Useful when importing data.
+   * @param status switch the painting on/off
+   */
+  void doNotPaint(bool status);
+
   virtual void paintContent( QPainter & painter, const QRect & rect, bool transparent = false,
                              double zoomX = 1.0, double zoomY = 1.0 );
   void paintContent( QPainter & painter, const QRect & rect, bool transparent,
-                     KSpreadSheet * sheet, bool drawCursor = true );
+                     Sheet * sheet, bool drawCursor = true );
 
   bool docData( QString const & xmlTag, QDomElement & data );
-  void deregisterPlugin( KSpreadPlugin * plugin );
-  void registerPlugin( KSpreadPlugin * plugin );
+  void deregisterPlugin( Plugin * plugin );
+  void registerPlugin( Plugin * plugin );
 
   /**
    * Primary entry point for painting.  Use this function to paint groups of cells
@@ -530,9 +505,9 @@ public:
    *                   marker
    */
   void paintCellRegions(QPainter& painter, const QRect &viewRect,
-                        KSpreadView* view,
+                        View* view,
                         QValueList<QRect> cellRegions,
-                        const KSpreadSheet* sheet, bool drawCursor);
+                        const Sheet* sheet, bool drawCursor);
 
   virtual DCOPObject* dcopObject();
 
@@ -547,7 +522,15 @@ public:
 
   QRect getRectArea(const QString &  _sheetName);
 
-  void insertChild( KoDocumentChild * child ) { KoDocument::insertChild( child ); }
+  /**
+   * Inserts an object to the object list.
+   */
+  void insertObject( EmbeddedObject * obj );
+    /**
+    * @return the list of all embedded objects (charts, pictures and koffice objects) Use insertObject to add an object to the list.
+    */
+  QPtrList<EmbeddedObject>& embeddedObjects();
+  KoPictureCollection *pictureCollection();
 
   void initConfig();
   void saveConfig();
@@ -560,7 +543,7 @@ public:
    * - No painting will be done to the screen
    * - No cell calculation will be done (maybe there are exceptions, such
    *   as the goalseek operation needs to calculate values)
-   * During an operation, calls to KSpreadSheet::setRegionPaintDirty mark
+   * During an operation, calls to Sheet::setRegionPaintDirty mark
    * regions as needing repainted.  Once the emitEndOperation function is
    * called, those regions will be painted all at once, values being calculated
    * as necessary.
@@ -577,9 +560,10 @@ public:
    * hourglass
    */
   virtual void emitBeginOperation();
-  
+
   /**
-   * Mark the end of an operation and triggers repaints/calculations.
+   * Mark the end of an operation and triggers a repaint of any cells or regions of cells which
+   * have been marked as 'dirty' via calls to Sheet::setRegionPaintDirty
    * See above comment to emitBeginOperation(bool).
    */
   virtual void emitEndOperation();
@@ -587,16 +571,19 @@ public:
   /**
    * s.a. difference does only specified tasks and thats why it improves performance
    * significantly. rect normally are the visible cells/the cells that need to be updated.
+   *
+   * TODO:  This is essentially redundant now since emitEndOperation behaviour has been fixed to
+   * only update cells that were already in the paint dirty list.
    */
-  void emitEndOperation( QRect const & rect );
+  void emitEndOperation( const Region& region );
 
   bool delayCalculation() const;
 
 
   void updateBorderButton();
 
-  void insertSheet( KSpreadSheet * sheet );
-  void takeSheet( KSpreadSheet * sheet );
+  void insertSheet( Sheet * sheet );
+  void takeSheet( Sheet * sheet );
 
   // The user-chosen global unit
 
@@ -628,18 +615,38 @@ public:
     void addIgnoreWordAllList( const QStringList & _lst);
     QStringList spellListIgnoreAll() const ;
 
-    void setDisplaySheet(KSpreadSheet *_Sheet );
-    KSpreadSheet * displaySheet() const;
-    KSPLoadingInfo * loadingInfo() const;
+    void setDisplaySheet(Sheet *_Sheet );
+    Sheet * displaySheet() const;
+
+    /**
+     * @return the loading info
+     */
+    KSPLoadingInfo* loadingInfo() const;
+
+    /**
+     * deletes the loading info after loading is complete
+     */
+    void deleteLoadingInfo();
+
   void increaseNumOperation();
   void decreaseNumOperation();
 
-  void addDamage( KSpread::Damage* damage );
+  void addDamage( Damage* damage );
 
 /* Function specific when we load config from file */
   void loadConfigFromFile();
   bool configLoadFromFile() const;
 
+  // repaint (update) all views
+  void repaint( const QRect& );
+  void repaint( EmbeddedObject* );
+  void repaint( const KoRect& );
+
+  virtual void addShell( KoMainWindow *shell );
+
+  int undoRedoLimit() const;
+  void setUndoRedoLimit(int _val);
+
 public slots:
 
   //void newView(); obsloete (Werner)
@@ -666,15 +673,21 @@ signals:
   void sig_addAreaName( const QString & );
   void sig_removeAreaName( const QString & );
 
-  void damagesFlushed( const QValueList<KSpread::Damage*>& damages );
+  void damagesFlushed( const QValueList<Damage*>& damages );
 
 protected slots:
   void commandExecuted();
-  void documentRestored();  
-  
+  void documentRestored();
+
+  virtual void openTemplate( const QString& file );
+  virtual void initEmpty();
+
 protected:
   KoView* createViewInstance( QWidget* parent, const char* name );
 
+  void makeUsedPixmapList();
+  void insertPixmapKey( KoPictureKey key );
+
   /**
    * Overloaded function of @ref KoDocument.
    */
@@ -685,25 +698,16 @@ protected:
    */
   virtual bool saveChildren( KoStore* _store );
 
-  /**
-   * Initializes the KScript Interpreter.
-   */
-  void initInterpreter();
-  /**
-   * Destroys the interpreter.
-   */
-  void destroyInterpreter();
-
   class SavedDocParts : public QMap<QString, QDomElement> {};
   SavedDocParts m_savedDocParts;
 
 private:
-
-  DocPrivate* d;
+  class Private;
+  Private* d;
 
   // don't allow copy or assignment
-  KSpreadDoc( const KSpreadDoc& );
-  KSpreadDoc& operator=( const KSpreadDoc& );
+  Doc( const Doc& );
+  Doc& operator=( const Doc& );
 
   /* helper functions for painting */
 
@@ -714,33 +718,9 @@ private:
   void paintUpdates();
 
   void PaintRegion(QPainter& painter, const KoRect &viewRegion,
-                   KSpreadView* view, const QRect &paintRegion,
-                   const KSpreadSheet* sheet);
-  void PaintChooseRect(QPainter& painter, const KoRect &viewRect,
-                       KSpreadView* view, const KSpreadSheet* sheet,
-                       const QRect &chooseRect);
-  void PaintNormalMarker(QPainter& painter, const KoRect &viewRect,
-                         KSpreadView* view, const KSpreadSheet* sheet,
-                         const QRect &selection);
+                   View* view, const QRect &paintRegion,
+                   const Sheet* sheet);
 
-  /**
-   * helper function in drawing the marker and choose marker.
-   * @param marker the rectangle that represents the marker being drawn
-   *               (cell coordinates)
-   * @param sheet the sheet this marker is on
-   * @param viewRect the visible area on the canvas
-   * @param positions output parameter where the viewable left, top, right, and
-   *                  bottom of the marker will be.  They are stored in the array
-   *                  in that order, and take into account cropping due to part
-   *                  of the marker being off screen.  This array should have
-   *                  at least a size of 4 pre-allocated.
-   * @param paintSides booleans indicating whether a particular side is visible.
-   *                   Again, these are in the order left, top, right, bottom.
-   *                   This should be preallocated with a size of at least 4.
-   */
-  void retrieveMarkerInfo( const QRect &marker, const KSpreadSheet* sheet,
-                           KSpreadView* view, const KoRect &viewRect,
-                           double positions[], bool paintSides[] );
   void loadPaper( QDomElement const & paper );
 
     void saveOasisSettings( KoXmlWriter &settingsWriter );
@@ -749,4 +729,6 @@ private:
     KSPLoadingInfo *m_loadingInfo;
 };
 
+} // namespace KSpread
+
 #endif /* KSPREAD_DOC */
