@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
-   Copyright (C) 2002-2004 Ariya Hidayat <ariya@kde.org>
+   Copyright (C) 2006 Raphael Langerhorst <raphael.langerhorst@kdemail.net>
+             (C) 2002-2004 Ariya Hidayat <ariya@kde.org>
              (C) 1999-2003 Laurent Montel <montel@kde.org>
              (C) 2002-2003 Norbert Andres <nandres@web.de>
              (C) 2002-2003 Philipp Mueller <philipp.mueller@gmx.de>
@@ -20,8 +21,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KSPREAD_VIEW
@@ -32,38 +33,144 @@
 #include <qstringlist.h>
 #include <qvaluelist.h>
 
-#include <koView.h>
+#include <kprinter.h>
+#include <kdeprint/kprintdialogpage.h>
+
+#include <KoPoint.h>
+#include <KoView.h>
+
 
 class QScrollBar;
 
 class KoDocumentEntry;
 class KoTabBar;
 
-class KSpreadCanvas;
-class KSpreadCell;
-class KSpreadChild;
-class KSpreadDoc;
-class KSpreadEditWidget;
-class KSpreadHBorder;
-class KSpreadLocationEditWidget;
-class KSpreadSelection;
-class KSpreadSheet;
-class KSpreadVBorder;
-class KSpreadView;
-class KSpreadComboboxLocationEditWidget;
-class ViewPrivate;
+class SheetSelectWidget;
 
 namespace KSpread
 {
+class Cell;
 class Damage;
-}
+class Sheet;
+class Canvas;
+class Child;
+class Doc;
+class EditWidget;
+class HBorder;
+class LocationEditWidget;
+class Region;
+class Selection;
+class VBorder;
+class View;
+class ComboboxLocationEditWidget;
+class EmbeddedKOfficeObject;
+class EmbeddedObject;
+
 
 /**
- * \brief
- * The KSpreadView class displays a KSpread document.
+ * \class KPSheetSelectPage
+ * \brief Print dialog page for selecting sheets to print.
+ * @author raphael.langerhorst@kdemail.net
+ * @see SheetSelectWidget
+ *
+ * This dialog is shown in the print dialog and allows the user
+ * to select the sheets that should be printed and in which order
+ * they should be printed.
+ */
+class KPSheetSelectPage : public KPrintDialogPage
+{
+  Q_OBJECT
+  public:
+    KPSheetSelectPage( QWidget *parent = 0 );
+//     ~KPSheetSelectPage();
+
+//     //reimplement virtual functions
+    /**
+     * @see printOptionPrefix()
+     */
+    void getOptions( QMap<QString,QString>& opts, bool incldef = false );
+
+    /**
+     * @see printOptionPrefix()
+     */
+    void setOptions( const QMap<QString,QString>& opts );
+
+    /**
+     * @return false if no sheet is selected for printing.
+     */
+    bool isValid( QString& msg );
+
+    /**
+     * @return list of sheets that will be printed, in correct order.
+     */
+    QStringList selectedSheets();
+
+    /**
+     * Removes all sheets from the list of selected sheets.
+     */
+    void clearSelection();
+
+    /**
+     * The print order of the sheets is stored in the option map,
+     * using a prefix plus the index of the sheet, like the following:
+     * \li sheetprintorder0
+     * \li sheetprintorder1
+     * \li sheetprintorder2
+     * Please note that this is just the key to the value, not the value
+     * itself. The value of the option is the sheetname itself.
+     * @param index the index of the print order, starting at 0
+     * @return the string that is used in the printoption for given index
+     */
+    static QString printOptionForIndex(unsigned int index);
+
+    /**
+     * @param prt the printer from which the options should be read.
+     * @return list of sheets to print in correct order configured for given printer.
+     */
+    static QStringList selectedSheets(KPrinter &prt);
+
+  public slots:
+
+    /**
+     * Inserts given sheet to the list of available sheets.
+     */
+    void prependAvailableSheet(const QString& sheetname);
+
+    /**
+     * Inserts given sheet to the list of sheets for printing at the top.
+     */
+    void prependSelectedSheet(const QString& sheetname);
+
+  protected slots:
+
+    // The following slots just implement the code for the buttons
+
+    void selectAll();
+    void select();
+    void remove();
+    void removeAll();
+
+    void moveTop();
+    void moveUp();
+    void moveDown();
+    void moveBottom();
+
+  private:
+
+    /**
+     * The widget used, includes two lists of sheet names and
+     * buttons to move sheets between and within the lists.
+     */
+    SheetSelectWidget* gui;
+};
+
+
+/** @class View
+ *
+ * @brief The View class displays a KSpread document.
  *
  *
- * KSpreadView is used to display a spreadsheet document and provide
+ * View is used to display a spreadsheet document and provide
  * the interface for the user to perform editing and data analysis.
  *
  * A view consists of several parts:
@@ -76,30 +183,30 @@ class Damage;
  *  \li tab bar to select active worksheet
  *
  */
-class KSPREAD_EXPORT KSpreadView : public KoView
+class KSPREAD_EXPORT View : public KoView
 {
-    friend class KSpreadCanvas;
+    friend class Canvas;
 
     Q_OBJECT
 public:
 
     /** Creates a new view */
-    KSpreadView( QWidget *_parent, const char *_name,
-        KSpreadDoc *doc );
+    View( QWidget *_parent, const char *_name,
+        Doc *doc );
 
     /** Destroys the view */
-    ~KSpreadView();
-    
-    KSpreadDoc* doc();
+    ~View();
+
+    Doc* doc() const;
 
     /** Returns the canvas of the view */
-    KSpreadCanvas* canvasWidget() const;
+    Canvas* canvasWidget() const;
 
     /** Returns the column header */
-    KSpreadHBorder* hBorderWidget() const;
+    HBorder* hBorderWidget() const;
 
     /** Returns the row header */
-    KSpreadVBorder* vBorderWidget() const;
+    VBorder* vBorderWidget() const;
 
     /** Returns the horizontal scrollbar */
     QScrollBar* horzScrollBar() const;
@@ -108,23 +215,23 @@ public:
     QScrollBar* vertScrollBar() const;
 
     /** Returns the editor widget */
-    KSpreadEditWidget* editWidget() const;
+    KSpread::EditWidget* editWidget() const;
 
     /** Returns the location widget */
-    KSpreadComboboxLocationEditWidget* posWidget() const;
+    ComboboxLocationEditWidget* posWidget() const;
 
     /** Returns the tab bar */
     KoTabBar* tabBar() const;
 
     void setZoom( int zoom, bool updateViews ); // change the zoom value
 
-    void addSheet( KSpreadSheet *_t );
-    //void removesheet( KSpreadSheet *_t );
+    void addSheet( Sheet *_t );
+    //void removesheet( Sheet *_t );
     void removeAllSheets();
-    void setActiveSheet( KSpreadSheet *_t,bool updatesheet=true );
+    void setActiveSheet( Sheet *_t,bool updatesheet=true );
 
-    const KSpreadSheet* activeSheet() const;
-    KSpreadSheet* activeSheet();
+    const Sheet* activeSheet() const;
+    Sheet* activeSheet();
 
     void openPopupMenu( const QPoint &_global );
     void popupRowMenu(const QPoint & _point ) ;
@@ -133,9 +240,9 @@ public:
     // void showFormulaToolBar( bool show );
 
     /**
-     * Used by @ref KSpreadEditWidget. Sets the text of the active cell.
+     * Used by @ref EditWidget. Sets the text of the active cell(s).
      */
-    void setText( const QString& _text );
+    void setText( const QString& _text, bool array = false );
 
     void enableUndo( bool _b );
     void enableRedo( bool _b );
@@ -143,23 +250,29 @@ public:
     void enableInsertRow( bool _b );
 
     /**
-     * Called by @ref KSpreadInsertHandler
      *
      * @param _geometry is the zoomed geometry of the new child.
+     * @param _entry is the entry to insert.
+     *
+     * @todo check validity of @p _entry docs.
      */
     void insertChart( const QRect& _geometry, KoDocumentEntry& _entry );
     /**
-     * Called by @ref KSpreadInsertHandler
      *
      * @param _geometry is the geometry of the new child.
+     * @param _entry is the entry to insert.
+     *
+     * @todo check validity of @p _entry docs.
      */
     void insertChild( const QRect& _geometry, KoDocumentEntry& _entry );
 
+   // void insertPicture( const QRect& _geometry, KURL& _file );
+
     virtual void print( KPrinter &printer );
     virtual void setupPrinter( KPrinter &printer );
 
     /**
-     * Fills the @ref KSpreadEditWidget with the current cells
+     * Fills the @ref EditWidget with the current cells
      * content. This function is usually called after the
      * cursor moved.
      */
@@ -177,7 +290,7 @@ public:
     void closeEditor();
     virtual DCOPObject* dcopObject();
 
-    virtual QWidget *canvas();
+    virtual QWidget *canvas() const;
     virtual int canvasXOffset() const;
     virtual int canvasYOffset() const;
 
@@ -189,16 +302,6 @@ public:
 
     void initConfig();
 
-    /**
-     * Returns true if document is being loaded. It is useful to be checked for
-     * when doing view update.
-     */
-    bool isLoading() const;
-
-    /**
-     * write in statusBar result of calc (Min, or Max, average, sum, count)
-     */
-    void resultOfCalc();
 
     void initCalcMenu();
 
@@ -206,34 +309,58 @@ public:
 
     void updateBorderButton();
 
-    void removeSheet( KSpreadSheet *_t );
-    void insertSheet( KSpreadSheet* sheet );
+    void removeSheet( Sheet *_t );
+    void insertSheet( Sheet* sheet );
     QColor borderColor() const;
 
-    KSpreadSelection* selectionInfo() const;
-    QRect selection(bool extend = true) const;
-    QPoint marker() const;
+    Selection* selectionInfo() const;
+    Selection* choice() const;
 
     void updateShowSheetMenu();
 
+    /**
+     * Mark all selected cells / regions of cells as 'dirty' (ie. requiring a repaint)
+     * They will be repainted on the next call to paintUpdates()
+     */
+    void markSelectionAsDirty();
+
     /**
      * Repaint any cell with the paintDirty flag that is visible in this view
      */
     void paintUpdates();
 
     /**
-     * Resets the internal handle pointer, called from KSpreadInsertHandler destructor
+     * Resets the internal handle pointer, called from InsertHandler destructor
      */
     void resetInsertHandle();
 
+    bool isInsertingObject();
+
     bool showSheet(const QString& sheetName);
 
-    QPoint markerFromSheet( KSpreadSheet *_sheet ) const;
-    /*
-     * Save current sheet selection. Call when we change sheet, or save in oasis format
+    /**
+     * @return marker for @p sheet
+     */
+    QPoint markerFromSheet( Sheet* sheet ) const;
+
+    /**
+     * @return scroll offset for @p sheet
+     */
+    KoPoint offsetFromSheet( Sheet* sheet ) const;
+
+    /**
+     * Save current sheet selection.
+     * Call when we change sheet, or before save in OpenDocument format.
      */
     void saveCurrentSheetSelection();
 
+    void deleteSelectedObjects();
+
+    /**
+    * Returns the default color for highlighting cells and column / row headers
+    */
+    static QColor highlightColor();
+
 public slots:
     /**
     * refresh view when you hide/show vertical scrollbar
@@ -299,6 +426,7 @@ public slots:
     void showSheet();
     void helpUsing();
     void insertChart();
+    void insertPicture();
     void moneyFormat(bool b);
     void alignLeft( bool b );
     void alignRight( bool b );
@@ -336,6 +464,7 @@ public slots:
     void sortInc();
     void sortDec();
     void layoutDlg();
+    void extraProperties();
     void borderBottom();
     void borderRight();
     void borderLeft();
@@ -383,6 +512,9 @@ public slots:
      * \sa dissociateCell
      */
     void mergeCell();
+    void mergeCellHorizontal();
+    void mergeCellVertical();
+
 
     /**
      * Breaks merged cell. Obviously this can be done only on merged cells.
@@ -453,22 +585,23 @@ public slots:
      */
     void showFormulaBar( bool b );
 
-    /**
-     * If b is true, a red triangle is displayed on the corner of cells
-     * which have comments.
-     */
-    void showCommentIndicator( bool b );
-
     /**
      * Shows context menu when tabbar is double-clicked.
      */
     void popupTabBarMenu( const QPoint& );
-    
-    void handleDamages( const QValueList<KSpread::Damage*>& damages );
+
+    void handleDamages( const QValueList<Damage*>& damages );
 
     void runInternalTests();
     void runInspector();
 
+    void initialiseMarkerFromSheet( Sheet *_sheet, const QPoint &point );
+
+    /**
+     * write in statusBar result of calc (Min, or Max, average, sum, count)
+     */
+    void calcStatusBarOp();
+
 protected slots:
     /**
      * Popup menu
@@ -483,6 +616,11 @@ protected slots:
      * Invoked if the popup menu for an embedded document should be opened.
      */
     void popupChildMenu( KoChild*, const QPoint& global_pos );
+
+    /**
+     * Invoked when the "Delete Embedded Document" option from an embedded document's
+     * popup menu is selected.
+     */
     void slotPopupDeleteChild();
 
     /**
@@ -509,27 +647,30 @@ protected slots:
     void slotSpecialChar( QChar c, const QString & _font );
     void slotSpecialCharDlgClosed();
 
-protected slots:
+    void propertiesOk();
 
+    void objectSelectedChanged();
+
+protected slots:
     void slotChildSelected( KoDocumentChild* ch );
     void slotChildUnselected( KoDocumentChild* );
 
 public slots:
     // Document signals
     void slotRefreshView();
-    void slotUpdateView( KSpreadSheet *_sheet );
-    void slotUpdateView( KSpreadSheet *_sheet, const QRect& );
-    void slotUpdateHBorder( KSpreadSheet *_sheet );
-    void slotUpdateVBorder( KSpreadSheet *_sheet );
-    void slotChangeSelection( KSpreadSheet *_sheet, const QRect &oldSelection,
-                              const QPoint &_oldMarker );
-    void slotAddSheet( KSpreadSheet *_sheet );
-    void slotRemoveChild( KSpreadChild *_child );
-    void slotUpdateChildGeometry( KSpreadChild *_child );
-    void slotSheetRenamed( KSpreadSheet* sheet, const QString& old_name );
-    void slotSheetHidden( KSpreadSheet*_sheet );
-    void slotSheetShown( KSpreadSheet*_sheet );
-    void slotSheetRemoved( KSpreadSheet*_sheet );
+    void slotUpdateView( Sheet *_sheet );
+    void slotUpdateView( Sheet *_sheet, const Region& );
+    void slotUpdateView( EmbeddedObject* obj );
+    void slotUpdateHBorder( Sheet *_sheet );
+    void slotUpdateVBorder( Sheet *_sheet );
+    void slotChangeSelection(const Region&);
+    void slotChangeChoice(const Region&);
+    void slotAddSheet( Sheet *_sheet );
+    void slotUpdateChildGeometry( EmbeddedKOfficeObject *_child );
+    void slotSheetRenamed( Sheet* sheet, const QString& old_name );
+    void slotSheetHidden( Sheet*_sheet );
+    void slotSheetShown( Sheet*_sheet );
+    void slotSheetRemoved( Sheet*_sheet );
     void refreshLocale();
     void extraSpelling();
 
@@ -553,10 +694,6 @@ public slots:
     virtual int topBorder() const;
     virtual int bottomBorder() const;
 
-signals:
-    void sig_selectionChanged( KSpreadSheet* _sheet, const QRect& _selection );
-    void sig_chooseSelectionChanged(KSpreadSheet *sheet, const QRect& _selection);
-
 protected:
 
     virtual void keyPressEvent ( QKeyEvent * _ev );
@@ -564,6 +701,14 @@ protected:
 
     virtual QWMatrix matrix() const;
 
+    /**
+     * Returns the position of the top-left point of the currently selected cell in document coordinates.
+     * This is used when inserting some types of objects or pasting images into the document (so that the newly
+     * pasted object's top-left point will be aligned with the top-left point of the currently selected cell)
+     *
+     */
+    KoPoint markerDocumentPosition();
+
     /**
      * Activates the formula editor for the current cell.
      * This function is usually called if the user presses
@@ -576,22 +721,32 @@ protected:
     virtual void guiActivateEvent( KParts::GUIActivateEvent *ev );
 
     void initFindReplace();
-    KSpreadCell* findNextCell();
+    Cell* findNextCell();
 
 private:
-
-    ViewPrivate* d;
+    class Private;
+    Private* d;
 
     // don't allow copy or assignment
-    KSpreadView( const KSpreadView& );
-    KSpreadView& operator=( const KSpreadView& );
-    
-    void initView();    
+    View( const View& );
+    View& operator=( const View& );
+
+    void initView();
 
     bool spellSwitchToOtherSheet();
     void spellCleanup();
 
-    void endOperation( QRect const & rect );
+    /**
+     * @return @c true if document is being loaded. It is useful to supress scrolling
+     * while the "View loading" process.
+     */
+    bool isLoading() const;
+
+    Cell* nextFindValidCell( int col, int row );
+
+    friend class Private;
 };
 
+} // namespace KSpread
+
 #endif // KSPREAD_VIEW
