@@ -13,16 +13,17 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
-#include <koApplication.h>
+#include <KoApplication.h>
 #include <kcmdlineargs.h>
 
 #include <dcopclient.h>
 #include "kspread_aboutdata.h"
 
+using namespace KSpread;
 
 static const KCmdLineOptions options[]=
 {
@@ -33,7 +34,7 @@ static const KCmdLineOptions options[]=
 extern "C" KSPREAD_EXPORT int kdemain( int argc, char **argv )
 {
 
-    KCmdLineArgs::init( argc, argv, newKSpreadAboutData() );
+    KCmdLineArgs::init( argc, argv, newAboutData() );
     KCmdLineArgs::addCmdLineOptions( options );
 
     KoApplication app;
