@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef CMSTYLE_H
@@ -40,18 +40,26 @@ private:
 class CMStyle : public FontStyle {
 public:
 
-    /// lazy init support. Needs to be run before anything else.
-    virtual bool init( ContextStyle* context );
+    /**
+     * lazy init support. Needs to be run before anything else.
+     * @param install if true fonts may be installed if needed
+     */
+    virtual bool init( ContextStyle* context, bool install = true );
 
     /// the table for special alphabets.
     virtual const AlphaTable* alphaTable() const;
 
     virtual Artwork* createArtwork( SymbolType type = EmptyBracket ) const;
 
-    static QStringList missingFonts();
+    static QStringList missingFonts( bool install = true );
+
+    static bool m_installed;
 
 private:
 
+    static QStringList missingFontsInternal();
+    static void installFonts();
+
     CMAlphaTable m_alphaTable;
 };
 
