@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qpainter.h>
@@ -31,7 +31,7 @@ KFORMULA_NAMESPACE_BEGIN
 
 #include "esstixfontmapping.cc"
 
-bool EsstixFontStyle::init( ContextStyle* context )
+bool EsstixFontStyle::init( ContextStyle* context, bool /* install */ )
 {
     SymbolTable* st = symbolTable();
     st->init( context );
@@ -303,15 +303,17 @@ void EsstixArtwork::calcSizes( const ContextStyle& style,
 }
 
 
-void EsstixArtwork::draw(QPainter& painter, const LuPixelRect& r,
+void EsstixArtwork::draw(QPainter& painter, const LuPixelRect& /*r*/,
                          const ContextStyle& style, ContextStyle::TextStyle tstyle,
                          luPt /*parentSize*/, const LuPixelPoint& origin)
 {
     luPt mySize = style.getAdjustedSize( tstyle );
     luPixel myX = origin.x() + getX();
     luPixel myY = origin.y() + getY();
+    /*
     if ( !LuPixelRect( myX, myY, getWidth(), getHeight() ).intersects( r ) )
         return;
+    */
 
     painter.setPen(style.getDefaultColor());
     //const SymbolTable& symbolTable = style.symbolTable();
