@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef FONTSTYLE_H
@@ -44,8 +44,11 @@ public:
 
     virtual ~FontStyle() {}
 
-    /// lazy init support. Needs to be run before anything else.
-    virtual bool init( ContextStyle* context ) = 0;
+    /**
+     * lazy init support. Needs to be run before anything else.
+     * @param install if true fonts may be installed if needed
+     */
+    virtual bool init( ContextStyle* context, bool install = true ) = 0;
 
     /// the table for ordinary symbols (those that have a unicode value)
     virtual const SymbolTable* symbolTable() const { return &m_symbolTable; }
