@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qpainter.h>
@@ -79,7 +79,8 @@ void FormulaCursor::calcCursorSize( const ContextStyle& context, bool smallCurso
     }
 }
 
-void FormulaCursor::draw( QPainter& painter, const ContextStyle& context, bool smallCursor )
+void FormulaCursor::draw( QPainter& painter, const ContextStyle& context, 
+                          bool smallCursor, bool activeCursor )
 {
     //if (readOnly && !isSelection())
     //return;
@@ -88,7 +89,7 @@ void FormulaCursor::draw( QPainter& painter, const ContextStyle& context, bool s
     SequenceElement* sequence = dynamic_cast<SequenceElement*>(current);
 
     if (sequence != 0) {
-        sequence->drawCursor( painter, context, this, smallCursor );
+        sequence->drawCursor( painter, context, this, smallCursor, activeCursor );
     }
 }
 
