@@ -310,7 +310,7 @@ QString FormulaElement::toLatex()
     return inherited::toLatex();   //Consider $$ sorround
 }
 
-void FormulaElement::writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat )
+void FormulaElement::writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat )
 {
     QDomElement de;
     if ( !oasisFormat )
