@@ -460,7 +460,7 @@ QString FractionElement::formulaString()
     return "(" + numerator->formulaString() + ")/(" + denominator->formulaString() + ")";
 }
 
-void FractionElement::writeMathML( QDomDocument& doc, QDomNode parent, bool oasisFormat )
+void FractionElement::writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat )
 {
     QDomElement de = doc.createElement( oasisFormat ? "math:mfrac": "mfrac" );
     if ( !withLine ) // why is this no function?
