@@ -14,14 +14,16 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qpainter.h>
 
 #include <kdebug.h>
+#include <klocale.h>
 
+#include "elementvisitor.h"
 #include "indexelement.h"
 #include "formulacursor.h"
 #include "formulaelement.h"
@@ -37,10 +39,13 @@ class IndexSequenceElement : public SequenceElement {
 public:
 
     IndexSequenceElement( BasicElement* parent = 0 ) : SequenceElement( parent ) {}
+    virtual IndexSequenceElement* clone() {
+        return new IndexSequenceElement( *this );
+    }
 
     /**
      * This is called by the container to get a command depending on
-     * the current cursor position (this is how the element gets choosen)
+     * the current cursor position (this is how the element gets chosen)
      * and the request.
      *
      * @returns the command that performs the requested action with
@@ -52,6 +57,11 @@ public:
 
 KCommand* IndexSequenceElement::buildCommand( Container* container, Request* request )
 {
+    FormulaCursor* cursor = container->activeCursor();
+    if ( cursor->isReadOnly() ) {
+        return 0;
+    }
+
     switch ( *request ) {
     case req_addIndex: {
         FormulaCursor* cursor = container->activeCursor();
@@ -105,6 +115,102 @@ IndexElement::~IndexElement()
 }
 
 
+IndexElement::IndexElement( const IndexElement& other )
+    : BasicElement( other )
+{
+    content = new IndexSequenceElement( *dynamic_cast<IndexSequenceElement*>( other.content ) );
+
+    if ( other.upperLeft ) {
+        upperLeft = new SequenceElement( *( other.upperLeft ) );
+        upperLeft->setParent( this );
+    }
+    else {
+        upperLeft = 0;
+    }
+    if ( other.upperMiddle ) {
+        upperMiddle = new SequenceElement( *( other.upperMiddle ) );
+        upperMiddle->setParent( this );
+    }
+    else {
+        upperMiddle = 0;
+    }
+    if ( other.upperRight ) {
+        upperRight = new SequenceElement( *( other.upperRight ) );
+        upperRight->setParent( this );
+    }
+    else {
+        upperRight = 0;
+    }
+
+    if ( other.lowerLeft ) {
+        lowerLeft = new SequenceElement( *( other.lowerLeft ) );
+        lowerLeft->setParent( this );
+    }
+    else {
+        lowerLeft = 0;
+    }
+    if ( other.lowerMiddle ) {
+        lowerMiddle = new SequenceElement( *( other.lowerMiddle ) );
+        lowerMiddle->setParent( this );
+    }
+    else {
+        lowerMiddle = 0;
+    }
+    if ( other.lowerRight ) {
+        lowerRight = new SequenceElement( *( other.lowerRight ) );
+        lowerRight->setParent( this );
+    }
+    else {
+        lowerRight = 0;
+    }
+}
+
+
+bool IndexElement::accept( ElementVisitor* visitor )
+{
+    return visitor->visit( this );
+}
+
+
+QChar IndexElement::getCharacter() const
+{
+    if ( !content->isTextOnly() ) {
+        return QChar::null;
+    }
+
+    if ( hasUpperRight() && !upperRight->isTextOnly() ) {
+        return QChar::null;
+    }
+    if ( hasUpperMiddle() && !upperMiddle->isTextOnly() ) {
+        return QChar::null;
+    }
+    if ( hasUpperLeft() && !upperLeft->isTextOnly() ) {
+        return QChar::null;
+    }
+    if ( hasLowerRight() && !lowerRight->isTextOnly() ) {
+        return QChar::null;
+    }
+    if ( hasLowerMiddle() && !lowerMiddle->isTextOnly() ) {
+        return QChar::null;
+    }
+    if ( hasLowerLeft() && !lowerLeft->isTextOnly() ) {
+        return QChar::null;
+    }
+
+    return ' ';
+}
+
+void IndexElement::entered( SequenceElement* child )
+{
+    if ( child == content ) {
+        formula()->tell( i18n( "Indexed list" ) );
+    }
+    else {
+        formula()->tell( i18n( "Index" ) );
+    }
+}
+
+
 /**
  * Returns the element the point is in.
  */
@@ -401,8 +507,8 @@ void IndexElement::draw( QPainter& painter, const LuPixelRect& r,
                          const LuPixelPoint& parentOrigin )
 {
     LuPixelPoint myPos( parentOrigin.x()+getX(), parentOrigin.y()+getY() );
-    if ( !LuPixelRect( myPos.x(), myPos.y(), getWidth(), getHeight() ).intersects( r ) )
-        return;
+    //if ( !LuPixelRect( myPos.x(), myPos.y(), getWidth(), getHeight() ).intersects( r ) )
+    //    return;
 
     ContextStyle::TextStyle i_tstyle = style.convertTextStyleIndex(tstyle);
     ContextStyle::IndexStyle u_istyle = style.convertIndexStyleUpper( istyle );
@@ -437,6 +543,30 @@ void IndexElement::draw( QPainter& painter, const LuPixelRect& r,
 }
 
 
+void IndexElement::dispatchFontCommand( FontCommand* cmd )
+{
+    content->dispatchFontCommand( cmd );
+    if (hasUpperLeft()) {
+        upperLeft->dispatchFontCommand( cmd );
+    }
+    if (hasUpperMiddle()) {
+        upperMiddle->dispatchFontCommand( cmd );
+    }
+    if (hasUpperRight()) {
+        upperRight->dispatchFontCommand( cmd );
+    }
+    if (hasLowerLeft()) {
+        lowerLeft->dispatchFontCommand( cmd );
+    }
+    if (hasLowerMiddle()) {
+        lowerMiddle->dispatchFontCommand( cmd );
+    }
+    if (hasLowerRight()) {
+        lowerRight->dispatchFontCommand( cmd );
+    }
+}
+
+
 // navigation
 //
 // The elements are responsible to handle cursor movement themselves.
@@ -1050,7 +1180,7 @@ void IndexElement::moveToLowerRight(FormulaCursor* cursor, Direction direction)
 /**
  * Appends our attributes to the dom element.
  */
-void IndexElement::writeDom(QDomElement& element)
+void IndexElement::writeDom(QDomElement element)
 {
     BasicElement::writeDom(element);
 
@@ -1096,7 +1226,7 @@ void IndexElement::writeDom(QDomElement& element)
  * Reads our attributes from the element.
  * Returns false if it failed.
  */
-bool IndexElement::readAttributesFromDom(QDomElement& element)
+bool IndexElement::readAttributesFromDom(QDomElement element)
 {
     if (!BasicElement::readAttributesFromDom(element)) {
         return false;
@@ -1194,27 +1324,31 @@ QString IndexElement::toLatex()
     QString index;
 
     if ( hasUpperMiddle() ) {
-        index += "\\overset" + upperMiddle->toLatex() + "{";
+        index += "\\overset{" + upperMiddle->toLatex() + "}{";
     }
 
     if ( hasLowerMiddle() ) {
-        index += "\\underset" + lowerMiddle->toLatex() + "{";
+        index += "\\underset{" + lowerMiddle->toLatex() + "}{";
     }
 
-    if ( hasUpperLeft() || hasUpperRight() ) {
-        index += "{}";
+    if ( hasUpperLeft() || hasUpperRight() ) { //Not sure that this is possible in Latex!
+        /*index += "{}";
         if ( hasUpperLeft() )
             index += "^" + upperLeft->toLatex();
         if ( hasLowerLeft() )
             index += "_" + lowerLeft->toLatex();
+        */
     }
 
     index += content->toLatex();
 
-    if ( hasUpperRight() )
-        index += "^" + upperRight->toLatex();
-    if ( hasLowerRight() )
-        index += "_" + lowerRight->toLatex();
+    if ( hasUpperRight() || hasLowerRight() ) {
+        if ( hasUpperRight() )
+            index += "^{" + upperRight->toLatex() + "}";
+        if ( hasLowerRight() )
+            index += "_{" + lowerRight->toLatex() + "}";
+        index += " ";
+    }
 
     if ( hasLowerMiddle() ) {
         index += "}";
@@ -1239,4 +1373,102 @@ QString IndexElement::formulaString()
     return index;
 }
 
+void IndexElement::writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat )
+{
+    QDomElement de;
+    QDomElement uo;
+    bool uoscripts = true;
+
+    if ( hasUpperMiddle() && hasLowerMiddle() )
+    {
+        uo = doc.createElement( "munderover" );
+        content->writeMathML( doc, uo, oasisFormat ); // base
+        lowerMiddle->writeMathML( doc, uo, oasisFormat );
+        upperMiddle->writeMathML( doc, uo,oasisFormat );
+    }
+    else if ( hasUpperMiddle() )
+    {
+        uo = doc.createElement( "mover" );
+        content->writeMathML( doc, uo,oasisFormat ); // base
+        upperMiddle->writeMathML( doc, uo,oasisFormat );
+    }
+    else if ( hasLowerMiddle() )
+    {
+        uo = doc.createElement( "munder" );
+        content->writeMathML( doc, uo, oasisFormat ); // base
+        lowerMiddle->writeMathML( doc, uo,oasisFormat );
+    }
+    else // no over- or underscripts
+        uoscripts = false;
+
+
+    if ( hasLowerLeft() || hasUpperLeft() )
+    {
+        de = doc.createElement( "mmultiscripts" );
+        if ( !uoscripts ) // base
+            content->writeMathML( doc, de, oasisFormat );
+        else
+            de.appendChild( uo );
+
+        if ( hasLowerRight() )
+            lowerRight->writeMathML( doc, de, oasisFormat );
+        else
+            de.appendChild( doc.createElement( "none" ) );
+
+        if ( hasUpperRight() )
+            upperRight->writeMathML( doc, de, oasisFormat );
+        else
+            de.appendChild( doc.createElement( "none" ) );
+
+        de.appendChild( doc.createElement( "mprescripts" ) );
+
+        if ( hasLowerLeft() )
+            lowerLeft->writeMathML( doc, de, oasisFormat );
+        else
+            de.appendChild( doc.createElement( "none" ) );
+
+        if ( hasUpperLeft() )
+            upperLeft->writeMathML( doc, de, oasisFormat );
+        else
+            de.appendChild( doc.createElement( "none" ) );
+    }
+    else if ( hasLowerRight() || hasUpperRight() )
+    {
+        if ( !hasUpperRight() )
+        {
+            de = doc.createElement( "msub" );
+            if ( !uoscripts ) // base
+                content->writeMathML( doc, de, oasisFormat );
+            else
+                de.appendChild( uo );
+            lowerRight->writeMathML( doc, de, oasisFormat );
+        }
+        else if ( !hasLowerRight() )
+        {
+            de = doc.createElement( "msup" );
+            if ( !uoscripts ) // base
+                content->writeMathML( doc, de, oasisFormat );
+            else
+                de.appendChild( uo );
+            upperRight->writeMathML( doc, de, oasisFormat );
+        }
+        else // both
+        {
+            de = doc.createElement( "msubsup" );
+            if ( !uoscripts ) // base
+                content->writeMathML( doc, de, oasisFormat );
+            else
+                de.appendChild( uo );
+            lowerRight->writeMathML( doc, de, oasisFormat );
+            upperRight->writeMathML( doc, de,oasisFormat );
+        }
+    }
+    else // no mmultiscripts, msubsup, msub or msup
+        de = uo;
+
+
+    parent.appendChild( de );
+
+}
+
 KFORMULA_NAMESPACE_END
