@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qvariant.h>   // first for gcc 2.7.2
@@ -48,21 +48,17 @@
 #include "kformulaconfigpage.h"
 #include "kformuladocument.h"
 #include "symboltable.h"
+#include "esstixfontstyle.h"
+#include "cmstyle.h"
+#include "symbolfontstyle.h"
+
 
 KFORMULA_NAMESPACE_BEGIN
 
-class ConfigurePage::Private
-{
-public:
-    QCheckBox* syntaxHighlighting;
-    bool m_changed;
-};
 
 ConfigurePage::ConfigurePage( Document* document, QWidget* view, KConfig* config, QVBox* box, char* name )
-    : QObject( box->parent(), name ), m_document( document ), m_view( view ), m_config( config )
+    : QObject( box->parent(), name ), m_document( document ), m_view( view ), m_config( config ), m_changed( false )
 {
-    d = new Private;
-    d->m_changed = false;
     const ContextStyle& contextStyle = document->getContextStyle( true );
 
     // fonts
@@ -109,8 +105,8 @@ ConfigurePage::ConfigurePage( Document* document, QWidget* view, KConfig* config
 
     // syntax highlighting
 
-    d->syntaxHighlighting = new QCheckBox( i18n( "Use syntax highlighting" ),box );
-    d->syntaxHighlighting->setChecked( contextStyle.syntaxHighlighting() );
+    syntaxHighlighting = new QCheckBox( i18n( "Use syntax highlighting" ),box );
+    syntaxHighlighting->setChecked( contextStyle.syntaxHighlighting() );
 
 //     hlBox = new QGroupBox( i18n( "Highlight Colors" ), box );
 //     hlBox->setColumnLayout( 0, Qt::Horizontal );
@@ -162,7 +158,7 @@ ConfigurePage::ConfigurePage( Document* document, QWidget* view, KConfig* config
 //     errorColorBtn->setColor( contextStyle.getErrorColorPlain() );
 //     grid->addWidget( errorColorBtn, 4, 1 );
 
-    connect( d->syntaxHighlighting, SIGNAL( clicked() ),
+    connect( syntaxHighlighting, SIGNAL( clicked() ),
             SLOT( syntaxHighlightingClicked() ) );
 
     syntaxHighlightingClicked();
@@ -187,16 +183,12 @@ ConfigurePage::ConfigurePage( Document* document, QWidget* view, KConfig* config
     grid->addWidget( cmStyle, 2, 0 );
 
     connect( styleBox, SIGNAL( clicked( int ) ), this, SLOT( slotChanged() ) );
-    connect( d->syntaxHighlighting, SIGNAL( clicked() ), this, SLOT( slotChanged() ) );
+    connect( syntaxHighlighting, SIGNAL( clicked() ), this, SLOT( slotChanged() ) );
     connect( sizeSpin, SIGNAL( valueChanged( int ) ), this, SLOT( slotChanged() ) );
 
-    Q_ASSERT( !d->m_changed );
+    Q_ASSERT( !m_changed );
 }
 
-ConfigurePage::~ConfigurePage()
-{
-    delete d;
-}
 
 QPushButton* ConfigurePage::buildFontLine( QWidget* parent,
             QGridLayout* layout, int number, QFont font, QString name,
@@ -219,54 +211,15 @@ QPushButton* ConfigurePage::buildFontLine( QWidget* parent,
 }
 
 
-static bool fontAvailable( QString fontName )
-{
-    QFont f( fontName );
-    QStringList fields = QStringList::split( '-', f.rawName() );
-    if ( ( fields.size() > 1 ) &&
-         ( ( fields[1].upper() == fontName.upper() ) ||
-           ( fields[0].upper() == fontName.upper() ) ) ) {
-        return true;
-    }
-    else {
-        kdWarning(39001) << "Font '" << fontName << "' not found but '" << f.rawName() << "'." << endl;
-        return false;
-    }
-}
-
-
-inline void testFont( QStringList& missing, const QString& fontName ) {
-    if ( !fontAvailable( fontName ) ) {
-        missing.append( fontName );
-    }
-}
-
 void ConfigurePage::apply()
 {
-    if ( !d->m_changed )
+    if ( !m_changed )
         return;
     QString fontStyle;
     if ( esstixStyle->isChecked() ) {
         fontStyle = "esstix";
 
-        QStringList missing;
-        testFont( missing, "esstixeight" );
-        testFont( missing, "esstixeleven" );
-        testFont( missing, "esstixfifteen" );
-        testFont( missing, "esstixfive" );
-        testFont( missing, "esstixfour" );
-        testFont( missing, "esstixfourteen" );
-        testFont( missing, "esstixnine" );
-        testFont( missing, "esstixone" );
-        testFont( missing, "esstixseven" );
-        testFont( missing, "esstixseventeen" );
-        testFont( missing, "esstixsix" );
-        testFont( missing, "esstixsixteen" );
-        testFont( missing, "esstixten" );
-        testFont( missing, "esstixthirteen" );
-        testFont( missing, "esstixthree" );
-        testFont( missing, "esstixtwelve" );
-        testFont( missing, "esstixtwo" );
+        QStringList missing = EsstixFontStyle::missingFonts();
 
         if ( missing.count() > 0 ) {
             QString text = i18n( "The fonts '%1' are missing."
@@ -281,16 +234,9 @@ void ConfigurePage::apply()
     else if ( cmStyle->isChecked() ) {
         fontStyle = "tex";
 
-        QStringList missing;
-        testFont( missing, "cmbx10" );
-        testFont( missing, "cmex10" );
-        testFont( missing, "cmmi10" );
-        testFont( missing, "cmr10" );
-        testFont( missing, "cmsy10" );
-        testFont( missing, "msam10" );
-        testFont( missing, "msbm10" );
+        QStringList missing = CMStyle::missingFonts();
 
-        if ( missing.count() > 0 ) {
+        if ( missing.count() > 0 && !CMStyle::m_installed) {
             QString text = i18n( "The fonts '%1' are missing."
                                  " Do you want to change the font style anyway?" )
                            .arg( missing.join( "', '" ) );
@@ -303,8 +249,7 @@ void ConfigurePage::apply()
     else { // symbolStyle->isChecked ()
         fontStyle = "symbol";
 
-        QStringList missing;
-        testFont( missing, "symbol" );
+        QStringList missing = SymbolFontStyle::missingFonts();
 
         if ( missing.count() > 0 ) {
             QString text = i18n( "The font 'symbol' is missing."
@@ -327,7 +272,7 @@ void ConfigurePage::apply()
 
     contextStyle.setFontStyle( fontStyle );
 
-    contextStyle.setSyntaxHighlighting( d->syntaxHighlighting->isChecked() );
+    contextStyle.setSyntaxHighlighting( syntaxHighlighting->isChecked() );
 //     contextStyle.setDefaultColor( defaultColorBtn->color() );
 //     contextStyle.setNumberColor( numberColorBtn->color() );
 //     contextStyle.setOperatorColor( operatorColorBtn->color() );
@@ -344,7 +289,7 @@ void ConfigurePage::apply()
     m_config->writeEntry( "fontStyle", fontStyle );
 
 //     m_config->setGroup( "kformula Color" );
-//     m_config->writeEntry( "syntaxHighlighting", d->syntaxHighlighting->isChecked() );
+//     m_config->writeEntry( "syntaxHighlighting", syntaxHighlighting->isChecked() );
 //     m_config->writeEntry( "defaultColor", defaultColorBtn->color() );
 //     m_config->writeEntry( "numberColor",  numberColorBtn->color() );
 //     m_config->writeEntry( "operatorColor", operatorColorBtn->color() );
@@ -353,7 +298,7 @@ void ConfigurePage::apply()
 
     // notify!!!
     m_document->updateConfig();
-    d->m_changed = false;
+    m_changed = false;
 }
 
 void ConfigurePage::slotDefault()
@@ -371,8 +316,14 @@ void ConfigurePage::slotDefault()
     updateFontLabel( operatorFont, operatorFontName );
 
     symbolStyle->setChecked( true );
+    if (CMStyle::missingFonts().isEmpty())
+        cmStyle->setChecked( true );
+    else if (EsstixFontStyle::missingFonts().isEmpty())
+        esstixStyle->setChecked( true );
+    else
+        symbolStyle->setChecked( true );
 
-    d->syntaxHighlighting->setChecked( true );
+    syntaxHighlighting->setChecked( true );
     syntaxHighlightingClicked();
 
 //     defaultColorBtn->setColor( Qt::black );
@@ -385,7 +336,7 @@ void ConfigurePage::slotDefault()
 
 void ConfigurePage::syntaxHighlightingClicked()
 {
-//     bool checked = d->syntaxHighlighting->isChecked();
+//     bool checked = syntaxHighlighting->isChecked();
 //     hlBox->setEnabled( checked );
 }
 
@@ -444,7 +395,7 @@ void ConfigurePage::updateFontLabel( QFont font, QLabel* label )
 
 void ConfigurePage::slotChanged()
 {
-    d->m_changed = true;
+    m_changed = true;
 }
 
 // class UsedFontItem : public KListViewItem {
