@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KFORMULADOCUMENT_H
@@ -30,8 +30,8 @@
 #include <kaction.h>
 #include <kcommand.h>
 #include <kconfig.h>
-#include <kocommandhistory.h>
-//#include "kocommandhistory.h"
+#include <KoCommandHistory.h>
+//#include "KoCommandHistory.h"
 #include "kformuladefs.h"
 
 KFORMULA_NAMESPACE_BEGIN
@@ -139,7 +139,7 @@ public:
     /**
      * Change the zoom factor to @p z (e.g. 150 for 150%)
      * and/or change the resolution, given in DPI.
-     * Uses the KoZoomHandler.
+     * Uses the KoTextZoomHandler.
      */
     void setZoomAndResolution( int zoom, int dpiX, int dpiY );
 
@@ -238,7 +238,7 @@ private:
      */
     void recalc();
 
-    void introduceWrapper( DocumentWrapper* wrapper );
+    void introduceWrapper( DocumentWrapper* wrapper, bool init );
 
     /**
      * The Wrapper we belong to.
@@ -295,7 +295,7 @@ public:
      * Inserts the document we are wrapping. This must be called once
      * before the wrapper can be used.
      */
-    void document( Document* document );
+    void document( Document* document, bool init = true );
 
     KAction* getAddNegThinSpaceAction()  { return m_addNegThinSpaceAction; }
     KAction* getAddThinSpaceAction()     { return m_addThinSpaceAction; }
