@@ -297,10 +297,12 @@ void MathML2KFormulaPrivate::math( QDomElement element )
 void MathML2KFormulaPrivate::mi( QDomElement element, QDomNode docnode )
 {
     MathStyle previousStyle( style );
-    //style.mathvariant = italic;
-    style.readStyles( element );
-
     QString text = element.text().stripWhiteSpace();
+    if ( text.length() == 1 ) { // Default italic, only when content is one char
+        style.mathvariant = italic;
+        style.useVariant = true;
+    }
+    style.readStyles( element );
     createTextElements( text, docnode );
 
     style = previousStyle;
@@ -1327,7 +1329,14 @@ bool MathML2KFormulaPrivate::isSpaceLike( QDomNode node, bool oasisFormat )
 
 
 MathML2KFormula::MathML2KFormula( const QDomDocument& mmldoc, const ContextStyle &contextStyle, bool _oasisFormat )
-    : m_error( false ), origdoc( mmldoc ), oasisFormat( _oasisFormat ), context( contextStyle )
+    : m_error( false ), oasisFormat( _oasisFormat ), context( contextStyle )
+{
+    orig_element = mmldoc.documentElement();
+    done = false;
+}
+
+MathML2KFormula::MathML2KFormula( const QDomElement& mmlelm, const ContextStyle &contextStyle, bool _oasisFormat )
+    : m_error( false ), orig_element( mmlelm ), oasisFormat( _oasisFormat ), context( contextStyle )
 {
     done = false;
 }
@@ -1346,9 +1355,8 @@ void MathML2KFormula::startConversion()
     done = false;
     formuladoc = QDomDocument( "KFORMULA" );
     impl = new MathML2KFormulaPrivate( this, context, formuladoc );
-    QDomElement element = origdoc.documentElement();
-    if ( element.tagName() == "math" ) {
-        impl->math( element );
+    if ( orig_element.tagName() == "math" ) {
+        impl->math( orig_element );
         m_error = false;
     }
     else {
