@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #include <qpainter.h>
@@ -41,7 +41,7 @@ SymbolFontHelper::SymbolFontHelper()
 }
 
 
-bool SymbolFontStyle::init( ContextStyle* context )
+bool SymbolFontStyle::init( ContextStyle* context, bool /* install */)
 {
     // We require the symbol font to be there as it's the last resort
     // anyway.
@@ -178,15 +178,17 @@ void SymbolArtwork::calcSizes( const ContextStyle& style,
 }
 
 
-void SymbolArtwork::draw(QPainter& painter, const LuPixelRect& r,
+void SymbolArtwork::draw(QPainter& painter, const LuPixelRect& /*r*/,
                          const ContextStyle& style, ContextStyle::TextStyle tstyle,
                          luPt parentSize, const LuPixelPoint& origin)
 {
     luPt mySize = style.getAdjustedSize( tstyle );
     luPixel myX = origin.x() + getX();
     luPixel myY = origin.y() + getY();
+    /*
     if ( !LuPixelRect( myX, myY, getWidth(), getHeight() ).intersects( r ) )
         return;
+    */
 
     painter.setPen(style.getDefaultColor());
 
