@@ -35,6 +35,8 @@ public:
     // The key of the map is the family
     QMap<QString, QDict<QDomElement> > m_styles;
     QMap<QString, QDict<QDomElement> > m_stylesAutoStyles;
+
+    NumericFormatsMap numericFormats;
 };
 
 KoOasisStyles::KoOasisStyles()
@@ -226,8 +228,26 @@ void KoOasisStyles::insertStyle( const QDomElement& e, bool styleAutoStyles )
 // lacking long-textual forms.
 void KoOasisStyles::importDataStyle( const QDomElement& parent )
 {
+    KoOasisNumericFormat dataStyle;
+
+    const QString localName = parent.localName();
+    if (localName == "number-style")
+      dataStyle.type = KoOasisNumericFormat::Number;
+    else if (localName == "currency-style")
+      dataStyle.type = KoOasisNumericFormat::Currency;
+    else if (localName == "percentage-style")
+      dataStyle.type = KoOasisNumericFormat::Percentage;
+    else if (localName == "boolean-style")
+      dataStyle.type = KoOasisNumericFormat::Boolean;
+    else if (localName == "text-style")
+      dataStyle.type = KoOasisNumericFormat::Text;
+    else if (localName == "date-style")
+      dataStyle.type = KoOasisNumericFormat::Date;
+    else if (localName == "time-style")
+      dataStyle.type = KoOasisNumericFormat::Time;
+
     QString format;
-    int precision = 0;
+    int precision = -1;
     int leadingZ  = 1;
     bool thousandsSep = false;
     //todo negred
@@ -281,9 +301,12 @@ void KoOasisStyles::importDataStyle( const QDomElement& parent )
             prefix = e.text();
             kdDebug()<<" prefix :"<<prefix<<endl;
         } else if ( localName == "currency-symbol" ) {
+            dataStyle.currencySymbol = e.text();
+            kdDebug()<<" currency-symbol: "<<dataStyle.currencySymbol<<endl;
             format += e.text();
             //TODO
             // number:language="de" number:country="DE">€</number:currency-symbol>
+            // Stefan: localization of the symbol?
         } else if ( localName == "number" ) {
             // TODO: number:grouping="true"
             if ( e.hasAttributeNS( KoXmlNS::number, "decimal-places" ) )
@@ -310,11 +333,16 @@ void KoOasisStyles::importDataStyle( const QDomElement& parent )
                 if ( ( i % 3 == 0 ) && thousandsSep )
                     format =+ ',' ;
             }
-            format += '.';
-            for ( i = 0; i < precision; ++i )
-                format += '0';
+            if (precision > -1)
+            {
+                format += '.';
+                for ( i = 0; i < precision; ++i )
+                    format += '0';
+            }
         }
         else if ( localName == "scientific-number" ) {
+            if (dataStyle.type == KoOasisNumericFormat::Number)
+                dataStyle.type = KoOasisNumericFormat::Scientific;
             int exp = 2;
 
             if ( e.hasAttributeNS( KoXmlNS::number, "decimal-places" ) )
@@ -354,14 +382,19 @@ void KoOasisStyles::importDataStyle( const QDomElement& parent )
                     format+=',';
             }
 
-            format+='.';
-            for ( i = 0; i < precision; ++i )
-                format+='0';
+            if (precision > -1)
+            {
+                format += '.';
+                for ( i = 0; i < precision; ++i )
+                    format += '0';
+            }
 
             format+="E+";
             for ( i = 0; i < exp; ++i )
                 format+='0';
         } else if ( localName == "fraction" ) {
+                if (dataStyle.type == KoOasisNumericFormat::Number)
+                    dataStyle.type = KoOasisNumericFormat::Fraction;
                 int integer = 0;
                 int numerator = 1;
                 int denominator = 1;
@@ -416,7 +449,7 @@ void KoOasisStyles::importDataStyle( const QDomElement& parent )
     }
 
     const QString styleName = parent.attributeNS( KoXmlNS::style, "name", QString::null );
-    kdDebug(30003) << "datetime style: " << styleName << " qt format=" << format << endl;
+    kdDebug(30003) << "data style: " << styleName << " qt format=" << format << endl;
     if ( !prefix.isEmpty() )
     {
         kdDebug(30003)<<" format.left( prefix.length() ) :"<<format.left( prefix.length() )<<" prefix :"<<prefix<<endl;
@@ -443,6 +476,13 @@ void KoOasisStyles::importDataStyle( const QDomElement& parent )
     numeric.suffix=suffix;
     kdDebug()<<" finish insert format :"<<format<<" prefix :"<<prefix<<" suffix :"<<suffix<<endl;
     m_dataFormats.insert( styleName, numeric );
+    dataStyle.precision = precision;
+    d->numericFormats.insert( styleName, dataStyle );
+}
+
+const KoOasisStyles::NumericFormatsMap& KoOasisStyles::numericFormats() const
+{
+    return d->numericFormats;
 }
 
 #define addTextNumber( text, elementWriter ) { \
@@ -1011,6 +1051,50 @@ QString KoOasisStyles::saveOasisFractionStyle( KoGenStyles &mainStyles, const QS
 }
 
 
+QString KoOasisStyles::saveOasisNumberStyle( KoGenStyles &mainStyles, const QString & _format, const QString &_prefix, const QString &_suffix )
+{
+    kdDebug(30003)<<"QString saveOasisNumberStyle( KoGenStyles &mainStyles, const QString & _format ) :"<<_format<<endl;
+    QString format( _format );
+
+    KoGenStyle currentStyle( KoGenStyle::STYLE_NUMERIC_NUMBER );
+    QBuffer buffer;
+    buffer.open( IO_WriteOnly );
+    KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
+    QString text;
+    int decimalplaces = 0;
+    int integerdigits = 0;
+    bool beforeSeparator = true;
+    do
+    {
+        if ( format[0]=='.' || format[0]==',' )
+            beforeSeparator = false;
+        else if ( format[0]=='0' && beforeSeparator )
+            integerdigits++;
+        else if ( format[0]=='0' && !beforeSeparator )
+            decimalplaces++;
+        else
+            kdDebug(30003)<<" error format 0 \n";
+        format.remove( 0,1 );
+    }
+    while ( format.length() > 0 );
+    text= _prefix ;
+    addTextNumber(text, elementWriter );
+    elementWriter.startElement( "number:number" );
+    kdDebug(30003)<<" decimalplaces :"<<decimalplaces<<" integerdigits :"<<integerdigits<<endl;
+    if (!beforeSeparator)
+        elementWriter.addAttribute( "number:decimal-places", decimalplaces );
+    elementWriter.addAttribute( "number:min-integer-digits", integerdigits );
+    elementWriter.endElement();
+
+    text =_suffix ;
+    addTextNumber(text, elementWriter );
+    addKofficeNumericStyleExtension( elementWriter, _suffix,_prefix );
+
+    QString elementContents = QString::fromUtf8( buffer.buffer(), buffer.buffer().size() );
+    currentStyle.addChildElement( "number", elementContents );
+    return mainStyles.lookup( currentStyle, "N" );
+}
+
 QString KoOasisStyles::saveOasisPercentageStyle( KoGenStyles &mainStyles, const QString & _format, const QString &_prefix, const QString &_suffix )
 {
     //<number:percentage-style style:name="N11">
@@ -1045,7 +1129,8 @@ QString KoOasisStyles::saveOasisPercentageStyle( KoGenStyles &mainStyles, const
     text= _prefix ;
     addTextNumber(text, elementWriter );
     elementWriter.startElement( "number:number" );
-    elementWriter.addAttribute( "number:decimal-places", decimalplaces );
+    if (!beforeSeparator)
+        elementWriter.addAttribute( "number:decimal-places", decimalplaces );
     elementWriter.addAttribute( "number:min-integer-digits", integerdigits );
     elementWriter.endElement();
 
@@ -1121,7 +1206,8 @@ QString KoOasisStyles::saveOasisScientificStyle( KoGenStyles &mainStyles, const
 
     elementWriter.startElement( "number:scientific-number" );
     kdDebug(30003)<<" decimalplace :"<<decimalplace<<" integerdigits :"<<integerdigits<<" exponentdigits :"<<exponentdigits<<endl;
-    elementWriter.addAttribute( "number:decimal-places", decimalplace );
+    if (!beforeSeparator)
+        elementWriter.addAttribute( "number:decimal-places", decimalplace );
     elementWriter.addAttribute( "number:min-integer-digits",integerdigits );
     elementWriter.addAttribute( "number:min-exponent-digits",exponentdigits );
     elementWriter.endElement();
@@ -1152,19 +1238,44 @@ QString KoOasisStyles::saveOasisCurrencyStyle( KoGenStyles &mainStyles, const QS
     buffer.open( IO_WriteOnly );
     KoXmlWriter elementWriter( &buffer );  // TODO pass indentation level
     QString text;
+    int decimalplaces = 0;
+    int integerdigits = 0;
+    bool beforeSeparator = true;
     do
     {
+        if ( format[0]=='.' || format[0]==',' )
+            beforeSeparator = false;
+        else if ( format[0]=='0' && beforeSeparator )
+            integerdigits++;
+        else if ( format[0]=='0' && !beforeSeparator )
+            decimalplaces++;
+        else
+            kdDebug(30003)<<" error format 0 \n";
         format.remove( 0,1 );
     }
     while ( format.length() > 0 );
-    text =  _prefix ;
+
+    // NOTE Stefan: Misusing the prefix for the currency symbol.
+    //              It was not used before. If somebody complains about missing
+    //              prefixes for the currency in the 1.5 series, we've got a
+    //              probably a problem. For KOffice 2.0 I added a separate arg.
+    text =  QString::null; // _prefix ;
     addTextNumber(text, elementWriter );
 
-    elementWriter.startElement( "number:currency-style" );
+    elementWriter.startElement( "number:number" );
+    kdDebug(30003)<<" decimalplaces :"<<decimalplaces<<" integerdigits :"<<integerdigits<<endl;
+    if (!beforeSeparator)
+      elementWriter.addAttribute( "number:decimal-places", decimalplaces );
+    elementWriter.addAttribute( "number:min-integer-digits", integerdigits );
+    elementWriter.endElement();
 
     text =  _suffix ;
     addTextNumber(text, elementWriter );
     addKofficeNumericStyleExtension( elementWriter, _suffix,_prefix );
+
+    elementWriter.startElement( "number:currency-symbol" );
+    kdDebug(30003)<<" currency-symbol: "<<_prefix<<endl;
+    elementWriter.addTextNode( _prefix );
     elementWriter.endElement();
 
     QString elementContents = QString::fromUtf8( buffer.buffer(), buffer.buffer().size() );
