@@ -212,6 +212,7 @@ Editor::fill()
 		StringListMap::ConstIterator it = map.constBegin();
 		for( ; it != map.constEnd(); ++it) {
 			EditorGroupItem *groupItem = 0;
+//			kopropertydbg << "'" << it.key() << "' -> " << it.data().count() << endl;
 			if(!it.key().isEmpty() && !it.data().isEmpty() && map.count() > 1)
 				groupItem = new EditorGroupItem(d->topItem, d->set->groupDescription(it.key()) );
 
@@ -319,8 +320,11 @@ Editor::changeSet(Set *set, bool preservePrevSelection)
 	}
 
 	fill();
+
+	emit propertySetChanged(d->set);
+
 	if (d->set) {
-		//select prev. selecteed item
+		//select prev. selected item
 		EditorItem * item = 0;
 		if (!selectedPropertyName2.isEmpty()) //try other one for old prop set
 			item = d->itemDict[selectedPropertyName2];
@@ -336,8 +340,6 @@ Editor::changeSet(Set *set, bool preservePrevSelection)
 //			ensureItemVisible(item);
 		}
 	}
-
-	emit propertySetChanged(d->set);
 }
 
 //! @internal
@@ -356,8 +358,10 @@ void
 Editor::changeSetLater()
 {
 	qApp->eventLoop()->processEvents(QEventLoop::AllEvents);
-	if (kapp->hasPendingEvents())
+	if (kapp->hasPendingEvents()) {
+		d->changeSetLaterTimer.start(10, true); //try again...
 		return;
+	}
 	d->setListLater_set = false;
 	if (!d->setListLater_list)
 		return;
@@ -371,17 +375,17 @@ Editor::changeSetLater()
 void
 Editor::clear(bool editorOnly)
 {
-	hideEditor();
 	d->itemToSelectLater = 0;
+	hideEditor();
 
 	if(!editorOnly) {
 		qApp->eventLoop()->processEvents(QEventLoop::AllEvents);
+		if(d->set)
+			d->set->disconnect(this);
 		clearWidgetCache();
 		KListView::clear();
 		d->itemDict.clear();
 		d->topItem = 0;
-		if(d->set)
-			d->set->disconnect(this);
 	}
 }
 
@@ -469,9 +473,11 @@ Editor::slotPropertyReset(Set& set, Property& property)
 		// prop not in the dict, might be a child prop.
 		if(!item && property.parent())
 			item = d->itemDict[property.parent()->name()];
-		repaintItem(item);
-		for(QListViewItem *it = item->firstChild(); it; it = it->nextSibling())
-			repaintItem(it);
+		if (item) {
+			repaintItem(item);
+			for(QListViewItem *it = item->firstChild(); it; it = it->nextSibling())
+				repaintItem(it);
+		}
 	}
 
 	showUndoButton( false );
@@ -576,6 +582,7 @@ Editor::slotCurrentChanged(QListViewItem *item)
 void
 Editor::slotSetWillBeCleared()
 {
+	d->itemToSelectLater = 0;
 	if (d->currentWidget) {
 		acceptInput();
 		d->currentWidget->setProperty(0);
@@ -615,7 +622,7 @@ Editor::createWidgetForProperty(Property *property, bool changeWidgetProperty)
 	//update geometry earlier, because Widget::setValue() can depend on widget's geometry
 	updateEditorGeometry(d->currentItem, widget);
 
-	if(widget && !widget->property() || changeWidgetProperty)
+	if(widget && (!widget->property() || changeWidgetProperty))
 		widget->setProperty(property);
 
 //	if (!d->doNotSetFocusOnSelection) {
@@ -630,7 +637,8 @@ void
 Editor::clearWidgetCache()
 {
 	for(QMap<Property*, Widget*>::iterator it = d->widgetCache.begin(); it != d->widgetCache.end(); ++it)
-		delete it.data();
+		it.data()->deleteLater();
+//		delete it.data();
 	d->widgetCache.clear();
 }
 
