@@ -106,6 +106,7 @@ Set::Iterator::Iterator(const Set &set)
 
 Set::Iterator::~Iterator()
 {
+	delete iterator;
 }
 
 void
@@ -229,7 +230,7 @@ Set::removeProperty(const QCString &name)
 	if(name.isNull())
 		return;
 
-	Property *p = d->dict.take(name);
+	Property *p = d->dict.find(name);
 	removeProperty(p);
 }
 
@@ -238,6 +239,8 @@ Set::clear()
 {
 	aboutToBeCleared();
 	d->propertiesOfGroup.clear();
+	d->groupsDescription.clear();
+	d->groupForProperty.clear();
 	Property::DictIterator it(d->dict);
 	while (it.current())
 		removeProperty( it.current() );
@@ -251,7 +254,7 @@ Set::addToGroup(const QCString &group, Property *property)
 	if(!property)
 		return;
 
-	//do not add same property to the group twice
+	//do not add the same property to the group twice
 	if(d->groupForProperty.contains(property) && (d->groupForProperty[property] == group))
 		return;
 
@@ -273,6 +276,10 @@ Set::removeFromGroup(Property *property)
 		return;
 	QCString group = d->groupForProperty[property];
 	d->propertiesOfGroup[group].remove(property->name());
+	if (d->propertiesOfGroup[group].isEmpty()) {
+		//remove group as well
+		d->propertiesOfGroup.remove(group);
+	}
 	d->groupForProperty.remove(property);
 }
 
@@ -331,7 +338,7 @@ Set::contains(const QCString &name)
 Property&
 Set::property(const QCString &name)
 {
-	Property *p = d->dict[name];
+	Property *p = d->dict.find(name);
 	if (p)
 		return *p;
 //		p = new Property();
@@ -354,9 +361,7 @@ Set::operator= (const Set &set)
 	if(&set == this)
 		return *this;
 
-	d->dict.clear();
-	d->propertiesOfGroup.clear();
-	d->groupForProperty.clear();
+	clear();
 
 	d->ownProperty = set.d->ownProperty;
 	d->prevSelection = set.d->prevSelection;
