@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
 */
 
 #ifndef KOTEXTVIEW_IFACE_H
@@ -25,7 +25,7 @@
 
 #include <qstring.h>
 #include <qcolor.h>
-#include <korichtext.h>
+#include <KoRichText.h>
 #include <koffice_export.h>
 class KoTextView;
 
