@@ -12,8 +12,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -22,8 +22,8 @@
 
 #include <klocale.h>
 #include <kgenericfactory.h>
-#include <koStore.h>
-#include <koStoreDevice.h>
+#include <KoStore.h>
+#include <KoStoreDevice.h>
 
 #include <qdom.h>
 #include <qfile.h>
@@ -35,7 +35,7 @@ K_EXPORT_COMPONENT_FACTORY(kfile_koffice, KOfficeFactory( "kfile_koffice" ))
 
 KOfficePlugin::KOfficePlugin(QObject *parent, const char *name,
                        const QStringList &args)
-    
+
     : KFilePlugin(parent, name, args)
 {
     makeMimeTypeInfo( "application/x-kword" );
@@ -43,6 +43,11 @@ KOfficePlugin::KOfficePlugin(QObject *parent, const char *name,
     makeMimeTypeInfo( "application/x-kspread" );
     makeMimeTypeInfo( "application/x-karbon" );
     makeMimeTypeInfo( "application/x-kontour" );
+    makeMimeTypeInfo( "application/x-kchart" );
+    makeMimeTypeInfo( "application/x-kivio" );
+    makeMimeTypeInfo( "application/x-krita" );
+    makeMimeTypeInfo( "application/x-kformula" );
+    
     /*makeMimeTypeInfo( "application/vnd.kde.kword" );
     makeMimeTypeInfo( "application/vnd.kde.kpresenter" );
     makeMimeTypeInfo( "application/vnd.kde.kspread" );
@@ -53,7 +58,7 @@ KOfficePlugin::KOfficePlugin(QObject *parent, const char *name,
 void KOfficePlugin::makeMimeTypeInfo(const QString& mimeType)
 {
     KFileMimeTypeInfo* info = addMimeTypeInfo( mimeType );
-    
+
     KFileMimeTypeInfo::GroupInfo* group = 0L;
 
     group = addGroupInfo(info, "DocumentInfo", i18n("Document Information"));
@@ -65,40 +70,43 @@ void KOfficePlugin::makeMimeTypeInfo(const QString& mimeType)
     item = addItemInfo(group, "Title", i18n("Title"), QVariant::String);
     setHint(item, KFileMimeTypeInfo::Name);
     item = addItemInfo(group, "Abstract", i18n("Abstract"), QVariant::String);
-    setHint(item, KFileMimeTypeInfo::Description);    
+    setHint(item, KFileMimeTypeInfo::Description);
 }
 
 bool KOfficePlugin::readInfo( KFileMetaInfo& info, uint what)
 {
+    if ( info.path().isEmpty() ) // remote file
+        return false;
+
     KFileMetaInfoGroup group = appendGroup(info, "DocumentInfo");
-    
+
     KoStore* store = KoStore::createStore(info.path(), KoStore::Read);
     if ( store && store->open( QString("documentinfo.xml") ) )
     {
         KoStoreDevice dev( store );
         QDomDocument doc;
         doc.setContent( &dev );
-                
+
         QDomNode authorNode = doc.namedItem("document-info").namedItem("author");
         QDomNode aboutNode = doc.namedItem("document-info").namedItem("about");
-        
+
         QString author = stringFromNode(authorNode, "full-name");
         QString title = stringFromNode(aboutNode, "title");
         QString abstract = stringFromNode(aboutNode, "abstract");
-               
+
         appendItem(group, "Author", author);
         appendItem(group, "Title", title);
         appendItem(group, "Abstract", abstract);
-        
+
         store->close();
         delete store;
         return true;
     }
-    delete store;   
+    delete store;
     return false;
 }
 
-QString KOfficePlugin::stringFromNode(QDomNode node, QString name)
+QString KOfficePlugin::stringFromNode(const QDomNode &node, const QString &name)
 {
     QString value = node.namedItem(name).toElement().text();
     return value.isEmpty() ? i18n("*Unknown*") : value;
